@@ -74,13 +74,13 @@ void AutoComplete::AddSymbols(wxString xml) {
 void AutoComplete::AddSymbols_Backgroundtask(wxString xml) {
   wxXmlDocument xmldoc;
   wxStringInputStream xmlStream(xml);
-  xmldoc.Load(xmlStream, wxT("UTF-8"));
+  xmldoc.Load(xmlStream, wxS("UTF-8"));
   wxXmlNode *node = xmldoc.GetRoot();
   if (node != NULL) {
     wxXmlNode *children = node->GetChildren();
     while (children != NULL) {
       if (children->GetType() == wxXML_ELEMENT_NODE) {
-        if (children->GetName() == wxT("function")) {
+        if (children->GetName() == wxS("function")) {
           wxXmlNode *val = children->GetChildren();
           if (val) {
             wxString name = val->GetContent();
@@ -88,7 +88,7 @@ void AutoComplete::AddSymbols_Backgroundtask(wxString xml) {
           }
         }
 
-        if (children->GetName() == wxT("template")) {
+        if (children->GetName() == wxS("template")) {
           wxXmlNode *val = children->GetChildren();
           if (val) {
             wxString name = val->GetContent();
@@ -96,7 +96,7 @@ void AutoComplete::AddSymbols_Backgroundtask(wxString xml) {
           }
         }
 
-        if (children->GetName() == wxT("unit")) {
+        if (children->GetName() == wxS("unit")) {
           wxXmlNode *val = children->GetChildren();
           if (val) {
             wxString name = val->GetContent();
@@ -104,7 +104,7 @@ void AutoComplete::AddSymbols_Backgroundtask(wxString xml) {
           }
         }
 
-        if (children->GetName() == wxT("value")) {
+        if (children->GetName() == wxS("value")) {
           wxXmlNode *val = children->GetChildren();
           if (val) {
             wxString name = val->GetContent();
@@ -186,9 +186,8 @@ void AutoComplete::BuiltinSymbols_BackgroundTask() {
   /// Load private symbol list (do something different on Windows).
   wxString privateList;
   privateList = Dirstructure::Get()->UserAutocompleteFile();
-  wxLogMessage(wxString::Format(
-				_("Trying to load a list of autocompletable symbols from file %s"),
-				privateList.utf8_str()));
+  wxLogMessage(_("Trying to load a list of autocompletable symbols from file %s"),
+	       privateList.utf8_str());
   if (wxFileExists(privateList)) {
     wxTextFile priv(privateList);
 
@@ -211,9 +210,9 @@ void AutoComplete::BuiltinSymbols_BackgroundTask() {
         else if (unt.Replace(&line, ""))
           m_wordList[unit].Add(line);
         else
-          wxLogMessage(privateList +
-		       wxString::Format(_(": Can't interpret line: %s")),
-                       line.utf8_str());
+          wxLogMessage(_("%s: Can't interpret line: %s"),
+	    privateList.mb_str(),
+	    line.mb_str());
       }
     }
     priv.Close();
@@ -251,9 +250,8 @@ void AutoComplete::LoadableFiles_BackgroundTask(wxString sharedir) {
     else {
       wxFileName shareDir(sharedir + "/");
       shareDir.MakeAbsolute();
-      wxLogMessage(wxString::Format(
-				    _("Autocompletion: Scanning %s recursively for loadable lisp files."),
-				    shareDir.GetFullPath().utf8_str()));
+      wxLogMessage(_("Autocompletion: Scanning %s recursively for loadable lisp files."),
+				    shareDir.GetFullPath().utf8_str());
       wxDir maximadir(shareDir.GetFullPath());
       if (maximadir.IsOpened())
         maximadir.Traverse(maximaLispIterator); // todo
@@ -262,13 +260,12 @@ void AutoComplete::LoadableFiles_BackgroundTask(wxString sharedir) {
     wxFileName userDir(Dirstructure::Get()->UserConfDir() + "/");
     userDir.MakeAbsolute();
     wxDir maximauserfilesdir(userDir.GetFullPath());
-    wxLogMessage(wxString::Format(
-				  _("Autocompletion: Scanning %s for loadable lisp files."),
-				  userDir.GetFullPath().utf8_str()));
+    wxLogMessage(_("Autocompletion: Scanning %s for loadable lisp files."),
+		 userDir.GetFullPath().utf8_str());
     if (maximauserfilesdir.IsOpened())
       maximauserfilesdir.Traverse(userLispIterator);
     int num = m_builtInLoadFiles.GetCount();
-    wxLogMessage(wxString::Format(_("Found %i loadable files."), num));
+    wxLogMessage(_("Found %i loadable files."), num);
   }
 
   // Prepare a list of all built-in demos of maxima.
@@ -279,15 +276,14 @@ void AutoComplete::LoadableFiles_BackgroundTask(wxString sharedir) {
     demoDir.MakeAbsolute();
     demoDir.RemoveLastDir();
     GetDemoFiles_includingSubdirs maximaLispIterator(m_builtInDemoFiles);
-    wxLogMessage(wxString::Format(
-				  _("Autocompletion: Scanning %s for loadable demo files."),
-				  demoDir.GetFullPath().utf8_str()));
+    wxLogMessage(_("Autocompletion: Scanning %s for loadable demo files."),
+		 demoDir.GetFullPath().utf8_str());
 
     wxDir maximadir(demoDir.GetFullPath());
     if (maximadir.IsOpened())
       maximadir.Traverse(maximaLispIterator);
     int num = m_builtInDemoFiles.GetCount();
-    wxLogMessage(wxString::Format(_("Found %i demo files."), num));
+    wxLogMessage(_("Found %i demo files."), num);
   }
   m_builtInLoadFiles.Sort();
   m_builtInDemoFiles.Sort();
@@ -296,16 +292,16 @@ void AutoComplete::LoadableFiles_BackgroundTask(wxString sharedir) {
 void AutoComplete::UpdateDemoFiles(wxString partial, wxString maximaDir) {
   WaitForBackgroundThread_Files();
   // Remove the opening quote from the partial.
-  if (partial[0] == wxT('\"'))
+  if (partial[0] == wxS('\"'))
     partial = partial.Right(partial.Length() - 1);
 
   partial.Replace(wxFileName::GetPathSeparator(), "/");
   int pos;
-  if ((pos = partial.Find(wxT('/'), true)) == wxNOT_FOUND)
+  if ((pos = partial.Find(wxS('/'), true)) == wxNOT_FOUND)
     partial = wxEmptyString;
   else
     partial = partial.Left(pos);
-  wxString prefix = partial + wxT("/");
+  wxString prefix = partial + wxS("/");
 
   // Determine if we need to add the path to maxima's current dir to the path in
   // partial
@@ -322,7 +318,7 @@ void AutoComplete::UpdateDemoFiles(wxString partial, wxString maximaDir) {
   ClearDemofileList();
 
   // Add all files from the maxima directory to the demo file list
-  if (partial != wxT("//")) {
+  if (partial != wxS("//")) {
     GetDemoFiles userLispIterator(m_wordList[demofile], prefix);
     wxDir demofilesdir(partial);
     if (demofilesdir.IsOpened())
@@ -333,16 +329,16 @@ void AutoComplete::UpdateDemoFiles(wxString partial, wxString maximaDir) {
 void AutoComplete::UpdateGeneralFiles(wxString partial, wxString maximaDir) {
   WaitForBackgroundThread_Files();
   // Remove the opening quote from the partial.
-  if (partial[0] == wxT('\"'))
+  if (partial[0] == wxS('\"'))
     partial = partial.Right(partial.Length() - 1);
 
   partial.Replace(wxFileName::GetPathSeparator(), "/");
   int pos;
-  if ((pos = partial.Find(wxT('/'), true)) == wxNOT_FOUND)
+  if ((pos = partial.Find(wxS('/'), true)) == wxNOT_FOUND)
     partial = wxEmptyString;
   else
     partial = partial.Left(pos);
-  wxString prefix = partial + wxT("/");
+  wxString prefix = partial + wxS("/");
 
   // Determine if we need to add the path to maxima's current dir to the path in
   // partial
@@ -356,7 +352,7 @@ void AutoComplete::UpdateGeneralFiles(wxString partial, wxString maximaDir) {
     partial += "/";
 
   // Add all files from the maxima directory to the demo file list
-  if (partial != wxT("//")) {
+  if (partial != wxS("//")) {
     GetGeneralFiles fileIterator(m_wordList[generalfile], prefix);
     wxDir generalfilesdir(partial);
     if (generalfilesdir.IsOpened())
@@ -369,16 +365,16 @@ void AutoComplete::UpdateLoadFiles(wxString partial, wxString maximaDir) {
                  "file names."));
   WaitForBackgroundThread_Files();
   // Remove the opening quote from the partial.
-  if (partial[0] == wxT('\"'))
+  if (partial[0] == wxS('\"'))
     partial = partial.Right(partial.Length() - 1);
 
   partial.Replace(wxFileName::GetPathSeparator(), "/");
   int pos;
-  if ((pos = partial.Find(wxT('/'), true)) == wxNOT_FOUND)
+  if ((pos = partial.Find(wxS('/'), true)) == wxNOT_FOUND)
     partial = wxEmptyString;
   else
     partial = partial.Left(pos);
-  wxString prefix = partial + wxT("/");
+  wxString prefix = partial + wxS("/");
 
   // Determine if we need to add the path to maxima's current dir to the path in
   // partial
@@ -395,7 +391,7 @@ void AutoComplete::UpdateLoadFiles(wxString partial, wxString maximaDir) {
   m_wordList[loadfile] = m_builtInLoadFiles;
 
   // Add all files from the maxima directory to the load file list
-  if (partial != wxT("//")) {
+  if (partial != wxS("//")) {
     GetMacFiles userLispIterator(m_wordList[loadfile], prefix);
     wxDir loadfilesdir(partial);
     if (loadfilesdir.IsOpened())
@@ -418,20 +414,19 @@ wxArrayString AutoComplete::CompleteSymbol(wxString partial,
                _("Bug: Autocompletion requested for unknown type of item."));
 
   if (type != tmplte) {
-    for (size_t i = 0; i < m_wordList[type].GetCount(); i++) {
-      if (m_wordList[type][i].StartsWith(partial) &&
-          completions.Index(m_wordList[type][i]) == wxNOT_FOUND)
-        completions.Add(m_wordList[type][i]);
+    for (const auto &i : m_wordList[type]) {
+      if (i.StartsWith(partial) &&
+          completions.Index(i) == wxNOT_FOUND)
+        completions.Add(i);
     }
   } else {
-    for (size_t i = 0; i < m_wordList[type].GetCount(); i++) {
-      wxString templ = m_wordList[type][i];
-      if (templ.StartsWith(partial)) {
-        if (completions.Index(templ) == wxNOT_FOUND)
-          completions.Add(templ);
-        if (templ.SubString(0, templ.Find(wxT("(")) - 1) == partial &&
-            perfectCompletions.Index(templ) == wxNOT_FOUND)
-          perfectCompletions.Add(templ);
+    for (const auto &i: m_wordList[type]) {
+      if (i.StartsWith(partial)) {
+        if (completions.Index(i) == wxNOT_FOUND)
+          completions.Add(i);
+        if (i.SubString(0, i.Find(wxS("(")) - 1) == partial &&
+            perfectCompletions.Index(i) == wxNOT_FOUND)
+          perfectCompletions.Add(i);
       }
     }
   }
@@ -439,11 +434,10 @@ wxArrayString AutoComplete::CompleteSymbol(wxString partial,
   // Add a list of words that were defined on the work sheet but that aren't
   // defined as maxima commands or functions.
   if (type == command) {
-    WorksheetWords::const_iterator it;
-    for (it = m_worksheetWords.begin(); it != m_worksheetWords.end(); ++it) {
-      if (it->first.StartsWith(partial)) {
-        if (completions.Index(it->first) == wxNOT_FOUND) {
-          completions.Add(it->first);
+    for (const auto &it : m_worksheetWords) {
+      if (it.first.StartsWith(partial)) {
+        if (completions.Index(it.first) == wxNOT_FOUND) {
+          completions.Add(it.first);
         }
       }
     }
@@ -462,13 +456,13 @@ void AutoComplete::AddSymbol(wxString fun, autoCompletionType type) {
 
 void AutoComplete::AddSymbol_nowait(wxString fun, autoCompletionType type) {
   /// Check for function of template
-  if (fun.StartsWith(wxT("FUNCTION: "))) {
+  if (fun.StartsWith(wxS("FUNCTION: "))) {
     fun = fun.Mid(10);
     type = command;
-  } else if (fun.StartsWith(wxT("TEMPLATE: "))) {
+  } else if (fun.StartsWith(wxS("TEMPLATE: "))) {
     fun = fun.Mid(10);
     type = tmplte;
-  } else if (fun.StartsWith(wxT("UNIT: "))) {
+  } else if (fun.StartsWith(wxS("UNIT: "))) {
     fun = fun.Mid(6);
     type = unit;
   }
@@ -482,25 +476,31 @@ void AutoComplete::AddSymbol_nowait(wxString fun, autoCompletionType type) {
   /// only add one template. We count the arguments by counting '<'
   if (type == tmplte) {
     fun = FixTemplate(fun);
-    wxString funName = fun.SubString(0, fun.Find(wxT("(")));
-    long count = fun.Freq('<');
-    size_t i = 0;
-    for (i = 0; i < m_wordList[type].GetCount(); i++) {
-      wxString t = m_wordList[type][i];
-      if (t.StartsWith(funName) && (t.Freq('<') == count))
-        break;
-    }
-    if (i == m_wordList[type].GetCount())
-      m_wordList[type].Add(fun);
+    long openpos = fun.Find(wxS("("));
+    if(openpos < 0)
+      wxLogMessage(_("Cannot interpret template %s"), fun.mb_str());
+    else
+      {
+	wxString funName = fun.SubString(0, openpos);
+	long count = fun.Freq('<');
+	size_t i = 0;
+	for (const auto &o: m_wordList[type]) {
+	  if (o.StartsWith(funName) && (o.Freq('<') == count))
+	    break;
+	  i++;
+	}
+	if (i == m_wordList[type].GetCount())
+	  m_wordList[type].Add(fun);
+      }
   }
 }
 
 wxString AutoComplete::FixTemplate(wxString templ) {
-  templ.Replace(wxT(" "), wxEmptyString);
-  templ.Replace(wxT(",..."), wxEmptyString);
+  templ.Replace(wxS(" "), wxEmptyString);
+  templ.Replace(wxS(",..."), wxEmptyString);
 
   /// This will change optional arguments
-  m_args.ReplaceAll(&templ, wxT("<[\\1]>"));
+  m_args.ReplaceAll(&templ, wxS("<[\\1]>"));
 
   return templ;
 }
