@@ -226,7 +226,7 @@ bool AutocompletePopup::Create(wxWindow *parent) {
   bool retval = wxListView::Create(parent, 1, m_position, wxDefaultSize,
                                    wxLC_ALIGN_LEFT | wxLC_REPORT |
 				   wxLC_NO_HEADER | wxLC_SINGLE_SEL);
-  wxWindowUpdateLocker lock(this);
+  //  wxWindowUpdateLocker lock(this);
   InsertColumn(0, wxEmptyString);
   UpdateResults();
   SetColumnWidth(0, wxLIST_AUTOSIZE);
@@ -295,11 +295,11 @@ AutocompletePopup::AutocompletePopup(wxWindow *parent, EditorCell *editor,
 void AutocompletePopup::OnChar(wxKeyEvent &event) {
   wxChar key = event.GetUnicodeKey();
   if (((m_type == AutoComplete::esccommand) && wxIsprint(key)) ||
-      ((wxIsalnum(key)) || (key == wxT('_')) || (key == wxT('\"')) ||
+      ((wxIsalnum(key)) || (key == wxS('_')) || (key == wxS('\"')) ||
        (((m_type == AutoComplete::generalfile) ||
          (m_type == AutoComplete::loadfile) ||
          (m_type == AutoComplete::demofile)) &&
-        (key == wxT('/'))))) {
+        (key == wxS('/'))))) {
     wxString oldString = m_editor->GetSelectionString();
     m_partial += wxString(key);
     if (m_type != AutoComplete::esccommand)
