@@ -37,6 +37,7 @@ extern unsigned char view_refresh_svg_gz[];
 #include <wx/image.h>
 #include <wx/grid.h>
 #include <wx/hashmap.h>
+#include <wx/clrpicker.h>
 #include <memory>
 #include <wx/propdlg.h>
 #include <wx/generic/propdlg.h>
@@ -46,12 +47,18 @@ extern unsigned char view_refresh_svg_gz[];
 #include <wx/imaglist.h>
 #include <wx/bookctrl.h>
 #include <wx/artprov.h>
+#include <unordered_map>
 
 #ifndef CONFIGDIALOGUE_H
 #define CONFIGDIALOGUE_H
 
 #include "TextStyle.h"
+#include "Worksheet.h"
 #include "Configuration.h"
+#include <unordered_map>
+
+extern unsigned char GTK_PRINT_SVG_GZ[];
+extern size_t GTK_PRINT_SVG_GZ_SIZE;
 
 enum
 {
@@ -60,6 +67,8 @@ enum
   checkbox_bold,
   checkbox_italic,
   checkbox_underlined,
+  checkbox_slanted,
+  checkbox_strikethrough,
   button_defaultFont,
   button_mathFont,
   style_font_family,
@@ -93,11 +102,8 @@ public:
     svg = 3
   };
 
-  /*! Called if the color of an item has been changed
-
-    called from class ColorPanel
-  */
-  void OnChangeColor();
+  /*! Called if the color of an item has been changed */
+  void OnChangeColor(wxColourPickerEvent& event);
 
   /*! Stores the settings from the configuration dialog.
 
@@ -107,8 +113,8 @@ public:
   void WriteSettings();
 
 private:
-  const int mMinPanelWidth = 640;
-  const int mMinPanelHeight = 720;
+  const int mMinPanelWidth = 500;
+  const int mMinPanelHeight = 500;
 
 private:
   enum newVariables
@@ -131,10 +137,17 @@ private:
   };
   std::unique_ptr<struct NSVGrasterizer, decltype(std::free)*> m_svgRast{nullptr, std::free};
   //! The configuration storage
-  Configuration *m_configuration;
-  
+  std::unique_ptr<Configuration> m_configuration;
+  Worksheet *m_sampleWorksheet = NULL;
+
+#if wxCHECK_VERSION(3, 3, 0) || wxUSE_STL
+  typedef std::unordered_map <wxString, wxString> StringHash;
+  typedef std::unordered_map <wxString, long> Languages;
+#else
   WX_DECLARE_STRING_HASH_MAP(wxString, StringHash);
   WX_DECLARE_STRING_HASH_MAP(long, Languages);
+#endif
+
   Languages m_languages;
   /*! TheSample text that is shown by the style selector.
 
@@ -150,7 +163,6 @@ private:
     //! Sets the text style of the example
     void SetStyle(const Style &style)
       {
-        if (m_style.IsStyleEqualTo(style)) return;
         m_style = style;
         Refresh();
       }
@@ -166,30 +178,6 @@ private:
     Style m_style;
   };
 
-  /*! A rectangle showing the color of an item
-
-    If the color contains transparency the rectangle is checkered accordingly.
-  */
-  class ColorPanel : public wxPanel
-  {
-  public:
-    ColorPanel(ConfigDialogue *conf, wxWindow *parent,
-               int id, wxPoint pos, wxSize size, long style);
-
-    void OnPaint(wxPaintEvent &WXUNUSED(event));
-
-    void OnClick(wxMouseEvent& WXUNUSED(event));
-
-    void SetColor(wxColor color)
-      {
-        m_color = color;
-        Refresh();
-      };
-  private:
-    ConfigDialogue *m_configDialogue;
-    wxColor m_color;
-  };
-
 
   /*! begin wxGlade: ConfigDialogue::methods
 
@@ -200,13 +188,12 @@ private:
   //! Calculates the size of the images for a configuration tab
   int GetImageSize();
 
-  //! Loads the image for a configuration tab
-  wxBitmap GetImage(wxString name,
-                    unsigned char *data, size_t len);
-
   //! The panel that allows to choose which formats to put on the clipboard
   wxWindow *CreateClipboardPanel();
 
+  //! The panel that allows to change the print settings
+  wxWindow *CreatePrintPanel();
+
   //! The panel that allows to choose which formats to put on the clipboard
   wxWindow *CreateRevertToDefaultsPanel();
 
@@ -236,7 +223,7 @@ private:
 protected:
   wxGrid *m_maximaEnvVariables;
   void OnImport(wxCommandEvent& event);
-  static void CopyConfig(wxConfigBase *src, wxConfigBase *dst, wxString dir = wxT("/"));
+  static void CopyConfig(wxConfigBase *src, wxConfigBase *dst, wxString dir = wxS("/"));
   void OnReloadAll(wxCommandEvent& event);
   void OnReloadStyles(wxCommandEvent& event);
   void OnResetAllToDefaults(wxCommandEvent& event);
@@ -304,13 +291,14 @@ protected:
   wxSpinCtrl *m_defaultPlotWidth;
   wxSpinCtrl *m_defaultPlotHeight;
   wxSpinCtrl *m_displayedDigits;
+  wxSpinCtrl *m_printMargin_Top;
+  wxSpinCtrl *m_printMargin_Bot;
+  wxSpinCtrl *m_printMargin_Left;
+  wxSpinCtrl *m_printMargin_Right;
   wxRadioButton *m_displayNDigits;
   wxRadioButton *m_displayAllDigits;
   wxRadioButton *m_linebreaksInLongNums;
-  wxRadioButton *m_automaticWxMathML;
-  wxRadioButton *m_userWxMathML;
   wxSpinCtrl *m_maxClipbrdBitmapMegabytes;
-  wxTextCtrl *m_wxMathMLLocation;
   //! A checkbox that asks if TeX should put the exponents above or after the subscripts.
   wxCheckBox *m_TeXExponentsAfterSubscript;
   //! A checkbox that asks if TeX should use the \\partial symbol for representing diff()
@@ -344,14 +332,14 @@ protected:
   wxCheckBox *m_incrementalSearch;
   wxCheckBox *m_notifyIfIdle;
   wxChoice *m_showUserDefinedLabels;
-  wxButton *m_getDefaultFont;
-  wxButton *m_getMathFont;
   wxButton *m_getStyleFont;
   wxListBox *m_styleFor;
   //! An example rectangle with the font color
-  ColorPanel *m_styleColor;
+  wxColourPickerCtrl *m_styleColor;
   wxCheckBox *m_boldCB;
   wxCheckBox *m_italicCB;
+  wxCheckBox *m_slantedCB;
+  wxCheckBox *m_strikethroughCB;
   wxCheckBox *m_underlinedCB;
   wxCheckBox *m_fixedFontInTC;
   wxCheckBox *m_unixCopy;
@@ -386,9 +374,6 @@ protected:
 
   void OnIdle(wxIdleEvent &event);
 
-  //! Starts the font selector dialog triggered by the math or default font buttons
-  void OnFontButton(wxCommandEvent &event);
-
   //! Called if a new item type that is to be styled is selected
   void OnChangeStyle(wxCommandEvent &event);
 
@@ -407,16 +392,9 @@ protected:
   //! A "export the configuration" dialog
   void LoadSave(wxCommandEvent &event);
 
-  //! Map the style list index to a style
-  static TextStyle StyleForListIndex(int index);
-  //! Map the style to the style list index
-  static int StyleListIndexForStyle(TextStyle style);
   //! Get the style currently selected in the m_styleFor control
   TextStyle GetSelectedStyle() const;
 
-  //! Sets the label for the font setting button given by the style (either TS_DEFAULT or TS_MATH)
-  void UpdateButton(TextStyle st);
-
   //! The size of the text font
   int m_fontSize;
   //! The size of the maths font.
