@@ -31,7 +31,9 @@
 #include "LoggingMessageDialog.h"
 #include "TextStyle.h"
 #include <memory>
+#include <mutex>
 #include <unordered_map>
+#include <random>
 #include <list>
 #include <vector>
 #include <wx/wupdlock.h>
@@ -39,6 +41,7 @@
 #ifdef __WXMSW__
 #include <wx/msw/webview_ie.h>
 #endif
+#include <unordered_map>
 
 #define MC_LINE_SKIP Scale_Px(2)
 #define MC_TEXT_PADDING Scale_Px(1)
@@ -95,7 +98,8 @@ public:
     mathJaX_TeX = 0,
     bitmap = 1,
     mathML_mathJaX = 2,
-    svg = 3
+    svg = 3,
+    html_export_invalidChoice
   };
 
   enum showLabels : int8_t
@@ -103,17 +107,14 @@ public:
     labels_automatic = 0,
     labels_prefer_user = 1,
     labels_useronly = 2,
-    labels_none = 3
+    labels_none = 3,
+    labels_invalidSelection
   };
 
   enum drawMode
   {
     ascii,              //!< Use ascii characters only
-    assembled_unicode_fallbackfont,  //!< Unicode, fallbackfont 1
-    assembled_unicode,  //!< Unicode, current font
-    assembled_unicode_fallbackfont2,  //!< Unicode, fallbackfont 2
-    handdrawn,           //!< A  parenthesis sign that was created using draw commands
-    unknown
+    handdrawn           //!< A  parenthesis sign that was created using draw commands
   };
 
   enum InitOpt
@@ -129,11 +130,20 @@ public:
     display_1dASCII
   };
 
+#if wxCHECK_VERSION(3, 3, 0) || wxUSE_STL
+  typedef std::unordered_map <wxString, bool> StringBoolHash;
+  typedef std::unordered_map <wxString, wxString> RenderablecharsHash;
+  typedef std::unordered_map <wxString, int> StringHash;
+#else
+  WX_DECLARE_STRING_HASH_MAP(bool, StringBoolHash);
+  WX_DECLARE_STRING_HASH_MAP(wxString, RenderablecharsHash);
   WX_DECLARE_STRING_HASH_MAP(int, StringHash);
+#endif
   /*! All maxima operator names we know
    */
   StringHash m_maximaOperators;
-
+  //! Coincides name with a operator known to maxima?
+  bool IsOperator(wxString name){return !(m_maximaOperators.find(name) == m_maximaOperators.end());}
   const wxEnvVariableHashMap& MaximaEnvVars() const {return m_maximaEnvVars;}
   wxEnvVariableHashMap m_maximaEnvVars;
 
@@ -142,7 +152,7 @@ public:
 
   //! Set maxima's working directory
   void SetWorkingDirectory(wxString dir)
-    { m_workingdir = dir; }
+    { m_workingdir = std::move(dir); }
 
   wxString GetWorkingDirectory() const
     { return m_workingdir; }
@@ -158,10 +168,9 @@ public:
   void ResetAllToDefaults(InitOpt options = {});
 
   //! Set the drawing context that is currently active
-  void SetContext(wxDC &dc)
+  void SetRecalcContext(wxDC &dc)
     {
       m_dc = &dc;
-      m_antialiassingDC = NULL;
     }
   void UnsetContext() {m_dc = NULL;}
 
@@ -170,18 +179,13 @@ public:
   void FixedFontInTextControls(bool fixed) {m_fixedFontTC = fixed;}
   wxBrush GetBackgroundBrush() const {return m_BackgroundBrush;}
   wxBrush GetTooltipBrush() const {return m_tooltipBrush;}
-  void SetAntialiassingDC(wxDC &antialiassingDC)
-    {m_antialiassingDC = &antialiassingDC;}
-
-  void UnsetAntialiassingDC()
-    {m_antialiassingDC = NULL;}
 
   ~Configuration();
 
-  static wxString m_maximaLocation_override;
   static wxString m_configfileLocation_override;
 
   using EscCodeContainer = std::unordered_map<wxString, wxString, wxStringHash>;
+  static std::unordered_map<TextStyle, wxString> m_styleNames;
   using EscCodeIterator = EscCodeContainer::const_iterator;
 
   //! Retrieve a symbol for the escape code typed after the Escape key.
@@ -229,6 +233,15 @@ public:
   //! Define if we want to hide brackets that are not under the pointer.
   void PrintScale(double scale){m_printScale = scale;}
 
+  void PrintMargin_Top(double margin){m_printMargin_Top = margin;}
+  void PrintMargin_Bot(double margin){m_printMargin_Bot = margin;}
+  void PrintMargin_Left(double margin){m_printMargin_Left = margin;}
+  void PrintMargin_Right(double margin){m_printMargin_Right = margin;}
+  double PrintMargin_Top() const {return m_printMargin_Top;}
+  double PrintMargin_Bot() const {return m_printMargin_Bot;}
+  double PrintMargin_Left() const {return m_printMargin_Left;}
+  double PrintMargin_Right() const {return m_printMargin_Right;}
+
   //! Sets the zoom factor the worksheet is displayed at
   void SetZoomFactor(double newzoom);
 
@@ -249,23 +262,17 @@ public:
     { return m_zoomFactor; }
 
   //! Get a drawing context suitable for size calculations
-  wxDC *GetDC()
+  wxDC *GetRecalcDC() const
     { return m_dc; }
 
-  //! Get a drawing context suitable for size calculations
-  wxDC *GetAntialiassingDC()
-    {
-      if ((m_antialiassingDC != NULL) && m_antiAliasLines)
-        return m_antialiassingDC;
-      else
-        return m_dc;
-    }
+  void SetRecalcDC(wxDC *dc)
+    { m_dc = dc; }
   
-  AFontName GetFontName(TextStyle ts = TS_DEFAULT) const;
+  wxString GetFontName(TextStyle ts = TS_CODE_DEFAULT) const;
 
   // cppcheck-suppress functionStatic
   // cppcheck-suppress functionConst
-  AFontName GetSymbolFontName() const;
+  wxString GetSymbolFontName() const;
 
   wxFontWeight IsBold(long st) const;
 
@@ -290,7 +297,6 @@ public:
         return m_indent;
     }
 
-  void SetPPI(wxSize ppi){m_ppi = ppi;}
   /*! Get the resolution 
 
     During recalculation the drawing context doesn't know the display's resolution
@@ -343,12 +349,6 @@ public:
       m_indent = indent;
     }
 
-  //! Set the width of the visible window for GetClientWidth()
-  void SetClientWidth(long width)
-    {
-      m_clientWidth = width;
-    }
-
   bool IncrementalSearch() const {return m_incrementalSearch;}
 
 
@@ -367,18 +367,6 @@ public:
       m_charsInFont.clear();
     }
   
-  //! Set the height of the visible window for GetClientHeight()
-  void SetClientHeight(long height)
-    { m_clientHeight = height; }
-
-  //! Returns the width of the visible portion of the worksheet
-  long GetClientWidth() const
-    { return m_clientWidth; }
-
-  //! Returns the height of the visible portion of the worksheet
-  long GetClientHeight() const
-    { return m_clientHeight; }
-
   //! Calculates the default line width for the worksheet
   double GetDefaultLineWidth() const
     {
@@ -447,14 +435,9 @@ public:
   //! Do we want to indent all maths?
   bool IndentMaths() const {return m_indentMaths;}
   void IndentMaths(bool indent){m_indentMaths = indent;}
-  AFontSize GetFontSize(TextStyle st) const
-    {
-      if (st == TS_TEXT || st == TS_HEADING5 || st == TS_HEADING6 || st == TS_SUBSUBSECTION || st == TS_SUBSECTION || st == TS_SECTION || st == TS_TITLE)
-        return m_styles[st].GetFontSize();
-      return {};
-    }
+  AFontSize GetFontSize(TextStyle st) const { return m_styles[st].GetFontSize(); }
 
-  const wxString &GetStyleName(TextStyle textStyle) const;
+  static const wxString &GetStyleName(TextStyle textStyle);
 
   /*! Reads the style settings 
 
@@ -470,35 +453,29 @@ public:
   void WriteStyles(const wxString &file = {});
   void WriteStyles(wxConfigBase *config);
   void WriteSettings(const wxString &file = {});
-  
+  void MakeStylesConsistent();
   void Outdated(bool outdated)
     { m_outdated = outdated; }
 
-  bool CheckTeXFonts() const
-    { return m_TeXFonts; }
-
-  void CheckTeXFonts(bool check)
-    { m_TeXFonts = check; }
-
   bool CheckKeepPercent() const
     { return m_keepPercent; }
 
   void SetKeepPercent(bool keepPercent)
     { m_keepPercent = keepPercent; }
 
-  AFontName GetTeXCMRI() const
+  wxString GetTeXCMRI() const
     { return m_fontCMRI; }
 
-  AFontName GetTeXCMSY() const
+  wxString GetTeXCMSY() const
     { return m_fontCMSY; }
 
-  AFontName GetTeXCMEX() const
+  wxString GetTeXCMEX() const
     { return m_fontCMEX; }
 
-  AFontName GetTeXCMMI() const
+  wxString GetTeXCMMI() const
     { return m_fontCMMI; }
 
-  AFontName GetTeXCMTI() const
+  wxString GetTeXCMTI() const
     { return m_fontCMTI; }
 
   bool ShowCodeCells() const
@@ -527,7 +504,7 @@ public:
   wxColour GetColor(TextStyle style);
   
   //! Inverts a color: In 2020 wxColor still lacks this functionality
-  wxColour InvertColour(wxColour col);
+  static wxColour InvertColour(wxColour col);
   
   /*! Make this color differ from the background by a noticeable amount
     
@@ -564,7 +541,7 @@ public:
   
   wxString SymbolPaneAdditionalChars() const
     {return m_symbolPaneAdditionalChars;}
-  void SymbolPaneAdditionalChars(wxString symbols) {m_symbolPaneAdditionalChars = symbols;}
+  void SymbolPaneAdditionalChars(wxString symbols) {m_symbolPaneAdditionalChars = std::move(symbols);}
   
   //! Notify the user if maxima is idle?
   bool NotifyIfIdle() const
@@ -600,14 +577,32 @@ public:
     const wxMemoryBuffer m_data;
     const wxString m_filename;
   };
-    
-  std::list<FileToSave> m_filesToSave;
+
+  //! Stores the information about a file we need to write during the save process
+  class TextsnippetToDraw
+  {
+  public:
+    TextsnippetToDraw(const wxPoint &pos, const wxString &text, const wxColor color):
+      m_pos(pos),
+      m_text(text),
+      m_color(color)
+      {        
+      }
+    const wxPoint  Pos() const{return m_pos;}
+    const wxString Text() const{return m_text;}
+    const wxColor  Color() const{return m_color;}
+  private:
+    const wxPoint  m_pos;
+    const wxString m_text;
+    const wxColor  m_color;
+  };
+
   FileToSave PopFileToSave();
   void PushFileToSave(const wxString &filename, const wxMemoryBuffer &data)
     { m_filesToSave.emplace_front(FileToSave(filename, data)); }
 
   wxRect GetUpdateRegion() const {return m_updateRegion;}
-  const std::list<FileToSave> GetFilesToSave(){return m_filesToSave;}
+  const std::list<FileToSave> &GetFilesToSave() const {return m_filesToSave;}
   void SetUpdateRegion(wxRect rect){m_updateRegion = rect;}
 
   //! Whether any part of the given rectangle is within the current update region,
@@ -615,7 +610,7 @@ public:
   bool InUpdateRegion(wxRect rect) const;
 
   bool GetInsertAns() const
-    { return m_insertAns; }
+    { return m_insertAns; } 
 
   void SetInsertAns(bool insertAns){ m_insertAns = insertAns; }
 
@@ -651,6 +646,9 @@ public:
   showLabels GetLabelChoice() const
     { return m_showLabelChoice; }
 
+  bool ShowInputLabels() const {return m_showInputLabels;}
+  void ShowInputLabels(bool show) {m_showInputLabels = show;}
+  
   bool InvertBackground() const {return m_invertBackground;}
   void InvertBackground(bool invert){ m_invertBackground = invert; }
 
@@ -689,7 +687,7 @@ public:
   //! Parameters to the maxima binary
   wxString MaximaParameters() const {return m_maximaParameters;}
   //! The parameters we pass to the maxima binary
-  void MaximaParameters(wxString parameters){m_maximaParameters = parameters;}
+  void MaximaParameters(wxString parameters){m_maximaParameters = std::move(parameters);}
 
   //! The auto-detected maxima location
   static wxString MaximaDefaultLocation();
@@ -703,7 +701,7 @@ public:
   void OnMpBrowse(wxCommandEvent& event);
   
   //! Sets the location of the maxima binary.
-  void MaximaUserLocation(wxString maxima) { m_maximaUserLocation = maxima; }
+  void MaximaUserLocation(wxString maxima) { m_maximaUserLocation = std::move(maxima); }
 
   //! Autodetect the web browser? (If false the user-specified location is used)
   bool AutodetectHelpBrowser() const {return m_autodetectHelpBrowser;}
@@ -726,7 +724,7 @@ public:
   wxString HelpBrowserUserLocation() const {return m_helpBrowserUserLocation;}
 
   //! Sets the location of the web browser the user has detected.
-  void HelpBrowserUserLocation(wxString helpBrowser) { m_helpBrowserUserLocation = helpBrowser;}
+  void HelpBrowserUserLocation(wxString helpBrowser) { m_helpBrowserUserLocation = std::move(helpBrowser);}
 
   /*! Could a maxima binary be found in the path we expect it to be in?
 
@@ -752,17 +750,11 @@ public:
   bool MathJaXURL_UseUser() const { return m_mathJaxURL_UseUser;}
   void MathJaXURL_UseUser(bool useUser){m_mathJaxURL_UseUser = useUser;}
 
-  bool WxMathML_UseFile() const { return m_wxMathML_UseFile;}
-  void WxMathML_UseFile(bool useFile){m_wxMathML_UseFile = useFile;}
-  wxString WxMathML_Filename() const { return m_wxMathML_Filename;}
-  void WxMathML_Filename(wxString name) { m_wxMathML_Filename = name;}
   bool EnterEvaluates() const {return m_enterEvaluates;}
   void EnterEvaluates(bool enterEvaluates) {m_enterEvaluates = enterEvaluates;}
-  static wxString MathJaXURL_Auto() { return wxT("https://cdn.jsdelivr.net/npm/mathjax@3/es5/tex-mml-chtml.js");}
+  static wxString MathJaXURL_Auto() { return wxS("https://cdn.jsdelivr.net/npm/mathjax@3/es5/tex-mml-chtml.js");}
   //! Returns the URL MathJaX can be found at.
-  void MathJaXURL(wxString url){m_mathJaxURL = url;}
-  bool AntiAliasLines() const {return m_antiAliasLines;}
-  void AntiAliasLines(bool antiAlias){ m_antiAliasLines = antiAlias; }
+  void MathJaXURL(wxString url){m_mathJaxURL = std::move(url);}
 
   bool CopyBitmap() const {return m_copyBitmap;}
   void CopyBitmap(bool copyBitmap){ m_copyBitmap = copyBitmap; }
@@ -784,7 +776,7 @@ public:
   void UseSVG(bool useSVG) { m_useSVG = useSVG ;}
   void ShowLength(long length) { m_showLength = length; }
   long ShowLength() const {return m_showLength;}
-  void LispType(wxString type) { m_lispType = type; }
+  void LispType(wxString type) { m_lispType = std::move(type); }
   wxString LispType() const {return m_lispType;}
   
   //! Which way do we want to draw parenthesis?
@@ -798,23 +790,26 @@ public:
     { m_useUnicodeMaths = useunicodemaths; }
   bool UseUnicodeMaths() const {return m_useUnicodeMaths;}
   
-  drawMode GetParenthesisDrawMode();
-
-  WX_DECLARE_STRING_HASH_MAP(bool, StringBoolHash);
   StringBoolHash m_hideMarkerForThisMessage;
 
-  /*! Get the resolved text Style for a given text style identifier.
+  /*! Get the text Style for a given text style identifier.
 
     \param textStyle The text style to resolve the style for.
-    \param fontSize Only relevant for math cells: Super- and subscripts can have different
-    font styles than the rest.
   */
-  Style GetStyle(TextStyle textStyle, AFontSize fontSize) const;
-  
+  const Style *GetStyle(TextStyle textStyle) const { return &m_styles[textStyle]; }
+  /*! Get the text Style for a given text style identifier.
+
+    Theoretically GetStyle and GetWritableStyle wouldn't collide if they had the
+    same name. But I am afraid if all developers know how to deal with the situation
+    that performance degrades if a const is missing while the rest works fine.
+    \param textStyle The text style to resolve the style for.
+  */
+  Style *GetWritableStyle(TextStyle textStyle) { return &m_styles[textStyle]; }
+
   //! Get the worksheet this configuration storage is valid for
   wxWindow *GetWorkSheet() const {return m_workSheet;}
   //! Set the worksheet this configuration storage is valid for
-  inline void SetWorkSheet(wxWindow *workSheet);
+  void SetWorkSheet(wxWindow *workSheet);
 
   long DefaultPort() const {return m_defaultPort;}
   void DefaultPort(long port){m_defaultPort = port;}
@@ -834,16 +829,16 @@ public:
     {m_offerKnownAnswers = offerKnownAnswers;}
   
   wxString Documentclass() const {return m_documentclass;}
-  void Documentclass(wxString clss){m_documentclass = clss;}
+  void Documentclass(wxString clss){m_documentclass = std::move(clss);}
   wxString DocumentclassOptions() const {return m_documentclassOptions;}
-  void DocumentclassOptions(wxString classOptions){m_documentclassOptions = classOptions;}
+  void DocumentclassOptions(wxString classOptions){m_documentclassOptions = std::move(classOptions);}
 
   
   htmlExportFormat HTMLequationFormat() const {return m_htmlEquationFormat;}
   void HTMLequationFormat(htmlExportFormat HTMLequationFormat)
     {m_htmlEquationFormat = HTMLequationFormat;}
 
-  AFontSize GetDefaultFontSize() const        { return m_styles[TS_DEFAULT].GetFontSize(); }
+  AFontSize GetDefaultFontSize() const        { return m_styles[TS_CODE_DEFAULT].GetFontSize(); }
   AFontSize GetMathFontSize() const           { return m_styles[TS_MATH].GetFontSize(); }
 
   //! Get the worksheet this configuration storage is valid for
@@ -858,17 +853,12 @@ public:
   bool ClipToDrawRegion() const {return m_clipToDrawRegion;}
   //! Do we want to save time by only redrawing the area currently shown on the screen?
   void ClipToDrawRegion(bool clipToDrawRegion){m_clipToDrawRegion = clipToDrawRegion; m_forceUpdate = true;}
-  //! Request adjusting the worksheet size?
-  void AdjustWorksheetSize(bool adjust)
-    { m_adjustWorksheetSizeNeeded = adjust; }
-  bool AdjustWorksheetSize() const
-    { return m_adjustWorksheetSizeNeeded; }
   void SetVisibleRegion(wxRect visibleRegion){m_visibleRegion = visibleRegion;}
   wxRect GetVisibleRegion() const {return m_visibleRegion;}
   void SetWorksheetPosition(wxPoint worksheetPosition){m_worksheetPosition = worksheetPosition;}
   wxPoint GetWorksheetPosition() const {return m_worksheetPosition;}
   wxString MaximaShareDir() const {return m_maximaShareDir;}
-  void MaximaShareDir(wxString dir){m_maximaShareDir = dir;}
+  void MaximaShareDir(wxString dir){m_maximaShareDir = std::move(dir);}
   void InLispMode(bool lisp){m_inLispMode = lisp;}
   bool InLispMode() const {return m_inLispMode;}
   void BitmapScale(int factor){m_bitmapScale = factor;}
@@ -887,8 +877,17 @@ public:
   bool UsePartialForDiff() const {return m_usePartialForDiff;}
   void UsePartialForDiff(bool usePartialForDiff)
     {m_usePartialForDiff = usePartialForDiff;}
+  //! Record that this cell has been drawn to ReportMultipleRedraws()
   void NotifyOfCellRedraw(const Cell *cell);
+  //! Clear the memory of ReportMultipleRedraws()
   void ClearAndEnableRedrawTracing();
+  /*! Report if a cell has been redrawn 2 or more times during a simple Draw() command
+    
+    Only used in debug mode; If a cell is drawn and then re-drawn in the same draw
+    command this most likely means that a 2D-displayed cell draws its sub-cells,
+    but didn't remove them from the Cell::NextToDraw()-list of cells to draw
+    after this cell has been drawn.
+  */
   void ReportMultipleRedraws();
   //! If we decide that the HTML browser in the sidebar doesn't work for every platform...
   bool OfferInternalHelpBrowser() const;
@@ -914,7 +913,7 @@ public:
   long WizardTab() const {return m_wizardTab;}
 
   wxString TexPreamble() const {return m_texPreamble;}
-  void TexPreamble(wxString texPreamble) {m_texPreamble = texPreamble;}
+  void TexPreamble(wxString texPreamble) {m_texPreamble = std::move(texPreamble);}
 
   Style m_styles[NUMBEROFSTYLES];
   //! Initialize the text styles on construction.
@@ -923,18 +922,53 @@ public:
   bool FontRendersChar(wxChar ch, const wxFont &font = *wxNORMAL_FONT);
   wxTextCtrl *LastActiveTextCtrl() const { return m_lastActiveTextCtrl; }
   void LastActiveTextCtrl(wxTextCtrl *last);
+
+  //! Which styles affect how code is displayed?
+  const std::vector<TextStyle> &GetCodeStylesList() const {return m_codeStyles;}
+  //! Which styles affect how math output is displayed?
+  const std::vector<TextStyle> &GetMathStylesList() const {return m_2dMathStyles;}
+  //! Which styles affect only colors?
+  const std::vector<TextStyle> &GetColorOnlyStylesList() const {return m_colorOnlyStyles;}
+  bool StyleAffectsCode(TextStyle style) const;
+  bool StyleAffectsMathOut(TextStyle style) const;
+  bool StyleAffectsColorOnly(TextStyle style) const;
+  //! true means: The system's config storage has changed since the configuration has been read
+  bool UpdateNeeded() const;
+  //! Enable costly checks
+  static void SetDebugmode(){m_debugMode = true;}
+  //! Enable costly checks?
+  static bool GetDebugmode(){return m_debugMode;}
+
 private:
-  WX_DECLARE_STRING_HASH_MAP(wxString, RenderablecharsHash);
+  /*! The id of the current configuration
+
+    If the ID in the operating system's config storage differs from this one someone
+    has changed the configuration.
+  */
+  long m_configId;
+public:
+ //! Our random device
+  std::random_device m_rd;
+  //! Our random engine
+  std::default_random_engine m_eng;
+private:
+  //! Which styles affect how code is displayed?
+  std::vector<TextStyle> m_codeStyles;
+  //! Which styles affect how math output is displayed?
+  std::vector<TextStyle> m_2dMathStyles;
+  //! Which styles affect only colors?
+  std::vector<TextStyle> m_colorOnlyStyles;
+  std::list<FileToSave> m_filesToSave;
   RenderablecharsHash m_renderableChars;
   RenderablecharsHash m_nonRenderableChars;
   //! True if drawing the char this button displays alters at least one pixel
-  bool FontDisplaysChar(wxChar ch, const wxFont &font = *wxNORMAL_FONT);
+  static bool FontDisplaysChar(wxChar ch, const wxFont &font = *wxNORMAL_FONT);
   //! True if drawing the char this button displays differs visibly from otherChar
-  bool CharVisiblyDifferent(wxChar ch, wxChar otherChar, const wxFont &font = *wxNORMAL_FONT);
-  //! The ppi rate if we don't have a worksheet that provides a current ppi rate
-  wxSize m_ppi = wxSize(-1, -1);
+  static bool CharVisiblyDifferent(wxChar ch, wxChar otherChar, const wxFont &font = *wxNORMAL_FONT);
   mathDisplayMode m_displayMode = display_2d;
   using CellRedrawTrace = std::vector<const Cell*>;
+  static bool m_debugMode;
+  bool m_showInputLabels;
   long m_wizardTab;
   bool m_usePartialForDiff;
   bool m_maximaUsesHhtmlBrowser;
@@ -959,6 +993,8 @@ private:
   long m_autoSubscript;
   //! The worksheet this configuration storage is valid for
   wxWindow *m_workSheet = NULL;
+  //! A drawing context that knows the text sizes for the worksheet 
+  std::unique_ptr<wxClientDC> m_worksheetDC;
   /*! Do these chars exist in the given font?
 
     wxWidgets currently doesn't define such a function. But we can do the following:
@@ -987,6 +1023,10 @@ private:
   bool m_hideBrackets;
   //! The scale for printing
   double m_printScale;
+  double m_printMargin_Top;
+  double m_printMargin_Bot;
+  double m_printMargin_Left;
+  double m_printMargin_Right;
   //! The size of the canvas our cells have to be drawn on
   wxSize m_canvasSize;
   //! Show the cell brackets [displayed left to each group cell showing its extend]?
@@ -1021,21 +1061,16 @@ private:
   long m_labelWidth;
   long m_indent;
   bool m_latin2greek;
-  bool m_antiAliasLines;
   double m_zoomFactor;
   wxDC *m_dc;
-  wxDC *m_antialiassingDC;
   wxString m_maximaShareDir;
   bool m_forceUpdate;
   bool m_clipToDrawRegion = true;
   bool m_outdated;
   wxString m_maximaParameters;
-  bool m_TeXFonts;
   bool m_keepPercent;
   bool m_restartOnReEvaluation;
-  AFontName m_fontCMRI, m_fontCMSY, m_fontCMEX, m_fontCMMI, m_fontCMTI;
-  long m_clientWidth;
-  long m_clientHeight;
+  wxString m_fontCMRI, m_fontCMSY, m_fontCMEX, m_fontCMMI, m_fontCMTI;
   bool m_printing;
   long m_lineWidth_em;
   showLabels m_showLabelChoice;
@@ -1071,11 +1106,17 @@ private:
   bool m_cursorJump;
   bool m_numpadEnterEvaluates;
   bool m_saveImgFileName;
+  /*! A vector containing pointers to all cells the current draw command hit
+
+    Only used in debug mode. There it is used in order to determine if any
+    cell is drawn twice - which most likely means that a 2D-displayed cell
+    draws its sub-cells, but didn't remove them from the list of cells to draw
+    after this cell has been drawn.
+  */
   std::unique_ptr<CellRedrawTrace> m_cellRedrawTrace;
   wxString m_documentclass;
   wxString m_documentclassOptions;
   htmlExportFormat m_htmlEquationFormat;
-  bool m_adjustWorksheetSizeNeeded;
   //! The rectangle of the worksheet that is currently visible.
   wxRect m_visibleRegion;
   //! The position of the worksheet in the wxMaxima window
@@ -1098,7 +1139,7 @@ private:
   int m_maxClipbrd_BitmapMegabytes;
   int m_autoSaveMinutes;
   wxString m_wxMathML_Filename;
-  bool m_wxMathML_UseFile;
+
   wxTextCtrl *m_lastActiveTextCtrl = NULL;
 };
 
