@@ -44,42 +44,41 @@ Dirstructure::Dirstructure() {
   // The path Gentoo hides the manual at
   if (wxDirExists(m_helpDir + wxString::Format("/doc/wxmaxima-%s", GITVERSION)))
     m_helpDir += wxString::Format("/doc/wxmaxima-%s", GITVERSION);
-  if (wxDirExists(m_helpDir + wxT("/doc/wxmaxima")))
-    m_helpDir += wxT("/doc/wxmaxima");
+  if (wxDirExists(m_helpDir + wxS("/doc/wxmaxima")))
+    m_helpDir += wxS("/doc/wxmaxima");
 
-  if (wxDirExists(m_helpDir + wxT("/html")))
-    m_helpDir += wxT("/html");
+  if (wxDirExists(m_helpDir + wxS("/html")))
+    m_helpDir += wxS("/html");
 
-  if (wxDirExists(m_helpDir + wxT("/info")))
-    m_helpDir += wxT("/info");
+  if (wxDirExists(m_helpDir + wxS("/info")))
+    m_helpDir += wxS("/info");
 
-  if (wxDirExists(m_helpDir + wxT("/help")))
-    m_helpDir += wxT("/help");
+  if (wxDirExists(m_helpDir + wxS("/help")))
+    m_helpDir += wxS("/help");
 
-  if (!wxGetEnv(wxT("MAXIMA_USERDIR"), &m_userConfDir))
+  if (!wxGetEnv(wxS("MAXIMA_USERDIR"), &m_userConfDir))
     m_userConfDir = wxGetHomeDir();
   m_userConfDir += "/";
 
 #ifndef __WXMSW__
-  m_userConfDir += wxT(".");
+  m_userConfDir += wxS(".");
 #endif
 
-  m_userConfDir += wxT("maxima");
+  m_userConfDir += wxS("maxima");
 
   if (!wxDirExists(m_userConfDir)) {
     if (!wxMkdir(m_userConfDir, wxS_DIR_DEFAULT))
-      wxLogMessage(wxString::Format(
-				    _("Warning: Cannot create %s, the directory maxima keeps "
-				      "configuration, user packages and caches in.\n"
-				      "Make sure that your system's home directory "
-				      "is set up correctly"),
-				    m_userConfDir.utf8_str()));
+      wxLogMessage(_("Warning: Cannot create %s, the directory maxima keeps "
+		     "configuration, user packages and caches in.\n"
+		     "Make sure that your system's home directory "
+		     "is set up correctly"),
+	m_userConfDir.mb_str());
   }
   m_userConfDir += "/";
 }
 
 void Dirstructure::UserConfDir(wxString userConfDir) {
-  wxFileName dir(userConfDir + wxT("/"));
+  wxFileName dir(userConfDir + wxS("/"));
   dir.MakeAbsolute();
   m_userConfDir = dir.GetFullPath();
   if (!wxDirExists(m_userConfDir))
@@ -99,23 +98,23 @@ wxString Dirstructure::ResourcesDir() const {
     // If the binary is in a source or bin folder the resources dir is one level
     // above
     wxArrayString dirs = exe.GetDirs();
-    if ((dirs.Last().Upper() == wxT("SRC")) ||
-        (dirs.Last().Upper() == wxT("BIN"))) {
+    if ((dirs.Last().Upper() == wxS("SRC")) ||
+        (dirs.Last().Upper() == wxS("BIN"))) {
       exe.RemoveLastDir();
       dirs = exe.GetDirs();
     }
 
     // If the binary is in the wxMaxima folder the resources dir is two levels
     // above as we are in MacOS/wxmaxima
-    if ((dirs.Last().Upper() == wxT("MACOS")))
+    if ((dirs.Last().Upper() == wxS("MACOS")))
       exe.RemoveLastDir();
 
     // If there is a Resources folder the resources are there
-    if (wxDirExists(exe.GetPath() + wxT("/Resources")))
+    if (wxDirExists(exe.GetPath() + wxS("/Resources")))
       exe.AppendDir("Resources");
 
     // If there is a share folder the resources are there
-    if (wxDirExists(exe.GetPath() + wxT("/share")))
+    if (wxDirExists(exe.GetPath() + wxS("/share")))
       exe.AppendDir("share");
 
     exepath = exe.GetPath();
@@ -127,10 +126,10 @@ wxString Dirstructure::ResourcesDir() const {
 
 wxString Dirstructure::DataDir() const {
   wxString dir = ResourcesDir();
-  if (wxDirExists(dir + wxT("/data")))
-    dir += wxT("/data");
-  if (wxDirExists(dir + wxT("/wxMaxima")))
-    dir += wxT("/wxMaxima");
+  if (wxDirExists(dir + wxS("/data")))
+    dir += wxS("/data");
+  if (wxDirExists(dir + wxS("/wxMaxima")))
+    dir += wxS("/wxMaxima");
 
   return dir;
 }
@@ -143,6 +142,8 @@ wxString Dirstructure::MaximaDefaultLocation() {
 #if defined __WXMSW__ || defined __WXOSX__
   wxString notFound = _("Maxima not found as %s");
 #endif
+
+  // -------------------------- MS Windows only ------------------------
 #if defined __WXMSW__
   wxString exeDir = exe.GetPathWithSep();
   maxima = exeDir + "../bin/maxima.bat";
@@ -150,105 +151,108 @@ wxString Dirstructure::MaximaDefaultLocation() {
   if (wxFileExists(maximaLocation = maxima.GetFullPath()))
     return maximaLocation;
 
-  wxLogMessage(wxString::Format(notFound, maximaLocation.utf8_str()));
+  wxLogMessage(notFound, maximaLocation.mb_str());
   maxima = exeDir + "maxima.bat";
   maxima.MakeAbsolute();
   if (wxFileExists(maximaLocation = maxima.GetFullPath()))
     return maximaLocation;
 
-  wxLogMessage(wxString::Format(notFound, maximaLocation.utf8_str()));
+  wxLogMessage(notFound, maximaLocation.mb_str());
   maxima = exeDir + "bin/maxima.bat";
   maxima.MakeAbsolute();
   if (wxFileExists(maximaLocation = maxima.GetFullPath()))
     return maximaLocation;
 
-  wxLogMessage(wxString::Format(notFound, maximaLocation.utf8_str()));
+  wxLogMessage(notFound, maximaLocation.mb_str());
   maxima = exeDir + "../maxima.bat";
   maxima.MakeAbsolute();
   if (wxFileExists(maximaLocation = maxima.GetFullPath()))
     return maximaLocation;
 
-  wxLogMessage(wxString::Format(notFound, maximaLocation.utf8_str()));
+  wxLogMessage(notFound, maximaLocation.mb_str());
   maxima = exeDir + "maxima";
   maxima.MakeAbsolute();
   if (wxFileExists(maximaLocation = maxima.GetFullPath()))
     return maximaLocation;
 
-  wxLogMessage(wxString::Format(notFound, maximaLocation.utf8_str()));
+  wxLogMessage(notFound, maximaLocation.mb_str());
   maxima = exeDir + "bin/maxima";
   maxima.MakeAbsolute();
   if (wxFileExists(maximaLocation = maxima.GetFullPath()))
     return maximaLocation;
 
-  wxLogMessage(wxString::Format(notFound, maximaLocation.utf8_str()));
+  wxLogMessage(notFound, maximaLocation.mb_str());
   maxima = exeDir + "../maxima";
   maxima.MakeAbsolute();
   if (wxFileExists(maximaLocation = maxima.GetFullPath()))
     return maximaLocation;
 
-  wxLogMessage(wxString::Format(notFound, maximaLocation.utf8_str()));
+  wxLogMessage(notFound, maximaLocation.mb_str());
   maxima = exeDir + "../bin/maxima";
   maxima.MakeAbsolute();
   if (wxFileExists(maximaLocation = maxima.GetFullPath()))
     return maximaLocation;
 
-  wxLogMessage(wxString::Format(notFound, maximaLocation.utf8_str()));
+  wxLogMessage(notFound, maximaLocation.mb_str());
 #elif defined __WXOSX__
-  wxString exeDir = exe.GetPathWithSep();
-  maximaLocation = "/Applications/Maxima.app";
-  if (wxFileExists(maximaLocation))
-    return maximaLocation;
 
-  wxLogMessage(wxString::Format(notFound, maximaLocation.utf8_str()));
-  maximaLocation = "/Applications/maxima.app";
-  if (wxFileExists(maximaLocation))
-    return maximaLocation;
+  // -------------------------- Mac OS only ------------------------
 
   // The Macports path (if it is preferred over homebrew)
 #if OSX_MACPORTS_PREFER
-  wxLogMessage(wxString::Format(notFound, maximaLocation.utf8_str()));
   maximaLocation = OSX_MACPORTS_PREFIX "/bin/maxima";
   if (wxFileExists(maximaLocation))
     return maximaLocation;
+  wxLogMessage(notFound, maximaLocation.mb_str());
 #endif
 
   // The homebrew path
-  wxLogMessage(wxString::Format(notFound, maximaLocation.utf8_str()));
   maximaLocation = "/usr/local/bin/maxima";
   if (wxFileExists(maximaLocation))
     return maximaLocation;
 
   // The Macports path (if it is not preferred over homebrew)
 #if !OSX_MACPORTS_PREFER
-  wxLogMessage(wxString::Format(notFound, maximaLocation.utf8_str()));
+  wxLogMessage(notFound, maximaLocation.mb_str());
   maximaLocation = OSX_MACPORTS_PREFIX "/bin/maxima";
   if (wxFileExists(maximaLocation))
     return maximaLocation;
 #endif
 
-  wxLogMessage(wxString::Format(notFound, maximaLocation.utf8_str()));
+  wxLogMessage(notFound, maximaLocation.mb_str());
+  maximaLocation = "/Applications/Maxima.app";
+  if (wxFileExists(maximaLocation))
+    return maximaLocation;
+
+  wxLogMessage(notFound, maximaLocation.mb_str());
+  maximaLocation = "/Applications/maxima.app";
+  if (wxFileExists(maximaLocation))
+    return maximaLocation;
+
+  wxLogMessage(notFound, maximaLocation.mb_str());
   maximaLocation = "/usr/bin/maxima";
   if (wxFileExists(maximaLocation))
     return maximaLocation;
 
-  wxLogMessage(wxString::Format(notFound, maximaLocation.utf8_str()));
+  wxString exeDir = exe.GetPathWithSep();
+  wxLogMessage(notFound, maximaLocation.mb_str());
   maxima = exeDir + "maxima";
   maxima.MakeAbsolute();
   if (wxFileExists(maximaLocation = maxima.GetFullPath()))
     return maximaLocation;
 
-  wxLogMessage(wxString::Format(notFound, maximaLocation.utf8_str()));
+  wxLogMessage(notFound, maximaLocation.mb_str());
 #endif
-  return wxT("maxima");
+  return wxS("maxima");
 }
 
 wxString Dirstructure::UserAutocompleteFile() {
-  wxString newFileName = UserConfDir() + wxT("wxmaxima.ac");
+  wxString newFileName = UserConfDir() + wxS("wxmaxima.ac");
   if (!wxFileExists(newFileName)) {
-    wxString potentialOldFile = UserConfDir() + wxT(".wxmaxima.ac");
+    wxString potentialOldFile = UserConfDir() + wxS(".wxmaxima.ac");
     if (wxFileExists(potentialOldFile))
       wxRenameFile(potentialOldFile, newFileName);
-    potentialOldFile = UserConfDir() + wxT(".wxmax.ac");
+    potentialOldFile = UserConfDir() + wxS(".wxmax.ac");
     if (wxFileExists(potentialOldFile))
       wxRenameFile(potentialOldFile, newFileName);
   }
