@@ -84,7 +84,7 @@ void EvaluationQueue::AddToQueue(GroupCell *gr) {
  * Add the tree of hidden cells to the EQ by recursively adding cells'
  * hidden branches to the EQ.
  */
-void EvaluationQueue::AddHiddenTreeToQueue(GroupCell *gr) {
+void EvaluationQueue::AddHiddenTreeToQueue(const GroupCell *gr) {
   if (!gr)
     return; // caller should check, but just in case
 
@@ -111,15 +111,15 @@ void EvaluationQueue::RemoveFirst() {
   }
 }
 
-void EvaluationQueue::AddTokens(GroupCell *cell) {
+void EvaluationQueue::AddTokens(const GroupCell *cell) {
   if (cell == NULL)
     return;
   wxString token;
   int index = 0;
-  for (auto const &tok : cell->GetEditable()->GetTokens()) {
-    const TextStyle itemStyle = tok.GetStyle();
+  for (auto const &tok : cell->GetEditable()->GetAllTokens()) {
+    const TextStyle itemStyle = tok.GetTextStyle();
     wxString itemText = tok.GetText();
-    itemText.Replace(wxT("\u00a0"), " ");
+    itemText.Replace(wxS("\u00a0"), " ");
     index += itemText.Length();
     if (itemStyle != TS_CODE_COMMENT)
       token += itemText;
@@ -164,16 +164,16 @@ wxString EvaluationQueue::GetCommand() {
   m_userLabel.Clear();
   wxString userLabel;
 
-  int colonPos = retval.find(wxT(":"));
-  if (colonPos != wxNOT_FOUND && !retval.StartsWith(wxT(":lisp"))) {
+  int colonPos = retval.find(wxS(":"));
+  if (colonPos != wxNOT_FOUND && !retval.StartsWith(wxS(":lisp"))) {
     userLabel = retval.Left(colonPos);
     userLabel.Trim(true);
     userLabel.Trim(false);
     if (!userLabel.empty() &&
-        (wxIsalpha(userLabel[0]) || (userLabel[0] == wxT('\\')) ||
-         (userLabel[0] > 127) || (userLabel[0] == wxT('_')))) {
+        (wxIsalpha(userLabel[0]) || (userLabel[0] == wxS('\\')) ||
+         (userLabel[0] > 127) || (userLabel[0] == wxS('_')))) {
       for (size_t i = 0; i < userLabel.Length(); i++) {
-        if (userLabel[i] == wxT('\\'))
+        if (userLabel[i] == wxS('\\'))
           i++;
         else {
           if ((!wxIsalnum(userLabel[i])) && (userLabel[i] != '_') &&
