@@ -29,15 +29,20 @@
 #include "FindReplaceDialog.h"
 #include "EditorCell.h"
 
-FindReplaceDialog::FindReplaceDialog(wxWindow *parent, wxFindReplaceData *data,
-                                     const wxString &title, int style)
+FindReplaceDialog::FindReplaceDialog(wxWindow *parent,
+				     FindReplacePane::FindReplaceData *data,
+                                     const wxString &title,
+				     FindReplaceDialog **pointerToDialogue, int style)
   : wxDialog(parent, wxID_ANY, title, wxDefaultPosition, wxDefaultSize,
 	     style) {
+  m_pointerToDialogue = pointerToDialogue;
+  if(m_pointerToDialogue != NULL)
+    *m_pointerToDialogue = this;
   m_contents = new FindReplacePane(this, data);
   wxBoxSizer *vbox = new wxBoxSizer(wxVERTICAL);
   vbox->Add(m_contents, wxSizerFlags().Expand());
   SetSizerAndFit(vbox);
-
+  m_activateDuringConstruction = true;
   // Remember how wide the user wanted the dialogue to be the last time it was
   // used.
   if (m_windowPos != wxPoint(-1, -1))
@@ -48,8 +53,14 @@ FindReplaceDialog::FindReplaceDialog(wxWindow *parent, wxFindReplaceData *data,
           NULL, this);
   Connect(wxEVT_CHAR_HOOK, wxKeyEventHandler(FindReplaceDialog::OnKeyDown),
           NULL, this);
-  Connect(wxEVT_CLOSE_WINDOW, wxCloseEventHandler(FindReplaceDialog::OnClose),
-          NULL, this);
+}
+
+FindReplaceDialog::~FindReplaceDialog()
+{
+  if(m_pointerToDialogue)
+    {
+      *m_pointerToDialogue = NULL;
+    }
 }
 
 void FindReplaceDialog::OnKeyDown(wxKeyEvent &event) {
@@ -59,14 +70,13 @@ void FindReplaceDialog::OnKeyDown(wxKeyEvent &event) {
     event.Skip();
 }
 
-void FindReplaceDialog::OnClose(wxCloseEvent &WXUNUSED(event)) {
-  wxFindDialogEvent *findEvent = new wxFindDialogEvent(wxEVT_FIND_CLOSE);
-  GetParent()->GetEventHandler()->QueueEvent(findEvent);
-  m_windowSize = GetSize();
-  m_windowPos = GetPosition();
-}
-
 void FindReplaceDialog::OnActivate(wxActivateEvent &event) {
+  event.Skip();
+  if(m_activateDuringConstruction)
+    {
+      m_activateDuringConstruction = false;
+      return;
+    }
   if (event.GetActive())
     SetTransparent(255);
   else
