@@ -42,9 +42,20 @@
  */
 class FindReplacePane : public wxPanel
 {
+public:
+  class FindReplaceData: public wxFindReplaceData
+  {
+  public:
+    FindReplaceData();
+    bool GetRegexSearch() const {return m_regexSearch;}
+    void SetRegexSearch(bool regexSearch) {m_regexSearch = regexSearch;}
+  private:
+    bool m_regexSearch;
+  };
+
 private:
   //! The storage the search strings and settings are kept in
-  wxFindReplaceData *m_findReplaceData;
+  FindReplaceData *m_findReplaceData;
   //! Is this pane currently in focus?
   bool m_active;
   wxTextCtrl *m_searchText;
@@ -54,17 +65,22 @@ private:
   wxButton *m_replaceAllButton;
   wxRadioButton *m_forward;
   wxRadioButton *m_backwards;
+  wxRadioButton *m_regexSearch;
+  wxRadioButton *m_simpleSearch;
   wxCheckBox *m_matchCase;
-
+  //! true means: The next Activation event is generated during construction
+  bool m_activateDuringConstruction;
 public:
-  FindReplacePane(wxWindow *parent, wxFindReplaceData *data);
+  FindReplacePane(wxWindow *parent, FindReplaceData *data);
 
-  wxString GetFindString()
+  bool GetRegexSearch() const {return m_findReplaceData->GetRegexSearch();}
+  
+  wxString GetFindString() const
     { return m_findReplaceData->GetFindString(); }
 
   void SetFindString(wxString strng);
 
-  wxFindReplaceData *GetData()
+  wxFindReplaceData *GetData() const
     { return m_findReplaceData; }
 
 protected:
@@ -82,6 +98,8 @@ protected:
 
   void OnDirectionChange(wxCommandEvent &event);
 
+  void OnRegexSimpleChange(wxCommandEvent &event);
+
   void OnMatchCase(wxCommandEvent &event);
 
   void OnKeyDown(wxKeyEvent &event);
