@@ -55,8 +55,6 @@ History::History(wxWindow *parent, int id, Configuration *cfg)
   box->Add(m_history, wxSizerFlags(1).Expand());
   box->Add(m_regex, wxSizerFlags().Expand());
 
-  SetSizer(box);
-  FitInside();
   Connect(wxEVT_RIGHT_DOWN, wxMouseEventHandler(History::OnMouseRightDown),
           NULL, this);
   m_history->Connect(wxEVT_RIGHT_DOWN,
@@ -65,6 +63,8 @@ History::History(wxWindow *parent, int id, Configuration *cfg)
   Connect(wxEVT_MENU, wxCommandEventHandler(History::OnMenu), NULL, this);
   m_regex->Connect(REGEX_EVENT, wxCommandEventHandler(History::OnRegExEvent),
                    NULL, this);
+  SetSizer(box);
+  FitInside();
 }
 
 void History::OnMouseRightDown(wxMouseEvent &WXUNUSED(event)) {
@@ -100,7 +100,7 @@ void History::OnMouseRightDown(wxMouseEvent &WXUNUSED(event)) {
 
 void History::MaximaSessionStart() {
   if (m_commands.size() != 0)
-    AddToHistory(wxT("quit();"));
+    AddToHistory(wxS("quit();"));
   m_sessionCommands = 0;
   if (m_showCurrentSessionOnly)
     m_history->Clear();
@@ -217,9 +217,9 @@ void History::AddToHistory(const wxString &cmd) {
 }
 
 void History::RebuildDisplay() {
-  wxWindowUpdateLocker speedUp(this);
+  //  wxWindowUpdateLocker speedUp(this);
   wxArrayString display;
-  std::vector<wxString>::reverse_iterator sessionEnd;
+  std::vector<wxString>::const_reverse_iterator sessionEnd;
   if (m_showCurrentSessionOnly)
     sessionEnd = m_commands.rbegin() + m_sessionCommands;
   else
@@ -272,4 +272,4 @@ void History::SetCurrent(long current) {
 }
 
 wxString
-History::m_showCurrentSessionOnlyKey(wxT("history/ShowCurrentSessionOnly"));
+History::m_showCurrentSessionOnlyKey(wxS("history/ShowCurrentSessionOnly"));
