@@ -29,6 +29,7 @@
 #include "Cell.h"
 #include "Version.h"
 #include <wx/image.h>
+#include <wx/rawbmp.h>
 
 #include <wx/filesys.h>
 #include <wx/fs_arc.h>
@@ -95,7 +96,10 @@ Image::Image(Configuration *config, wxMemoryBuffer image, wxString type) {
   if (m_compressedImage.GetDataLen() > 0) {
     wxMemoryInputStream istream(m_compressedImage.GetData(),
                                 m_compressedImage.GetDataLen());
-    Image.LoadFile(istream);
+    {
+      SuppressErrorDialogs logNull;
+      Image.LoadFile(istream);
+    }
     m_isOk = Image.IsOk();
     m_originalWidth = Image.GetWidth();
     m_originalHeight = Image.GetHeight();
@@ -123,8 +127,8 @@ Image::Image(Configuration *config, const wxBitmap &bitmap) {
 // pointer to the file system alive in a background task
 // cppcheck-suppress performance symbolName=filesystem
 Image::Image(Configuration *config, wxString image,
-             std::shared_ptr<wxFileSystem> filesystem, bool remove)
-  : m_fs_keepalive_imagedata(filesystem) {
+             std::shared_ptr<wxFileSystem> &filesystem, bool remove)
+{
   m_svgImage = NULL;
   m_configuration = config;
   m_scaledBitmap.Create(1, 1);
@@ -135,7 +139,7 @@ Image::Image(Configuration *config, wxString image,
   m_maxHeight = -1;
   m_originalWidth = 640;
   m_originalHeight = 480;
-  m_ppi = m_configuration->GetDC()->GetPPI().x;
+  m_ppi = m_configuration->GetPPI().x;
   LoadImage(image, filesystem, remove);
 }
 
@@ -156,26 +160,38 @@ Image::Image(Configuration *config, const Image &image) {
 }
 
 Image::~Image() {
+  if(m_loadImageTask.joinable())
+    m_loadImageTask.join();
+  if(m_loadGnuplotSourceTask.joinable())
+    m_loadGnuplotSourceTask.join();
   m_isOk = false;
   if (!m_gnuplotSource.IsEmpty()) {
     SuppressErrorDialogs logNull;
-    wxLogMessage(wxString::Format(_("Trying to delete gnuplot file %s"),
-                                  m_gnuplotSource.utf8_str()));
     if (wxFileExists(m_gnuplotSource))
-      wxRemoveFile(m_gnuplotSource);
-    wxString popoutname = m_gnuplotSource + wxT(".popout");
-    wxLogMessage(wxString::Format(_("Trying to delete gnuplot file %s"),
-                                  popoutname.utf8_str()));
+    {
+      if(!wxRemoveFile(m_gnuplotSource))
+        wxLogMessage(_("Failed to delete gnuplot file %s"),
+                     m_gnuplotSource.utf8_str());
+    }
+    wxString popoutname = m_gnuplotSource + wxS(".popout");
     if (wxFileExists(popoutname))
-      wxRemoveFile(popoutname);
+    {
+      if(!wxRemoveFile(popoutname))
+        wxLogMessage(_("Failed to delete gnuplot file %s"),
+                     popoutname.utf8_str());
+
+    }
   }
 
   if (!m_gnuplotData.IsEmpty()) {
     SuppressErrorDialogs logNull;
-    wxLogMessage(wxString::Format(_("Trying to delete gnuplot file %s"),
-                                  m_gnuplotData.utf8_str()));
     if (wxFileExists(m_gnuplotData))
-      wxRemoveFile(m_gnuplotData);
+    {
+      if(!wxRemoveFile(m_gnuplotData))
+        wxLogMessage(_("Failed to delete gnuplot data file %s"),
+                     m_gnuplotData.utf8_str());
+
+    }
   }
   if (m_svgImage)
     free(m_svgImage);
@@ -194,6 +210,8 @@ wxMemoryBuffer Image::ReadCompressedImage(wxInputStream *data) {
 }
 
 wxBitmap Image::GetUnscaledBitmap() {
+  if(m_loadImageTask.joinable())
+    m_loadImageTask.join();
   if (!m_isOk) {
     InvalidBitmap();
     return m_scaledBitmap;
@@ -205,7 +223,7 @@ wxBitmap Image::GetUnscaledBitmap() {
 
     nsvgRasterize(m_svgRast.get(), m_svgImage, 0, 0, 1, imgdata.data(),
                   m_originalWidth, m_originalHeight, m_originalWidth * 4);
-    return SvgBitmap::RGBA2wxBitmap(imgdata.data(), m_originalWidth,
+    return RGBA2wxBitmap(imgdata.data(), m_originalWidth,
                                     m_originalHeight);
   } else {
     wxMemoryInputStream istream(m_compressedImage.GetData(),
@@ -218,236 +236,223 @@ wxBitmap Image::GetUnscaledBitmap() {
   }
 }
 
-const wxMemoryBuffer Image::GetCompressedImage() const { return m_compressedImage; }
+const wxMemoryBuffer Image::GetCompressedImage() const {
+  if(m_loadImageTask.joinable())
+    m_loadImageTask.join();
+  return m_compressedImage;
+}
 
-size_t Image::GetOriginalWidth() const { return m_originalWidth; }
+size_t Image::GetOriginalWidth() const {
+  if(m_loadImageTask.joinable())
+    m_loadImageTask.join();
+  
+  return m_originalWidth;
+}
 
-size_t Image::GetOriginalHeight() const { return m_originalHeight; }
+size_t Image::GetOriginalHeight() const {
+    if(m_loadImageTask.joinable())
+    m_loadImageTask.join();
 
-bool Image::IsOk() const { return m_isOk; }
+    return m_originalHeight;
+}
+
+bool Image::IsOk() const {
+    if(m_loadImageTask.joinable())
+    m_loadImageTask.join();
+return m_isOk;
+}
 
 // filesystem cannot be passed by const reference as we want to keep the
 // pointer to the file system alive in a background task
 // cppcheck-suppress performance symbolName=filesystem
 void Image::GnuplotSource(wxString gnuplotFilename, wxString dataFilename,
-                          std::shared_ptr<wxFileSystem> filesystem) {
-  m_fs_keepalive_gnuplotdata = filesystem;
-  LoadGnuplotSource_Backgroundtask(gnuplotFilename, dataFilename, filesystem);
+                          std::shared_ptr<wxFileSystem> &filesystem) {
+  SuppressErrorDialogs suppressor;
+  if(m_loadGnuplotSourceTask.joinable())
+    m_loadGnuplotSourceTask.join();
+  m_gnuplotSource = std::move(gnuplotFilename);
+  m_gnuplotData = std::move(dataFilename);
+  std::unique_ptr<ThreadNumberLimiter> limiter(new
+                                               ThreadNumberLimiter(&m_gnuplotDataThreadRunning));
+  if (filesystem == NULL) {
+    m_loadGnuplotSourceTask = std::thread(&Image::LoadGnuplotSource_Backgroundtask2,
+                                          this,
+                                          std::move(limiter),
+                                          m_gnuplotSource, m_gnuplotData);
+  }
+  else {
+    std::unique_ptr<wxFSFile> sourcefile(filesystem->OpenFile(m_gnuplotSource));
+    std::shared_ptr<wxInputStream> source;
+    if (sourcefile)
+      source = std::shared_ptr<wxInputStream> (sourcefile->DetachStream());
+    std::unique_ptr<wxFSFile> datafile(filesystem->OpenFile(m_gnuplotData));
+    std::shared_ptr<wxInputStream> data;
+    if (datafile)
+      data = std::shared_ptr<wxInputStream> (datafile->DetachStream());
+    m_loadGnuplotSourceTask = std::thread(&Image::LoadGnuplotSource_Backgroundtask1,
+                                          this,
+                                          std::move(limiter),
+                                          filesystem, source, data);
+  } 
 }
 
 void Image::CompressedGnuplotSource(wxString gnuplotFilename, wxString dataFilename,
-                                    std::shared_ptr<wxFileSystem> filesystem) {
-  m_fs_keepalive_gnuplotdata = filesystem;
-  LoadCompressedGnuplotSource_Backgroundtask(gnuplotFilename, dataFilename, filesystem);
-}
+                                    std::shared_ptr<wxFileSystem> &filesystem) {
+  if(m_loadGnuplotSourceTask.joinable())
+    m_loadGnuplotSourceTask.join();
+  std::unique_ptr<ThreadNumberLimiter> limiter(new
+                                               ThreadNumberLimiter(&m_gnuplotDataThreadRunning)); 
 
-void Image::LoadGnuplotSource_Backgroundtask(
-					     wxString gnuplotFilename, wxString dataFilename,
-					     std::shared_ptr<wxFileSystem> filesystem) {
-  // Error dialogues need to be created by the foreground thread.
-  SuppressErrorDialogs suppressor;
-
-  m_gnuplotSource = gnuplotFilename;
-  m_gnuplotData = dataFilename;
-
-  if (filesystem == NULL) {
-    if (wxFileExists(dataFilename)) {
-      // Don't cache the data for unreasonably long files.
-      wxStructStat strucStat;
-      wxStat(dataFilename, &strucStat);
-      if (strucStat.st_size >
-          m_configuration->MaxGnuplotMegabytes() * 1000 * 1000) {
-        wxLogMessage(
-		     _("Too much gnuplot data => Not storing it in the worksheet"));
-        m_gnuplotData_Compressed.Clear();
-        return;
-      }
-
-      // The gnuplot source of the image is cached in a compressed form:
-      //
-      // as it is text-only and contains many redundancies it will get way
-      // smaller this way.
-      {
-        wxFileInputStream input(m_gnuplotSource);
-        if (input.IsOk()) {
-          wxTextInputStream textIn(input, wxT('\t'),
-                                   wxConvAuto(wxFONTENCODING_UTF8));
-
-          wxMemoryOutputStream mstream;
-          int zlib_flags;
-          if (wxZlibOutputStream::CanHandleGZip())
-            zlib_flags = wxZLIB_GZIP;
-          else
-            zlib_flags = wxZLIB_ZLIB;
-          wxZlibOutputStream zstream(mstream, wxZ_BEST_COMPRESSION, zlib_flags);
-          wxTextOutputStream textOut(zstream);
-          wxString line;
-
-          // A RegEx that matches the name of the data file (needed if we ever
-          // want to move a data file into the temp directory of a new computer
-          // that locates its temp data somewhere strange).
-          wxRegEx replaceDataFileName("'[^']*maxout_[^']*_[0-9]*\\.data'");
-          while (!input.Eof()) {
-            line = textIn.ReadLine();
-            if (replaceDataFileName.Matches(line)) {
-              wxString dataFileName;
-              dataFileName = replaceDataFileName.GetMatch(line);
-              replaceDataFileName.Replace(&line, wxT("'<DATAFILENAME>'"));
-            }
-            textOut << line + wxT("\n");
-          }
-          textOut.Flush();
-          zstream.Close();
-
-          m_gnuplotSource_Compressed.Clear();
-          m_gnuplotSource_Compressed.AppendData(
-						mstream.GetOutputStreamBuffer()->GetBufferStart(),
-						mstream.GetOutputStreamBuffer()->GetBufferSize());
-        }
-
-        {
-          wxFileInputStream input2(m_gnuplotData);
-          if (input2.IsOk()) {
-            wxTextInputStream textIn(input2, wxT('\t'),
-                                     wxConvAuto(wxFONTENCODING_UTF8));
-
-            wxMemoryOutputStream mstream;
-            int zlib_flags;
-            if (wxZlibOutputStream::CanHandleGZip())
-              zlib_flags = wxZLIB_GZIP;
-            else
-              zlib_flags = wxZLIB_ZLIB;
-            wxZlibOutputStream zstream(mstream, wxZ_BEST_COMPRESSION,
-                                       zlib_flags);
-            wxTextOutputStream textOut(zstream);
-            wxString line;
-
-            while (!input2.Eof()) {
-              line = textIn.ReadLine();
-              textOut << line + wxT("\n");
-            }
-            textOut.Flush();
-            zstream.Close();
-
-            m_gnuplotData_Compressed.Clear();
-            m_gnuplotData_Compressed.AppendData(
-						mstream.GetOutputStreamBuffer()->GetBufferStart(),
-						mstream.GetOutputStreamBuffer()->GetBufferSize());
-          }
-        }
-      }
-    }
-  } else {
-    {
-      wxFSFile *fsfile;
-      fsfile = filesystem->OpenFile(m_gnuplotSource);
-      if (fsfile) { // open successful
-        std::unique_ptr<wxInputStream> input(fsfile->GetStream());
-        if (input->IsOk()) {
-          wxTextInputStream textIn(*input, wxT('\t'),
-                                   wxConvAuto(wxFONTENCODING_UTF8));
-
-          wxMemoryOutputStream mstream;
-          int zlib_flags;
-          if (wxZlibOutputStream::CanHandleGZip())
-            zlib_flags = wxZLIB_GZIP;
-          else
-            zlib_flags = wxZLIB_ZLIB;
-          if (!input->Eof()) {
-            wxZlibOutputStream zstream(mstream, wxZ_BEST_COMPRESSION,
-                                       zlib_flags);
-            if (zstream.IsOk()) {
-              wxTextOutputStream textOut(zstream);
-              wxString line;
-
-              // A RegEx that matches the name of the data file (needed if we
-              // ever want to move a data file into the temp directory of a new
-              // computer that locates its temp data somewhere strange).
-              wxRegEx replaceDataFileName("'[^']*maxout_[^']*_[0-9*]\\.data'");
-              while (!input->Eof()) {
-                line = textIn.ReadLine();
-                if (replaceDataFileName.Matches(line)) {
-                  wxString dataFileName;
-                  dataFileName = replaceDataFileName.GetMatch(line);
-                  if (dataFileName != wxEmptyString)
-                    wxLogMessage(_("Gnuplot Data File Name: ") + dataFileName);
-                  replaceDataFileName.Replace(&line, wxT("'<DATAFILENAME>'"));
-                }
-                textOut << line + wxT("\n");
-              }
-              textOut.Flush();
-              zstream.Close();
-              m_gnuplotSource_Compressed.Clear();
-              m_gnuplotSource_Compressed.AppendData(
-						    mstream.GetOutputStreamBuffer()->GetBufferStart(),
-						    mstream.GetOutputStreamBuffer()->GetBufferSize());
-            }
-          }
-        }
-      }
-    }
-    {
-      wxFSFile *fsfile;
-      fsfile = filesystem->OpenFile(m_gnuplotData);
-      if (fsfile) { // open successful
-        wxInputStream *input = fsfile->GetStream();
-        if (input->IsOk()) {
-          wxTextInputStream textIn(*input, wxT('\t'),
-                                   wxConvAuto(wxFONTENCODING_UTF8));
-
-          wxMemoryOutputStream mstream;
-          int zlib_flags;
-          if (wxZlibOutputStream::CanHandleGZip())
-            zlib_flags = wxZLIB_GZIP;
-          else
-            zlib_flags = wxZLIB_ZLIB;
-          if (!input->Eof()) {
-            wxZlibOutputStream zstream(mstream, wxZ_BEST_COMPRESSION,
-                                       zlib_flags);
-            if (zstream.IsOk()) {
-              wxTextOutputStream textOut(zstream);
-              wxString line;
-
-              while (!input->Eof()) {
-                line = textIn.ReadLine();
-                textOut << line + wxT("\n");
-              }
-              textOut.Flush();
-              zstream.Close();
-
-              m_gnuplotData_Compressed.Clear();
-              m_gnuplotData_Compressed.AppendData(
-						  mstream.GetOutputStreamBuffer()->GetBufferStart(),
-						  mstream.GetOutputStreamBuffer()->GetBufferSize());
-            }
-          }
-        }
-      }
-    }
-  }
-  m_fs_keepalive_gnuplotdata.reset();
-}
-
-void Image::LoadCompressedGnuplotSource_Backgroundtask(
-  wxString gnuplotFilename, wxString dataFilename,
-  std::shared_ptr<wxFileSystem> filesystem) {
-  // Error dialogues need to be created by the foreground thread.
-  SuppressErrorDialogs suppressor;
-
-  // Store the filenames without the ".gz".
-  m_gnuplotSource = gnuplotFilename;
-  m_gnuplotData = dataFilename;
+    // Store the filenames without the ".gz".
+  m_gnuplotSource = std::move(gnuplotFilename);
+  m_gnuplotData = std::move(dataFilename);
   if(m_gnuplotSource.EndsWith(".gz"))
     m_gnuplotSource = m_gnuplotSource.Left(m_gnuplotSource.Length()-3);
   if(m_gnuplotData.EndsWith(".gz"))
     m_gnuplotData = m_gnuplotData.Left(m_gnuplotData.Length()-3);
 
+  
+  m_loadGnuplotSourceTask =
+    std::thread(&Image::LoadCompressedGnuplotSource_Backgroundtask,
+                this,
+                std::move(limiter),
+                filesystem,
+                std::shared_ptr<wxFSFile>(filesystem->OpenFile(m_gnuplotSource)),
+                std::shared_ptr<wxFSFile>(filesystem->OpenFile(m_gnuplotData)));
+}
+
+void Image::LoadGnuplotSource_Backgroundtask2(
+  std::unique_ptr<ThreadNumberLimiter> limiter,
+  wxString gnuplotFile,
+  wxString dataFile
+  ) {
+  // Error dialogues need to be created by the foreground thread.
+  SuppressErrorDialogs suppressor;
+  
+    if (wxFileExists(dataFile)) {
+      // Don't cache the data for unreasonably long files.
+      wxStructStat strucStat;
+      if(wxStat(dataFile, &strucStat) == 0)
+      {
+        if (strucStat.st_size >
+            m_configuration->MaxGnuplotMegabytes() * 1000 * 1000) {
+          wxLogMessage(_("Too much gnuplot data => Not storing it in the worksheet"));
+          m_gnuplotData_Compressed.Clear();
+          return;
+        }
+      }
+
+      wxFileInputStream source(gnuplotFile);
+      wxFileInputStream data(dataFile);
+      
+      LoadGnuplotSource_Backgroundtask(&source, &data);
+    }
+}
+
+void Image::LoadGnuplotSource_Backgroundtask(
+  wxInputStream *source,
+  wxInputStream *data)
+{
+  // The gnuplot source of the image is cached in a compressed form:
+  //
+  // as it is text-only and contains many redundancies it will get way
+  // smaller this way.
+  {
+    if (source->IsOk()) {
+      wxTextInputStream textIn(*source, wxS('\t'),
+                               wxConvAuto(wxFONTENCODING_UTF8));
+
+      wxMemoryOutputStream mstream;
+      int zlib_flags;
+      if (wxZlibOutputStream::CanHandleGZip())
+        zlib_flags = wxZLIB_GZIP;
+      else
+        zlib_flags = wxZLIB_ZLIB;
+      wxZlibOutputStream zstream(mstream, wxZ_BEST_COMPRESSION, zlib_flags);
+      wxTextOutputStream textOut(zstream);
+      wxString line;
+
+      // A RegEx that matches the name of the data file (needed if we ever
+      // want to move a data file into the temp directory of a new computer
+      // that locates its temp data somewhere strange).
+      wxRegEx replaceDataFileName("'[^']*maxout_[^']*_[0-9]*\\.data'");
+      while (!source->Eof()) {
+        line = textIn.ReadLine();
+        if (replaceDataFileName.Matches(line)) {
+          wxString dataFileName;
+          dataFileName = replaceDataFileName.GetMatch(line);
+          replaceDataFileName.Replace(&line, wxS("'<DATAFILENAME>'"));
+        }
+        textOut << line + wxS("\n");
+      }
+      textOut.Flush();
+      zstream.Close();
+
+      m_gnuplotSource_Compressed.Clear();
+      m_gnuplotSource_Compressed.AppendData(
+        mstream.GetOutputStreamBuffer()->GetBufferStart(),
+        mstream.GetOutputStreamBuffer()->GetBufferSize());
+    }
+
+    {
+      if (data->IsOk()) {
+        wxTextInputStream textIn(*data, wxS('\t'),
+                                 wxConvAuto(wxFONTENCODING_UTF8));
+
+        wxMemoryOutputStream mstream;
+        int zlib_flags;
+        if (wxZlibOutputStream::CanHandleGZip())
+          zlib_flags = wxZLIB_GZIP;
+        else
+          zlib_flags = wxZLIB_ZLIB;
+        wxZlibOutputStream zstream(mstream, wxZ_BEST_COMPRESSION,
+                                   zlib_flags);
+        wxTextOutputStream textOut(zstream);
+        wxString line;
+
+        while (!data->Eof()) {
+          line = textIn.ReadLine();
+          textOut << line + wxS("\n");
+        }
+        textOut.Flush();
+        zstream.Close();
+
+        m_gnuplotData_Compressed.Clear();
+        m_gnuplotData_Compressed.AppendData(
+          mstream.GetOutputStreamBuffer()->GetBufferStart(),
+          mstream.GetOutputStreamBuffer()->GetBufferSize());
+      }
+    }
+  }
+}
+
+void Image::LoadGnuplotSource_Backgroundtask1(
+  std::unique_ptr<ThreadNumberLimiter> limiter,
+  std::shared_ptr<wxFileSystem> filesystem,
+  std::shared_ptr<wxInputStream> gnuplotFile,
+  std::shared_ptr<wxInputStream> dataFile
+  ) {
+  // Error dialogues need to be created by the foreground thread.
+  SuppressErrorDialogs suppressor;
+  wxFileInputStream source(m_gnuplotSource);
+  wxFileInputStream data(m_gnuplotData);
+  
+  LoadGnuplotSource_Backgroundtask(&source, &data);
+}
+
+void Image::LoadCompressedGnuplotSource_Backgroundtask(
+  std::unique_ptr<ThreadNumberLimiter> limiter,
+  std::shared_ptr<wxFileSystem> filesystem,
+  std::shared_ptr<wxFSFile> sourcefile,
+  std::shared_ptr<wxFSFile> datafile) {
+
+  // Error dialogues need to be created by the foreground thread.
+  SuppressErrorDialogs suppressor;
+
   // Read the gnuplot source
   {
-    wxFSFile *fsfile;
-    fsfile = filesystem->OpenFile(gnuplotFilename);
-    if (fsfile) { // open successful
-      std::unique_ptr<wxInputStream> input(fsfile->GetStream());
+    if(sourcefile) { // open successful
+      std::unique_ptr<wxInputStream> input(sourcefile->DetachStream());
       if (input->IsOk()) {
         m_gnuplotSource_Compressed.Clear();
         wxMemoryOutputStream mstream;
@@ -460,10 +465,8 @@ void Image::LoadCompressedGnuplotSource_Backgroundtask(
   }
   // Read the gnuplot data
   {
-    wxFSFile *fsfile;
-    fsfile = filesystem->OpenFile(dataFilename);
-    if (fsfile) { // open successful
-      std::unique_ptr<wxInputStream> input(fsfile->GetStream());
+    if (datafile) { // open successful
+      std::unique_ptr<wxInputStream> input(datafile->DetachStream());
       if (input->IsOk()) {
         m_gnuplotData_Compressed.Clear();
         wxMemoryOutputStream mstream;
@@ -474,10 +477,12 @@ void Image::LoadCompressedGnuplotSource_Backgroundtask(
       }
     }
   }
-  m_fs_keepalive_gnuplotdata.reset();
 }
 
-const wxMemoryBuffer Image::GetGnuplotSource() const {
+const wxMemoryBuffer Image::GetGnuplotSource() {
+  if(m_loadGnuplotSourceTask.joinable())
+    m_loadGnuplotSourceTask.join();
+
   wxMemoryBuffer retval;
   if ((m_gnuplotSource_Compressed.GetDataLen() < 2) ||
       (m_gnuplotData_Compressed.GetDataLen() < 2)) {
@@ -494,7 +499,7 @@ const wxMemoryBuffer Image::GetGnuplotSource() const {
 
     while (!zstream.Eof()) {
       line = textIn.ReadLine();
-      textOut << line + wxT("\n");
+      textOut << line + wxS("\n");
     }
     textOut.Flush();
 
@@ -505,17 +510,23 @@ const wxMemoryBuffer Image::GetGnuplotSource() const {
   return retval;
 }
 
-const wxMemoryBuffer Image::GetCompressedGnuplotSource() const
+const wxMemoryBuffer Image::GetCompressedGnuplotSource()
 {
+  if(m_loadGnuplotSourceTask.joinable())
+    m_loadGnuplotSourceTask.join();
   return m_gnuplotSource_Compressed;
 }
 
-const wxMemoryBuffer Image::GetCompressedGnuplotData() const
+const wxMemoryBuffer Image::GetCompressedGnuplotData()
 {
+  if(m_loadGnuplotSourceTask.joinable())
+    m_loadGnuplotSourceTask.join();
   return m_gnuplotData_Compressed;
 }
 
-const wxMemoryBuffer Image::GetGnuplotData() const {
+const wxMemoryBuffer Image::GetGnuplotData() {
+  if(m_loadGnuplotSourceTask.joinable())
+    m_loadGnuplotSourceTask.join();
   wxMemoryBuffer retval;
   if ((m_gnuplotSource_Compressed.GetDataLen() < 2) ||
       (m_gnuplotData_Compressed.GetDataLen() < 2)) {
@@ -533,7 +544,7 @@ const wxMemoryBuffer Image::GetGnuplotData() const {
 
     while (!zstream.Eof()) {
       line = textIn.ReadLine();
-      textOut << line + wxT("\n");
+      textOut << line + wxS("\n");
     }
     textOut.Flush();
 
@@ -544,6 +555,8 @@ const wxMemoryBuffer Image::GetGnuplotData() const {
 }
 
 wxString Image::GnuplotData() {
+  if(m_loadGnuplotSourceTask.joinable())
+    m_loadGnuplotSourceTask.join();
   if ((!m_gnuplotData.IsEmpty()) && (!wxFileExists(m_gnuplotData))) {
     // Move the gnuplot data and data file into our temp directory
     wxFileName gnuplotSourceFile(m_gnuplotSource);
@@ -568,7 +581,7 @@ wxString Image::GnuplotData() {
 
       while (!zstream.Eof()) {
         line = textIn.ReadLine();
-        textOut << line + wxT("\n");
+        textOut << line + wxS("\n");
       }
       textOut.Flush();
     }
@@ -577,6 +590,8 @@ wxString Image::GnuplotData() {
 }
 
 wxString Image::GnuplotSource() {
+  if(m_loadGnuplotSourceTask.joinable())
+    m_loadGnuplotSourceTask.join();
   if ((!m_gnuplotSource.IsEmpty()) && (!wxFileExists(m_gnuplotSource))) {
     // Move the gnuplot source and data file into our temp directory
     wxFileName gnuplotSourceFile(m_gnuplotSource);
@@ -602,9 +617,9 @@ wxString Image::GnuplotSource() {
 
         while (!zstream.Eof()) {
           line = textIn.ReadLine();
-          line.Replace(wxT("'<DATAFILENAME>'"),
-                       wxT("'") + m_gnuplotData + wxT("'"));
-          textOut << line + wxT("\n");
+          line.Replace(wxS("'<DATAFILENAME>'"),
+                       wxS("'") + m_gnuplotData + wxS("'"));
+          textOut << line + wxS("\n");
         }
         textOut.Flush();
       }
@@ -616,6 +631,8 @@ wxString Image::GnuplotSource() {
 }
 
 wxSize Image::ToImageFile(wxString filename) {
+  if(m_loadImageTask.joinable())
+    m_loadImageTask.join();
   wxFileName fn(filename);
   wxString ext = fn.GetExt();
   if (filename.Lower().EndsWith(GetExtension().Lower())) {
@@ -642,7 +659,7 @@ wxSize Image::ToImageFile(wxString filename) {
     wxString line;
     while (!zstream.Eof()) {
       line = textIn.ReadLine();
-      svgContents_string += line + wxT("\n");
+      svgContents_string += line + wxS("\n");
     }
     wxFile file(filename, wxFile::write);
     if (!file.IsOpened())
@@ -658,21 +675,21 @@ wxSize Image::ToImageFile(wxString filename) {
     wxBitmap bitmap = GetUnscaledBitmap();
     wxImage image = bitmap.ConvertToImage();
     wxBitmapType mimetype = wxBITMAP_TYPE_ANY;
-    if ((ext.Lower() == wxT("jpg")) || (ext.Lower() == wxT("jpeg")))
+    if ((ext.Lower() == wxS("jpg")) || (ext.Lower() == wxS("jpeg")))
       mimetype = wxBITMAP_TYPE_JPEG;
-    else if (ext.Lower() == wxT("png"))
+    else if (ext.Lower() == wxS("png"))
       mimetype = wxBITMAP_TYPE_PNG;
-    else if (ext.Lower() == wxT("pcx"))
+    else if (ext.Lower() == wxS("pcx"))
       mimetype = wxBITMAP_TYPE_PCX;
-    else if (ext.Lower() == wxT("pnm"))
+    else if (ext.Lower() == wxS("pnm"))
       mimetype = wxBITMAP_TYPE_PNM;
-    else if ((ext.Lower() == wxT("tif")) || (ext.Lower() == wxT("tiff")))
+    else if ((ext.Lower() == wxS("tif")) || (ext.Lower() == wxS("tiff")))
       mimetype = wxBITMAP_TYPE_TIFF;
-    else if (ext.Lower() == wxT("xpm"))
+    else if (ext.Lower() == wxS("xpm"))
       mimetype = wxBITMAP_TYPE_XPM;
-    else if (ext.Lower() == wxT("ico"))
+    else if (ext.Lower() == wxS("ico"))
       mimetype = wxBITMAP_TYPE_ICO;
-    else if (ext.Lower() == wxT("cur"))
+    else if (ext.Lower() == wxS("cur"))
       mimetype = wxBITMAP_TYPE_CUR;
     else
       return (wxSize(-1, -1));
@@ -684,6 +701,8 @@ wxSize Image::ToImageFile(wxString filename) {
 }
 
 wxBitmap Image::GetBitmap(double scale) {
+  if(m_loadImageTask.joinable())
+    m_loadImageTask.join();
   // Recalculate contains its own WaitForLoad object.
   Recalculate(scale);
 
@@ -706,7 +725,7 @@ wxBitmap Image::GetBitmap(double scale) {
                   imgdata.data(),
                   m_width, m_height, m_width * 4);
     return m_scaledBitmap =
-      SvgBitmap::RGBA2wxBitmap(imgdata.data(), m_width, m_height);
+      RGBA2wxBitmap(imgdata.data(), m_width, m_height);
   } else {
     wxImage img;
     if (m_compressedImage.GetDataLen() > 0) {
@@ -768,6 +787,8 @@ void Image::InvalidBitmap() {
 }
 
 void Image::LoadImage(const wxBitmap &bitmap) {
+  if(m_loadImageTask.joinable())
+    m_loadImageTask.join();
   // Convert the bitmap to a png image we can use as m_compressedImage
   wxImage image = bitmap.ConvertToImage();
   m_isOk = image.IsOk();
@@ -777,7 +798,7 @@ void Image::LoadImage(const wxBitmap &bitmap) {
                                stream.GetOutputStreamBuffer()->GetBufferSize());
 
   // Set the info about the image.
-  m_extension = wxT("png");
+  m_extension = wxS("png");
   m_originalWidth = image.GetWidth();
   m_originalHeight = image.GetHeight();
   m_scaledBitmap.Create(1, 1);
@@ -790,28 +811,24 @@ wxString Image::GetExtension() const { return m_extension; }
 // filesystem cannot be passed by const reference as we want to keep the
 // pointer to the file system alive in a background task
 // cppcheck-suppress performance symbolName=filesystem
-void Image::LoadImage(wxString image, std::shared_ptr<wxFileSystem> filesystem,
+void Image::LoadImage(wxString image, std::shared_ptr<wxFileSystem> &filesystem,
                       bool remove) {
-  m_fs_keepalive_imagedata = filesystem;
+  if(m_loadImageTask.joinable())
+    m_loadImageTask.join();
   m_extension = wxFileName(image).GetExt();
   m_extension = m_extension.Lower();
   m_imageName = image;
-  LoadImage_Backgroundtask(image, filesystem, remove);
-}
-
-void Image::LoadImage_Backgroundtask(wxString image,
-                                     std::shared_ptr<wxFileSystem> filesystem,
-                                     bool remove) {
+  std::unique_ptr<ThreadNumberLimiter> limiter(new ThreadNumberLimiter()); 
   m_compressedImage.Clear();
   m_scaledBitmap.Create(1, 1);
+  SuppressErrorDialogs logNull;
 
   if (filesystem) {
-    wxFSFile *fsfile;
-    fsfile = filesystem->OpenFile(image);
+    std::unique_ptr<wxFSFile> fsfile(filesystem->OpenFile(image));
     if (fsfile) { // open successful
-      wxInputStream *istream = fsfile->GetStream();
+      std::unique_ptr<wxInputStream> istream(fsfile->DetachStream());
 
-      m_compressedImage = ReadCompressedImage(istream);
+      m_compressedImage = ReadCompressedImage(istream.get());
     }
 
     // Closing and deleting fsfile is important: If this line is missing
@@ -820,25 +837,40 @@ void Image::LoadImage_Backgroundtask(wxString image,
   } else {
     wxFile file;
     // Support relative and absolute paths.
-    if (wxFileExists(m_configuration->GetWorkingDirectory() + wxT("/") + image))
-      file.Open(m_configuration->GetWorkingDirectory() + wxT("/") + image);
+    if (wxFileExists(m_configuration->GetWorkingDirectory() + wxS("/") + image))
+      file.Open(m_configuration->GetWorkingDirectory() + wxS("/") + image);
     else
       file.Open(image);
 
     if (file.IsOpened()) {
-      wxFileInputStream strm(file);
-      bool ok = strm.IsOk();
+      std::unique_ptr<wxInputStream> strm (new wxFileInputStream(file));
+      bool ok = strm->IsOk();
       if (ok)
-        m_compressedImage = ReadCompressedImage(&strm);
+        m_compressedImage = ReadCompressedImage(strm.get());
 
       file.Close();
       if (ok && remove) {
-        SuppressErrorDialogs logNull;
-        wxRemoveFile(image);
+        if(!wxRemoveFile(image))
+        {
+          wxMilliSleep(300);
+          if(!wxRemoveFile(image))
+          {
+            wxMilliSleep(300);
+            wxRemoveFile(image);
+            wxLogMessage("File %s cannot be deleted.", image.mb_str());
+          }
+        }
       }
     }
   }
 
+  m_loadImageTask = std::thread(&Image::LoadImage_Backgroundtask,
+                                this,
+                                std::move(limiter));
+
+}
+
+void Image::LoadImage_Backgroundtask(std::unique_ptr<ThreadNumberLimiter> limiter) {
   m_isOk = false;
 
   wxImage Image;
@@ -875,24 +907,18 @@ void Image::LoadImage_Backgroundtask(wxString image,
         wxString line;
         while (!zstream.Eof()) {
           line = textIn.ReadLine();
-          svgContents_string += line + wxT("\n");
+          svgContents_string += line + wxS("\n");
         }
       }
       // Convert the data we have read to a modifiable char * containing the svg
       // file's contents.
-      char *svgContents;
-      svgContents = static_cast<char *>(strdup(svgContents_string.utf8_str()));
+      wxCharBuffer svgContents = svgContents_string.ToUTF8();
 
       // Parse the svg file's contents
-      int ppi;
-      if (m_configuration->GetDC()->GetPPI().x > 50)
-        ppi = m_configuration->GetDC()->GetPPI().x;
-      else
-        ppi = 96;
+      int ppi = m_configuration->GetPPI().x;
 
-      if (svgContents) {
-        m_svgImage = nsvgParse(svgContents, "px", ppi);
-        free(svgContents);
+      if (svgContents.data()) {
+        m_svgImage = nsvgParse(svgContents.data(), "px", ppi);
       }
 
       if (m_svgImage) {
@@ -906,7 +932,10 @@ void Image::LoadImage_Backgroundtask(wxString image,
     } else {
       wxMemoryInputStream istream(m_compressedImage.GetData(),
                                   m_compressedImage.GetDataLen());
-      Image.LoadFile(istream);
+      {
+        SuppressErrorDialogs logNull;
+        Image.LoadFile(istream);
+      }
       m_originalWidth = 700;
       m_originalHeight = 300;
 
@@ -914,15 +943,15 @@ void Image::LoadImage_Backgroundtask(wxString image,
         m_originalWidth = Image.GetWidth();
         m_originalHeight = Image.GetHeight();
         m_isOk = true;
-        if (Image.HasOption(wxT("wxIMAGE_OPTION_RESOLUTION"))) {
+        if (Image.HasOption(wxS("wxIMAGE_OPTION_RESOLUTION"))) {
           int resolution;
-          resolution = Image.GetOptionInt(wxT("wxIMAGE_OPTION_RESOLUTION"));
-          if (Image.HasOption(wxT("wxIMAGE_OPTION_RESOLUTIONUNIT"))) {
+          resolution = Image.GetOptionInt(wxS("wxIMAGE_OPTION_RESOLUTION"));
+          if (Image.HasOption(wxS("wxIMAGE_OPTION_RESOLUTIONUNIT"))) {
             if (Image.GetOptionInt("wxIMAGE_OPTION_RESOLUTIONUNIT") ==
                 wxIMAGE_RESOLUTION_CM)
               resolution *= 2.54;
           }
-          if (resolution > 50)
+          if (resolution > 10)
             m_ppi = resolution;
         }
       } else {
@@ -930,10 +959,15 @@ void Image::LoadImage_Backgroundtask(wxString image,
       }
     }
   }
-  m_fs_keepalive_imagedata.reset();
 }
 
 void Image::Recalculate(double scale) {
+  if(m_loadImageTask.joinable())
+    m_loadImageTask.join();
+  // It would better to use a jthread for joining no-more used threads.
+  // But that is C++20, which now (in 2023) is still too early.
+  if((!m_gnuplotDataThreadRunning) && m_loadGnuplotSourceTask.joinable())
+     m_loadGnuplotSourceTask.join();
   int width = m_originalWidth;
   int height = m_originalHeight;
 
@@ -957,18 +991,18 @@ void Image::Recalculate(double scale) {
     return;
   }
 
-  int viewPortHeight = m_configuration->GetClientHeight();
-  int viewPortWidth = m_configuration->GetClientWidth();
+  int viewPortHeight = m_configuration->GetCanvasSize().y - 1;
+  int viewPortWidth = m_configuration->GetLineWidth();
 
   if (viewPortHeight < 10)
     viewPortHeight = 10;
   if (viewPortWidth < 10)
     viewPortWidth = 10;
 
-  // Shrink to .9* the canvas size, if needed
-  if (scale * width > .9 * viewPortWidth)
-    scale = .9 * viewPortWidth / width;
+  if (scale * width > .99 * viewPortWidth)
+    scale = .99 * viewPortWidth / width;
 
+  // Shrink to .9* the canvas height, if needed
   if (scale * height > .9 * viewPortHeight) {
     if (scale > .9 * viewPortHeight / height)
       scale = .9 * viewPortHeight / height;
@@ -1006,3 +1040,38 @@ const wxString &Image::GetBadImageToolTip() {
 	    "One example of the latter would be: Gnuplot refuses to plot entirely "
 	    "empty images");
 }
+
+wxBitmap Image::RGBA2wxBitmap(const unsigned char imgdata[],
+                              const int &width, const int &height,
+
+#if defined __WXOSX__
+                                  const int &scaleFactor
+#else
+                                  const int &WXUNUSED(scaleFactor)
+#endif
+				  ) {
+#if defined __WXOSX__
+  wxBitmap retval = wxBitmap(wxSize(width, height), 32, scaleFactor);
+#else
+  wxBitmap retval = wxBitmap(wxSize(width, height), 32);
+#endif
+  const unsigned char *rgba = imgdata;
+  if (!retval.Ok())
+    return retval;
+
+  wxAlphaPixelData bmpdata(retval);
+  wxAlphaPixelData::Iterator dst(bmpdata);
+  for (int y = 0; y < height; y++) {
+    dst.MoveTo(bmpdata, 0, y);
+    for (int x = 0; x < width; x++) {
+      unsigned char a = rgba[3];
+      dst.Red() = rgba[0] * a / 255;
+      dst.Green() = rgba[1] * a / 255;
+      dst.Blue() = rgba[2] * a / 255;
+      dst.Alpha() = a;
+      dst++;
+      rgba += 4;
+    }
+  }
+  return retval;
+}
