@@ -30,17 +30,18 @@ LogPane::LogPane(wxWindow *parent, wxWindowID id, bool becomeLogTarget)
     new wxTextCtrl(this, -1, wxEmptyString, wxDefaultPosition, wxDefaultSize,
 		   wxTE_MULTILINE | wxTE_READONLY | wxHSCROLL | wxVSCROLL);
 
-  m_textCtrl->SetMinSize(
-			 wxSize(wxSystemSettings::GetMetric(wxSYS_SCREEN_X) / 10,
-				wxSystemSettings::GetMetric(wxSYS_SCREEN_Y) / 10));
-  vbox->Add(m_textCtrl, wxSizerFlags().Expand().Proportion(1));
+  // m_textCtrl->SetMinSize(
+  // 			 wxSize(wxSystemSettings::GetMetric(wxSYS_SCREEN_X) / 10,
+  // 				wxSystemSettings::GetMetric(wxSYS_SCREEN_Y) / 10));
+  vbox->Add(m_textCtrl, wxSizerFlags(1).Expand());
 
   if (becomeLogTarget)
     BecomeLogTarget();
 
   // m_logPanelTarget->SetRepetitionCounting();
   // m_logPanelTarget->DisableTimestamp();
-  SetSizerAndFit(vbox);
+  SetSizer(vbox);
+  FitInside();
 }
 
 void LogPane::DropLogTarget() {
