@@ -42,12 +42,15 @@ public:
                        long style = wxOK|wxCENTRE, const wxPoint &pos = wxDefaultPosition):
     wxMessageDialog (parent, message, caption, style, pos)
     {
+      wxString logString = message;
+      logString.Replace(wxS("%"), wxS("%%"));
+      wxLogMessage(logString);
       wxLogMessage(message);
     }
 };
 
 extern int LoggingMessageBox(   const wxString &        message,
-                                const wxString &        caption = wxMessageBoxCaptionStr,
+                                const wxString &        caption = wxString(wxMessageBoxCaptionStr),
                                 int     style = wxOK|wxCENTRE,
                                 wxWindow *      parent = NULL,
                                 int     x = wxDefaultCoord,
