@@ -42,6 +42,7 @@
 #include "EditorCell.h"
 #include "FracCell.h"
 #include "GroupCell.h"
+#include <unordered_map>
 
 /*! This class handles parsing the xml representation of a cell tree.
 
@@ -82,11 +83,17 @@ public:
 private:
   //! A pointer to a method that handles an XML tag for a type of Cell
   using MathCellFunc = std::unique_ptr<Cell> (MathParser::*)(wxXmlNode *node);
-  WX_DECLARE_STRING_HASH_MAP(MathCellFunc, MathCellFunctionHash);
 
   //! A pointer to a method that handles an XML tag for a type of GroupCell
   using GroupCellFunc = std::unique_ptr<GroupCell> (MathParser::*)(wxXmlNode *node);
+
+  #if wxCHECK_VERSION(3, 3, 0) || wxUSE_STL
+  typedef std::unordered_map <wxString, MathCellFunc> MathCellFunctionHash;
+  typedef std::unordered_map <wxString, GroupCellFunc> GroupCellFunctionHash;
+#else
+  WX_DECLARE_STRING_HASH_MAP(MathCellFunc, MathCellFunctionHash);
   WX_DECLARE_STRING_HASH_MAP(GroupCellFunc, GroupCellFunctionHash);
+#endif
 
   //! Who you gonna call if you encounter any of these math cell tags?
   static MathCellFunctionHash m_innerTags;
@@ -171,9 +178,12 @@ private:
   //! Parse an frac XML tag to a Cell.
   std::unique_ptr<Cell> ParseFracTag(wxXmlNode *node);
   //! Parse a text XML tag to a Cell.
-  std::unique_ptr<Cell> ParseText(wxXmlNode *node, TextStyle style = TS_DEFAULT);
-  //! Parse a Variable name tag t a Cell.
-  std::unique_ptr<Cell> ParseVariableNameTag(wxXmlNode *node){return ParseText(node->GetChildren(), TS_VARIABLE);}
+  std::unique_ptr<Cell> ParseText(wxXmlNode *node, TextStyle style = TS_MATH);
+  /*! Parse a Variable name / operator tag to a Cell.
+
+    Operators identify themself as variable.
+   */
+  std::unique_ptr<Cell> ParseVariableNameTag(wxXmlNode *node);
   //! Parse an Operator name tag to a Cell.
   std::unique_ptr<Cell> ParseOperatorNameTag(wxXmlNode *node){return ParseText(node->GetChildren(), TS_FUNCTION);}
   //! Parse a miscellaneous text tag to a Cell.
@@ -189,7 +199,7 @@ private:
   //! Parse a function name tag to a Cell.
   std::unique_ptr<Cell> ParseFunctionNameTag(wxXmlNode *node){return ParseText(node->GetChildren(), TS_FUNCTION);}
   //! Parse a space tag to a Cell.
-  std::unique_ptr<Cell> ParseSpaceTag(wxXmlNode *WXUNUSED(node)){return std::make_unique<TextCell>(m_group, m_configuration, wxT(" "));}
+  std::unique_ptr<Cell> ParseSpaceTag(wxXmlNode *WXUNUSED(node)){return std::make_unique<TextCell>(m_group, m_configuration, wxS(" "));}
   /*! Parse a math-in-maths tag to a Cell.
 
     \todo Does such a thing actually exist?
