@@ -70,7 +70,6 @@ void MaximaManual::WaitForBackgroundProcess() {
 
   if (!m_helpFileAnchorsThreadActive.try_lock()) {
     wxBusyCursor crs;
-    wxWindowDisabler disableAll;
     wxBusyInfo wait(_("Please wait while wxMaxima parses the maxima manual"));
     wxLogNull suppressRecursiveYieldWarning;
     while (!m_helpFileAnchorsThreadActive.try_lock()) {
@@ -112,7 +111,7 @@ bool MaximaManual::LoadBuiltInManualAnchors() {
   wxLogMessage(_("Using the built-in list of manual anchors."));
   wxMemoryInputStream istream(MANUAL_ANCHORS_XML, MANUAL_ANCHORS_XML_SIZE);
   wxXmlDocument xmlDoc;
-  if (!xmlDoc.Load(istream, wxT("UTF-8")))
+  if (!xmlDoc.Load(istream, wxS("UTF-8")))
     return false;
   if (!LoadManualAnchorsFromXML(xmlDoc, false))
     return false;
@@ -129,16 +128,14 @@ bool MaximaManual::LoadManualAnchorsFromCache() {
   }
   wxXmlDocument xmlDocument(anchorsFile);
   if (!xmlDocument.IsOk()) {
-    wxLogMessage(
-		 _("The cache for the subjects the manual contains cannot be read."));
+    wxLogMessage(_("The cache for the subjects the manual contains cannot be read."));
     wxRemoveFile(anchorsFile);
     return false;
   }
 
   if (LoadManualAnchorsFromXML(xmlDocument)) {
-    wxLogMessage(
-		 wxString::Format(_("Read the entries the maxima manual offers from %s"),
-				  Dirstructure::Get()->AnchorsCacheFile().utf8_str()));
+    wxLogMessage(_("Read the entries the maxima manual offers from %s"),
+		 Dirstructure::Get()->AnchorsCacheFile().utf8_str());
     return true;
   }
   return !m_helpFileURLs_singlePage.empty();
@@ -191,10 +188,10 @@ void MaximaManual::CompileHelpFileAnchors(wxString maximaHtmlDir,
       dir.Traverse(htmlFilesTraverser);
     }
 
-    for (auto file : helpFiles) {
+    for (const auto &file : helpFiles) {
       bool is_Singlepage = file.Contains("_singlepage.");
       long foundAnchors = 0;
-      wxString fileURI = wxURI(wxT("file://") + file).BuildURI();
+      wxString fileURI = wxURI(wxS("file://") + file).BuildURI();
       // wxWidgets cannot automatically replace a # as it doesn't know if it is
       // a anchor separator
       fileURI.Replace("#", "%23");
@@ -207,13 +204,13 @@ void MaximaManual::CompileHelpFileAnchors(wxString maximaHtmlDir,
       wxRegEx uriCorector1("^file:([a-zA-Z]):");
       wxRegEx uriCorector2("^file:([a-zA-Z][a-zA-Z]):");
 
-      uriCorector1.ReplaceFirst(&fileURI, wxT("file:///\\1:"));
-      uriCorector2.ReplaceFirst(&fileURI, wxT("file:///\\1:"));
+      uriCorector1.ReplaceFirst(&fileURI, wxS("file:///\\1:"));
+      uriCorector2.ReplaceFirst(&fileURI, wxS("file:///\\1:"));
 #endif
 
-      wxLogMessage(wxString::Format(_("Scanning help file %s for anchors"),
-                                    file.ToUTF8().data()));
-
+      wxLogMessage(_("Scanning help file %s for anchors"),
+		   file.ToUTF8().data());
+    
       wxRegEx idExtractor(".*<span id=\\\"([a-zAZ0-9_-]*)\\\"");
       wxRegEx idExtractor2("<dt id=\\\"(index-[a-zAZ0-9_-]*)\\\"");
       wxRegEx idExtractor3("<dt [^>]* id=\\\"(index-[a-zAZ0-9_-]*)\\\"");
@@ -221,11 +218,11 @@ void MaximaManual::CompileHelpFileAnchors(wxString maximaHtmlDir,
       wxString escapeChars = "`\"^()<=>[]`%?;\\$%&+-*/.!\'@#:^_";
       wxFileInputStream input(file);
       if (input.IsOk()) {
-        wxTextInputStream text(input, wxT('\t'),
+        wxTextInputStream text(input, wxS('\t'),
                                wxConvAuto(wxFONTENCODING_UTF8));
         while (input.IsOk() && !input.Eof()) {
           wxString line = text.ReadLine();
-          wxStringTokenizer tokens(line, wxT(">"));
+          wxStringTokenizer tokens(line, wxS(">"));
           while (tokens.HasMoreTokens()) {
             wxString token = tokens.GetNextToken();
             wxString oldToken(token);
@@ -272,14 +269,14 @@ void MaximaManual::CompileHelpFileAnchors(wxString maximaHtmlDir,
       AnchorAliasses(m_helpFileAnchors);
       AnchorAliasses(m_helpFileURLs_filePerChapter);
       AnchorAliasses(m_helpFileURLs_singlePage);
-      wxLogMessage(wxString::Format(_("Found %li anchors, %li anchors total."),
-                                    foundAnchors, foundAnchorsTotal));
+      wxLogMessage(_("Found %li anchors, %li anchors total."),
+		   foundAnchors, foundAnchorsTotal);
     }
     if(foundAnchorsTotal < 100)
       {
-	wxLogMessage(wxString::Format(_("Have only %li keyword anchors at the end of parsing the maxima manual => "
-					"Not caching the result of using the built-in keyword list"),
-				      foundAnchorsTotal));
+	wxLogMessage(_("Have only %li keyword anchors at the end of parsing the maxima manual => "
+		       "Not caching the result of using the built-in keyword list"),
+		     foundAnchorsTotal);
 	LoadBuiltInManualAnchors();
       }
     else
@@ -327,21 +324,21 @@ void MaximaManual::SaveManualAnchorsToCache(wxString maximaHtmlDir,
 					    wxString saveName) {
   long num = m_helpFileURLs_singlePage.size();
   if (num <= 50) {
-    wxLogMessage(wxString::Format(_("Found only %li keywords in maxima's "
-                                    "manual. Not caching them to disc."),
-                                  num));
+    wxLogMessage(_("Found only %li keywords in maxima's "
+		   "manual. Not caching them to disc."),
+		 num);
     return;
   }
   wxXmlAttribute *htmlDir =
-    new wxXmlAttribute(wxT("html_dir"), maximaHtmlDir);
+    new wxXmlAttribute(wxS("html_dir"), maximaHtmlDir);
 
   wxXmlAttribute *maximaVersionNode =
-    new wxXmlAttribute(wxT("maxima_version"), maximaVersion, htmlDir);
+    new wxXmlAttribute(wxS("maxima_version"), maximaVersion, htmlDir);
 
   wxXmlNode *topNode =
     new wxXmlNode(NULL, wxXML_DOCUMENT_NODE, wxEmptyString, wxEmptyString);
   wxXmlNode *headNode =
-    new wxXmlNode(topNode, wxXML_ELEMENT_NODE, wxT("maxima_toc"),
+    new wxXmlNode(topNode, wxXML_ELEMENT_NODE, wxS("maxima_toc"),
 		  wxEmptyString, maximaVersionNode);
 
   MaximaManual::HelpFileAnchors::const_iterator it;
@@ -370,7 +367,7 @@ void MaximaManual::SaveManualAnchorsToCache(wxString maximaHtmlDir,
       wxXmlNode *keyNode =
 	new wxXmlNode(manualEntry, wxXML_ELEMENT_NODE, "url_fileperchapter");
       new wxXmlNode(keyNode, wxXML_TEXT_NODE, wxEmptyString,
-                    m_helpFileURLs_singlePage[it->first]);
+                    m_helpFileURLs_filePerChapter[it->first]);
     }
   }
   wxXmlDocument xmlDoc;
@@ -383,68 +380,65 @@ void MaximaManual::SaveManualAnchorsToCache(wxString maximaHtmlDir,
 					   "overwritten if maxima's version changes or the file cannot be read"));
 
   xmlDoc.AppendToProlog(commentNode);
-  wxLogMessage(wxString::Format(_("Trying to cache the list of subjects the "
-                                  "manual contains in the file %s."),
-                                saveName.utf8_str()));
+  wxLogMessage(_("Trying to cache the list of subjects the "
+		 "manual contains in the file %s."),
+	       saveName.utf8_str());
   xmlDoc.Save(saveName);
 }
 
-bool MaximaManual::LoadManualAnchorsFromXML(wxXmlDocument xmlDocument,
+bool MaximaManual::LoadManualAnchorsFromXML(const wxXmlDocument &xmlDocument,
                                             bool checkManualVersion) {
   wxXmlNode *headNode = xmlDocument.GetDocumentNode();
   if (!headNode) {
-    wxLogMessage(
-		 _("The cache for the subjects the manual contains has no head node."));
+    wxLogMessage(_("The cache for the subjects the manual contains has no head node."));
     return false;
   }
   headNode = headNode->GetChildren();
-  while ((headNode) && (headNode->GetName() != wxT("maxima_toc")))
+  while ((headNode) && (headNode->GetName() != wxS("maxima_toc")))
     headNode = headNode->GetNext();
   if (!headNode) {
     wxLogMessage(_("Anchors file has no top node."));
     return false;
   }
-  wxString htmlDir = headNode->GetAttribute(wxT("html_dir"));
-  wxString cacheMaximaVersion = headNode->GetAttribute(wxT("maxima_version"));
-  wxLogMessage(wxString::Format(_("Maxima version: %s, Anchors cache version"),
-                                m_maximaVersion.utf8_str(),
-                                cacheMaximaVersion.utf8_str()));
+  wxString htmlDir = headNode->GetAttribute(wxS("html_dir"));
+  wxString cacheMaximaVersion = headNode->GetAttribute(wxS("maxima_version"));
+  wxLogMessage(_("Maxima version: %s, Anchors cache version"),
+	       m_maximaVersion.utf8_str(),
+	       cacheMaximaVersion.utf8_str());
   if (checkManualVersion && ((cacheMaximaVersion != m_maximaVersion) ||
                              (htmlDir != m_maximaHtmlDir))) {
     if (cacheMaximaVersion != m_maximaVersion)
       wxLogMessage(_("The cache for the subjects the manual contains is from a "
                      "different Maxima version."));
     if (htmlDir != m_maximaHtmlDir)
-      wxLogMessage(
-		   _("The help dir from the cache differs from the current one."));
+      wxLogMessage(_("The help dir from the cache differs from the current one."));
     return false;
   }
   if(!checkManualVersion)
     wxLogMessage(_("Ignoring the cache version for the manual anchors."));
   wxXmlNode *entry = headNode->GetChildren();
   if (entry == NULL) {
-    wxLogMessage(
-		 _("No entries in the caches for the subjects the manual contains."));
+    wxLogMessage(_("No entries in the caches for the subjects the manual contains."));
     return false;
   }
   long anchors = 0;
   long urls_FilePerChapter = 0;
   long urls_SinglePage = 0;
   while (entry) {
-    if (entry->GetName() == wxT("entry")) {
+    if (entry->GetName() == wxS("entry")) {
       wxString key;
       wxString url_singlepage;
       wxString url_filePerChapter;
       wxString anchor;
       wxXmlNode *node = entry->GetChildren();
       while (node) {
-        if ((node->GetName() == wxT("anchor")) && (node->GetChildren()))
+        if ((node->GetName() == wxS("anchor")) && (node->GetChildren()))
           anchor = node->GetChildren()->GetContent();
-        if ((node->GetName() == wxT("key")) && (node->GetChildren()))
+        if ((node->GetName() == wxS("key")) && (node->GetChildren()))
           key = node->GetChildren()->GetContent();
-        if ((node->GetName() == wxT("url_singlepage")) && (node->GetChildren()))
+        if ((node->GetName() == wxS("url_singlepage")) && (node->GetChildren()))
           url_singlepage = node->GetChildren()->GetContent();
-        if ((node->GetName() == wxT("url_fileperchapter")) &&
+        if ((node->GetName() == wxS("url_fileperchapter")) &&
             (node->GetChildren()))
           url_filePerChapter = node->GetChildren()->GetContent();
         node = node->GetNext();
@@ -467,11 +461,10 @@ bool MaximaManual::LoadManualAnchorsFromXML(wxXmlDocument xmlDocument,
     }
     entry = entry->GetNext();
   }
-  wxLogMessage(wxString::Format(
-				_("Found %li anchors, URLs (individual files): %li, URLs (singlepage): %li"),
+  wxLogMessage(_("Found %li anchors, URLs (individual files): %li, URLs (singlepage): %li"),
                                 anchors,
                                 urls_FilePerChapter,
-				urls_SinglePage));
+				urls_SinglePage);
   return !m_helpFileURLs_singlePage.empty();
 }
 
@@ -497,7 +490,7 @@ void MaximaManual::FindMaximaHtmlDir(wxString docDir) {
   // helpFile=/usr/local/share/maxima/5.44.0/doc/html/maxima_singlepage.html
   // Use that file, if the configuration option is used.
   wxString headerFile;
-  wxConfig::Get()->Read(wxT("helpFile"), &headerFile);
+  wxConfig::Get()->Read(wxS("helpFile"), &headerFile);
   if (headerFile.Length() && wxFileExists(headerFile)) {
     wxLogMessage(_("Using Maxima help file from wxMaxima configuration file "
                    "(helpFile=...))"));
@@ -507,9 +500,9 @@ void MaximaManual::FindMaximaHtmlDir(wxString docDir) {
   // Cygwin uses /c/something instead of c:/something and passes this path to
   // the web browser - which doesn't support cygwin paths => convert the path to
   // a native windows pathname if needed.
-  if (headerFile.Length() > 1 && headerFile[1] == wxT('/')) {
+  if (headerFile.Length() > 1 && headerFile[1] == wxS('/')) {
     headerFile[1] = headerFile[2];
-    headerFile[2] = wxT(':');
+    headerFile[2] = wxS(':');
   }
 #endif // __CYGWIN__
   wxPathList helpfilepaths;
@@ -529,9 +522,8 @@ void MaximaManual::FindMaximaHtmlDir(wxString docDir) {
 
   if (helpfile_cleanup.IsFileReadable()) {
     m_maximaHtmlDir = helpfile_cleanup.GetPath();
-    wxLogMessage(
-		 wxString::Format(_("Found the maxima HTML manual in the folder %s."),
-				  m_maximaHtmlDir.ToUTF8().data()));
+    wxLogMessage(_("Found the maxima HTML manual in the folder %s."),
+				  m_maximaHtmlDir.ToUTF8().data());
   } else {
     m_maximaHtmlDir.clear();
     wxLogMessage(_("Didn't find the maxima HTML manual."));
@@ -569,7 +561,9 @@ void MaximaManual::LoadHelpFileAnchors(wxString docdir,
 }
 
 MaximaManual::~MaximaManual() {
-  wxLogMessage(
-	       _("Waiting for the thread that parses the maxima manual to finish"));
+  if (!m_helpFileAnchorsThreadActive.try_lock())
+    wxLogMessage(_("Waiting for the thread that parses the maxima manual to finish"));
+  else
+    m_helpFileAnchorsThreadActive.unlock();
   WaitForBackgroundProcess();
 }
