@@ -51,9 +51,6 @@ TableOfContents::TableOfContents(wxWindow *parent, int id,
   box->Add(m_displayedItems, wxSizerFlags(1).Expand());
   box->Add(m_regex, wxSizerFlags().Expand());
   m_lastSelection = -1;
-
-  SetSizer(box);
-  FitInside();
   m_regex->Connect(REGEX_EVENT,
                    wxCommandEventHandler(TableOfContents::OnRegExEvent), NULL,
                    this);
@@ -74,6 +71,8 @@ TableOfContents::TableOfContents(wxWindow *parent, int id,
 			    wxMouseCaptureLostEventHandler(TableOfContents::OnMouseCaptureLost), NULL,
 			    this);
   Connect(wxEVT_TIMER, wxTimerEventHandler(TableOfContents::OnTimer));
+  SetSizer(box);
+  FitInside();
 }
 
 void TableOfContents::OnTimer(wxTimerEvent &event) {
@@ -156,7 +155,7 @@ void TableOfContents::OnDragStart(wxListEvent &evt) {
     if (!m_displayedItems->HasCapture()) {
       wxString dragImageLabel = m_displayedItems->GetItemText(evt.GetIndex());
       if (dragImageLabel.Length() > 15)
-        dragImageLabel = dragImageLabel.Left(12) + wxT("...");
+        dragImageLabel = dragImageLabel.Left(12) + wxS("...");
       m_dragImage = new wxDragImage(dragImageLabel);
       m_dragImage->BeginDrag(
 			     wxPoint(-20 * GetContentScaleFactor(), -20 * GetContentScaleFactor()),
@@ -242,13 +241,27 @@ void TableOfContents::UpdateTableOfContents(GroupCell *pos) {
     long item = m_displayedItems->GetNextItem(-1, wxLIST_NEXT_ALL,
                                               wxLIST_STATE_SELECTED);
     UpdateStruct();
+
+    std::vector<GroupCell *>::const_iterator it = m_displayedGroupCells.begin();
+    
     // Select the cell with the cursor
-    for (auto &cell : OnList(m_tree->get())) {
-      if (&cell == pos) {
-        if (!m_structure.empty())
-          selection = m_structure.size() - 1;
+    if(!m_displayedGroupCells.empty())
+      {
+	int cursorItem = -1;
+	for (const auto &cell : OnList(m_tree->get())) {
+	  if ((it != m_displayedGroupCells.end()) && (&cell == *it))
+	    {
+	      ++it;
+	      ++cursorItem;
+	    }
+	  if (&cell == pos) {
+	    if(cursorItem < 0)
+	      cursorItem = 0;
+	    selection = cursorItem;
+	    break;
+	  }
+	}
       }
-    }
     if ((selection >= 0) && (item != selection)) {
       if ((long)m_displayedItems->GetItemCount() < selection)
         selection = m_displayedItems->GetItemCount() - 1;
@@ -269,12 +282,12 @@ void TableOfContents::UpdateDisplay() {
 
   // Create a wxArrayString containing all section/chapter/... titles we want
   // to display
-  for (unsigned int i = 0; i < m_structure.size(); i++) {
+  for (const auto &i: m_structure) {
     // Indentation further reduces the screen real-estate. So it is to be used
     // sparingly. But we should perhaps add at least a little bit of it to make
     // the list more readable.
     int tocDepth = 0;
-    switch (m_structure[i]->GetGroupType()) {
+    switch (i->GetGroupType()) {
     case GC_TYPE_TITLE:
       tocDepth = 0;
       break;
@@ -301,10 +314,10 @@ void TableOfContents::UpdateDisplay() {
     if (m_configuration->TocDepth() <= tocDepth)
       continue;
 
-    wxString curr = TocEntryString(m_structure[i]);
+    wxString curr = TocEntryString(i);
 
     if (m_regex->Matches(curr)) {
-      m_displayedGroupCells.push_back(m_structure[i]);
+      m_displayedGroupCells.push_back(i);
     }
   }
 
@@ -326,8 +339,7 @@ void TableOfContents::UpdateDisplay() {
     m_dndEndCell = NULL;
 
     for (unsigned long index = 0; index < m_structure.size(); index++) {
-      if ((index >= static_cast<unsigned long>(m_dragCurrentPos)) &&
-	  (m_dragCurrentPos >= 0)) {
+      if (index >= static_cast<unsigned long>(m_dragCurrentPos)) {
         m_dndEndCell = m_tree->get();
         if (m_otherCells.empty()) {
           while (m_dndEndCell->GetNext() != NULL)
@@ -361,7 +373,7 @@ void TableOfContents::UpdateDisplay() {
     displayedCells_dndOrder = m_displayedGroupCells;
 
   wxArrayString items;
-  for (auto i : displayedCells_dndOrder)
+  for (const auto &i : displayedCells_dndOrder)
     items.Add(TocEntryString(i));
   // Work around a wxWidgets bug: items==m_items_old if items is empty and
   // m_items_old isn't.
@@ -410,33 +422,33 @@ wxString TableOfContents::TocEntryString(GroupCell *cell) {
 
   if (m_configuration->TocShowsSectionNumbers()) {
     if (cell->GetPrompt() != NULL)
-      curr = cell->GetPrompt()->ToString() + wxT(" ") + curr;
+      curr = cell->GetPrompt()->ToString() + wxS(" ") + curr;
     curr.Trim(false);
   } else
     switch (cell->GetGroupType()) {
     case GC_TYPE_TITLE:
       break;
     case GC_TYPE_SECTION:
-      curr = wxT("  ") + curr;
+      curr = wxS("  ") + curr;
       break;
     case GC_TYPE_SUBSECTION:
-      curr = wxT("    ") + curr;
+      curr = wxS("    ") + curr;
       break;
     case GC_TYPE_SUBSUBSECTION:
-      curr = wxT("      ") + curr;
+      curr = wxS("      ") + curr;
       break;
     case GC_TYPE_HEADING5:
-      curr = wxT("        ") + curr;
+      curr = wxS("        ") + curr;
       break;
     case GC_TYPE_HEADING6:
-      curr = wxT("          ") + curr;
+      curr = wxS("          ") + curr;
       break;
     default: {
     }
     }
 
   // Respecting linebreaks doesn't make much sense here.
-  curr.Replace(wxT("\n"), wxT(" "));
+  curr.Replace(wxS("\n"), wxS(" "));
   return curr;
 }
 
@@ -513,16 +525,15 @@ void TableOfContents::OnMouseRightDown(wxListEvent &event) {
 
   wxMenu *tocLevelMenu = new wxMenu();
   tocLevelMenu->AppendRadioItem(EventIDs::popid_tocLevel1, _("1 Level"));
-  tocLevelMenu->AppendRadioItem(EventIDs::popid_tocLevel2, _("2 Levels"));
-  tocLevelMenu->AppendRadioItem(EventIDs::popid_tocLevel3, _("3 Levels"));
-  tocLevelMenu->AppendRadioItem(EventIDs::popid_tocLevel4, _("4 Levels"));
-  tocLevelMenu->AppendRadioItem(EventIDs::popid_tocLevel5, _("5 Levels"));
-  tocLevelMenu->AppendRadioItem(EventIDs::popid_tocLevel6, _("All Levels"));
-  if (m_configuration->TocDepth() < 6)
+  for(int i = 2; i < EventIDs::NumberOfTocLevels() - 1; i++)
+    tocLevelMenu->AppendRadioItem(EventIDs::popid_tocLevel1 + i - 1, wxString::Format(_("%li Levels"), (long) i));
+  tocLevelMenu->AppendRadioItem(EventIDs::popid_tocLevel1 + EventIDs::NumberOfTocLevels() - 1, _("All Levels"));
+
+  if (m_configuration->TocDepth() < EventIDs::NumberOfTocLevels())
     tocLevelMenu->Check(EventIDs::popid_tocLevel1 + m_configuration->TocDepth() - 1,
                         true);
   else
-    tocLevelMenu->Check(EventIDs::popid_tocLevel6, true);
+    tocLevelMenu->Check(EventIDs::popid_tocLevel1 + EventIDs::NumberOfTocLevels() - 1, true);
   popupMenu->Append(wxID_ANY, _("Toc levels shown here"), tocLevelMenu);
 
   if (popupMenu->GetMenuItemCount() > 0)
