@@ -29,6 +29,7 @@
 */
 
 #include "../data/UnicodeData.h"
+#include "EventIDs.h"
 #include <memory>
 #include <wx/mstream.h>
 #include <wx/sizer.h>
@@ -46,7 +47,7 @@ wxDEFINE_EVENT(SYMBOLADDEVENT, SymboladdEvent);
 UnicodeSidebar::UnicodeSidebar(wxWindow *parent, wxWindow *worksheet,
                                Configuration *cfg)
   : wxPanel(parent), m_worksheet(worksheet) {
-  wxWindowUpdateLocker speedUp(this);
+  //  wxWindowUpdateLocker speedUp(this);
   wxBoxSizer *box = new wxBoxSizer(wxVERTICAL);
   m_initialized = false;
   m_regex = new RegexCtrl(this, wxID_ANY, cfg);
@@ -91,25 +92,23 @@ void UnicodeSidebar::OnRightClick(wxGridEvent &event) {
   number = m_grid->GetCellValue(event.GetRow(), 0);
   if (number.ToLong(&m_charRightClickedOn, 16)) {
     std::unique_ptr<wxMenu> popupMenu(new wxMenu());
-    popupMenu->Append(popid_addToSymbols, _("Add to symbols Sidebar"));
-    Connect(popid_addToSymbols, wxEVT_MENU,
+    popupMenu->Append(EventIDs::popid_addToSymbols, _("Add to symbols Sidebar"));
+    Connect(EventIDs::popid_addToSymbols, wxEVT_MENU,
             wxCommandEventHandler(UnicodeSidebar::OnMenu), NULL, this);
     PopupMenu(&*popupMenu);
   }
 }
 
 void UnicodeSidebar::OnMenu(wxCommandEvent &event) {
-  switch (event.GetId()) {
-  case popid_addToSymbols:
+  if (event.GetId() == EventIDs::popid_addToSymbols) {
     wxWindow *toplevel = this;
     while (toplevel->GetParent() != NULL)
       toplevel = toplevel->GetParent();
     wxCommandEvent *ev =
       new wxCommandEvent(SYMBOLADDEVENT, m_charRightClickedOn);
     toplevel->GetEventHandler()->QueueEvent(ev);
-
-    break;
   }
+  event.Skip();
 }
 
 void UnicodeSidebar::OnChangeAttempt(wxGridEvent &event) { event.Veto(); }
@@ -149,7 +148,7 @@ void UnicodeSidebar::OnPaint(wxPaintEvent &event) {
   m_grid->HideColLabels();
   while (!zstream.Eof()) {
     wxString line = textIn.ReadLine();
-    wxStringTokenizer items(line, wxT(";"), wxTOKEN_RET_EMPTY_ALL);
+    wxStringTokenizer items(line, wxS(";"), wxTOKEN_RET_EMPTY_ALL);
     wxString number = items.GetNextToken();
     wxString name = items.GetNextToken();
     if (!name.IsEmpty() && (name != "<control>") &&
