@@ -34,6 +34,7 @@
 #include "precomp.h"
 #include "MaximaManual.h"
 #include "EventIDs.h"
+#include "RecentDocuments.h"
 #include <wx/wx.h>
 #include <wx/xml/xml.h>
 #include <wx/aui/aui.h>
@@ -59,6 +60,8 @@
 #include "TableOfContents.h"
 #include "UnicodeSidebar.h"
 #include "ToolBar.h"
+#include <thread>
+#include <vector>
 
 /*! The canvas that contains the spreadsheet the whole program is about.
 
@@ -91,8 +94,10 @@
 class Worksheet : public wxScrolled<wxWindow>
 {
 public:
+  RecentDocuments m_unsavedDocuments;
   //! Is an update of the worksheet controls needed?
   bool UpdateControlsNeeded(){bool result = m_updateControls; m_updateControls = false; return result;}
+  void UpdateControlsNeeded(bool updateControlsNeeded){m_updateControls = updateControlsNeeded;}
 private:
   wxString m_maximaVersion;
   //! The directory with maxima's documentation
@@ -107,8 +112,6 @@ private:
   int m_newxPosition;
   // The y position to scroll to
   int m_newyPosition;
-  // false = collect scroll events without redrawing for every single one
-  bool m_dontSkipScrollEvent;
   //! Which zoom level were we at when we started the zoom gesture?
   double m_zoomAtGestureStart;
   //! If m_cellPointers.m_scrollToCell = true: Do we want to scroll to the top of this cell?
@@ -116,7 +119,7 @@ private:
   //! Is our window currently active?
   bool m_windowActive;
   //! The rectangle we need to refresh.
-  wxRegion m_rectToRefresh;
+  wxRegion m_regionToRefresh;
   /*! The size of a scroll step
 
     Defines the size of a
@@ -421,7 +424,8 @@ private:
   enum TimerIDs
   {
     TIMER_ID,
-    CARET_TIMER_ID
+    CARET_TIMER_ID,
+    DISPLAY_TIMEOUT_ID
   };
 
   //! Add a line to a file.
@@ -463,11 +467,31 @@ private:
 
   /*! Is called by wxWidgets when it wants to redraw the worksheet or a part of it.
 
-    The canonical way to schedule triggering this function is calling the Refresh()
-    function of this class.
+    The canonical way to schedule triggering this function is calling the
+    Refresh() or RequestRedraw() function of this class.
+
+    Using multiple threads in order to speed up this process is kind of hard:
+     * Using more than one wxPaintDC at the same time isn't supported by most
+       (if not all) operating systems.
+     * Drawing in a wxMemoryDC and then blitting the result in the central
+       wxPaintDC works, but each wxMemoryDC needs to draw into a separate bitmap
+       for that to work.
   */
   void OnPaint(wxPaintEvent &event);
+  //! Draws a groupcell on the DC
+  void DrawGroupCell(wxDC &dc, wxDC &adc, GroupCell &cell);
+  /*! Draws a groupcell in a bitmap and then blits it onto the DC
 
+    Drawing to a DC is only allowed to one thread at once. But doing the lengthy
+    stuff with bitmaps is possible to do in multiple threads at the same time so
+    as long as there is a mutex watching that we do the blit when no-one else
+    accesses the DC should be fine.
+   */
+  void DrawGroupCell_UsingBitmap(wxDC *dc, GroupCell *cell, wxRect DrawRegion);
+
+  //! All that has need to be done before drawing a GroupCell in a DC
+  void PrepareDrawGC(wxDC &dc);
+  
   void OnSize(wxSizeEvent &event);
 
   void OnMouseRightDown(wxMouseEvent &event);
@@ -589,7 +613,12 @@ private:
   bool m_mouseOutside;
   //! The list of tree that contains the document itself
   std::unique_ptr<GroupCell> m_tree;
-  GroupCell *m_last;
+  //! A pointer to the last cell of this worksheet
+  mutable CellPtr<GroupCell> m_last;
+  //! Request adjusting the worksheet size?
+  mutable bool m_adjustWorksheetSizeNeeded = false;
+  //! Returns a pointer to the last cell of this worksheet
+  GroupCell *GetLastCellInWorksheet() const;
   int m_clickType;
   int m_clickType_selectionStart;
   GroupCell *m_clickInGC;
@@ -657,6 +686,8 @@ public:
   //! Is called if this element looses or gets the focus
   void OnActivate(wxActivateEvent &event);
 private:
+  std::vector<std::thread> m_drawThreads;
+  static std::mutex m_drawDCLock;
   /*! The pointer to thesettings storage
    */
   Configuration *m_configuration;
@@ -687,9 +718,6 @@ public:
   void SetCurrentTextCell(TextCell *cell) { m_cellPointers.m_currentTextCell = cell; }
   void SetWorkingGroup(GroupCell *group) { m_cellPointers.SetWorkingGroup(group); }
 
-  //! The reference to a pointer that observes this object's lifetime
-  Worksheet* &m_observer;
-
   /*! Update the table of contents
 
     This function actually only schedules the update of the table-of-contents-tab.
@@ -760,7 +788,11 @@ public:
   void CodeCellVisibilityChanged();
 
   //! Re-read the configuration
-  void UpdateConfig() { m_configuration->ReadConfig(); }
+  void UpdateConfig() {
+    m_configuration->ReadConfig();
+    Recalculate();
+    Refresh();
+  }
 
   //! The name of the currently-opened file
   wxString m_currentFile;
@@ -810,9 +842,18 @@ public:
   */
   void TreeUndo_ClearBuffers();
 
-  //! The constructor
-  Worksheet(wxWindow *parent, int id, Worksheet *&observer, Configuration *config,
-            wxPoint pos = wxDefaultPosition, wxSize size = wxDefaultSize);
+  /*! The constructor
+
+    \param parent The parent window
+    \param id The window ID. Often wxID_ANY
+    \param The worksheet's initial location
+    \param The worksheet's initial size
+    \param reactToEvents Can be set to false for creating an example panel, for example
+           for the config dialogue.
+  */
+  Worksheet(wxWindow *parent, int id, Configuration *config,
+            wxPoint pos = wxDefaultPosition, wxSize size = wxDefaultSize,
+            bool reactToEvents = true);
 
   //! The destructor
   ~Worksheet();
@@ -858,7 +899,7 @@ public:
   GroupCell *GetInsertGroup() const;
 
   // Actually recalculate the worksheet.
-  bool RecalculateIfNeeded();
+  bool RecalculateIfNeeded(bool timeout = false);
 
   //! Schedule a recalculation of the worksheet starting with the cell start.
   void Recalculate(Cell *start);
@@ -1106,6 +1147,19 @@ public:
   }
   bool StatusTextHas(){return m_statusTextHas;}
 private:
+    /* ! A timer that tells us to urgently update the display
+
+     Normally we priorize tasks: If there are GUI actions to process we do so.
+     If not we look if there is data from maxima to process. If not we 
+     If not we recalculate the worksheet element sizes and positions and if
+     there still is no pressing task we update the display. This way we
+     respond quickly to the most important inputs.
+
+     This timer, if expired, tells us that if we don't update the screen now
+     maxima feels like not being responsive.
+   */
+  wxTimer m_displayTimeoutTimer;
+
   template <class T_SRC, class T_DEST>
   inline std::unique_ptr<T_DEST> unique_cast(std::unique_ptr<T_SRC> &&src)
     {
@@ -1113,8 +1167,8 @@ private:
 
       T_DEST *dest_ptr = &dynamic_cast<T_DEST &>(*src.get());
 
-      src.release();
-      return std::move(std::unique_ptr<T_DEST>(dest_ptr));
+      (void) src.release();
+      return std::unique_ptr<T_DEST>(dest_ptr);
     }
   wxString m_statusText;
   wxString m_statusText_old;
@@ -1202,7 +1256,7 @@ public:
   //! Is the selection in the current working group?
   bool IsSelectionInWorkingGroup();
 
-  void SetActiveCell(EditorCell *cell, bool callRefresh = true);
+  void SetActiveCell(EditorCell *cell);
 
 /*!
   Set the HCaret to its default location, at the end of the document.
@@ -1328,11 +1382,21 @@ public:
   //! The list of cells that have to be evaluated
   EvaluationQueue m_evaluationQueue;
 
-  // methods for folding
+  /*! Update the info which cell is the last of the worksheet
+
+    Also adjusts the scrollbar range to the worksheet length
+   */
   GroupCell *UpdateMLast();
+  /*! Update the info which cell is the last of the worksheet
+
+    Also adjusts the scrollbar range to the worksheet length
+    \param gc The last GroupCell of the worksheet
+   */
+  GroupCell *UpdateMLast(GroupCell *gc);
 
   void FoldOccurred();
 
+  // methods for folding
   //! Fold or unfold a cell
   GroupCell *ToggleFold(GroupCell *which);
 
@@ -1380,24 +1444,28 @@ public:
     \todo Keep a list of positions the last few letters were found at?
   */
   bool FindIncremental(const wxString &str, bool down, bool ignoreCase);
+  bool FindIncremental_RegEx(const wxString &str, bool down);
 
   /*! Find the next occurrence of a string
 
     Used by the find dialog.
   */
   bool FindNext(const wxString &str, bool down, bool ignoreCase, bool warn = true);
+  bool FindNext_Regex(const wxString &str, bool down, bool warn = true);
 
   /*! Replace the current occurrence of a string
 
     Used by the find dialog.
   */
   void Replace(const wxString &oldString, const wxString &newString, bool ignoreCase);
+  void Replace_RegEx(const wxString &oldString, const wxString &newString);
 
   /*! Replace all occurrences of a string
 
     Used by the find dialog.
   */
   int ReplaceAll(const wxString &oldString, const wxString &newString, bool ignoreCase);
+  int ReplaceAll_RegEx(const wxString &oldString, const wxString &newString);
 
   wxString GetInputAboveCaret();
 
@@ -1570,7 +1638,4 @@ inline Worksheet *Cell::GetWorksheet() const
   return static_cast<Worksheet*>(worksheet);
 }
 
-inline void Configuration::SetWorkSheet(wxWindow *workSheet)
-{ m_workSheet = dynamic_cast<Worksheet*>(workSheet); }
-
 #endif // WORKSHEET_H
