@@ -2,7 +2,7 @@
 // nil -*-
 //
 //  Copyright (C) 2007-2015 Andrej Vodopivec <andrej.vodopivec@gmail.com>
-//            (C) 2014-2018 Gunter Königsmann <wxMaxima@physikbuch.de>
+//            (C) 2014-2023 Gunter Königsmann <wxMaxima@physikbuch.de>
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -31,6 +31,7 @@
 #define PRINT_SIZE_MULTIPLIER (72.0 / 96.0)
 
 #include "AnimationCell.h"
+#include "../ErrorRedirector.h"
 #include "CellImpl.h"
 #include "CellPointers.h"
 #include "ImgCell.h"
@@ -49,15 +50,16 @@
 #include <wx/quantize.h>
 #include <wx/utils.h>
 #include <wx/wfstream.h>
+#include <wx/window.h>
 
 // filesystem cannot be passed by const reference as we want to keep the
 // pointer to the file system alive in a background task
 // cppcheck-suppress performance symbolName=filesystem
 AnimationCell::AnimationCell(GroupCell *group, Configuration *config,
-                             std::shared_ptr<wxFileSystem> filesystem,
+                             std::shared_ptr<wxFileSystem> &filesystem,
                              int framerate)
   : ImgCellBase(group, config),
-    m_timer(m_cellPointers->GetWorksheet(), wxNewId()),
+    m_timer(m_cellPointers->GetWorksheet(), wxWindow::NewControlId()),
     m_fileSystem(filesystem), m_framerate(framerate), m_displayed(0),
     m_imageBorderWidth(Scale_Px(1)) {
   InitBitFields();
@@ -68,7 +70,7 @@ AnimationCell::AnimationCell(GroupCell *group, Configuration *config,
 AnimationCell::AnimationCell(GroupCell *group, Configuration *config,
                              int framerate)
   : ImgCellBase(group, config),
-    m_timer(m_cellPointers->GetWorksheet(), wxNewId()),
+    m_timer(m_cellPointers->GetWorksheet(), wxWindow::NewControlId()),
     m_framerate(framerate), m_displayed(0), m_imageBorderWidth(Scale_Px(1)) {
   InitBitFields();
   m_type = MC_TYPE_SLIDE;
@@ -95,10 +97,8 @@ AnimationCell::AnimationCell(GroupCell *group, const AnimationCell &cell)
   CopyCommonData(cell);
 
   m_images.reserve(cell.Length());
-  for (std::vector<std::shared_ptr<Image>>::const_iterator i =
-	 cell.m_images.begin();
-       i != cell.m_images.end(); ++i)
-    m_images.push_back(std::make_shared<Image>(cell.m_configuration, **i));
+  for (const auto &i: cell.m_images)
+    m_images.push_back(std::make_shared<Image>(cell.m_configuration, *i));
 
   m_framerate = cell.m_framerate;
   m_displayed = cell.m_displayed;
@@ -186,6 +186,7 @@ void AnimationCell::LoadImages(wxMemoryBuffer imageData) {
 }
 
 void AnimationCell::LoadImages(wxString imageFile) {
+  SuppressErrorDialogs logNull;
   wxImage images;
   size_t count = wxImage::GetImageCount(imageFile);
 
@@ -204,14 +205,14 @@ void AnimationCell::LoadImages(wxArrayString images, bool deleteRead) {
   if (images.GetCount() == 1) {
     LoadImages(images[0]);
   } else
-    for (size_t i = 0; i < images.GetCount(); i++) {
-      if (images[i].EndsWith(".gnuplot"))
-        gnuplotFilename = images[i];
+    for (auto const &i: images) {
+      if (i.EndsWith(wxS(".gnuplot")))
+        gnuplotFilename = i;
       else {
-        if (images[i].EndsWith(".data"))
-          dataFilename = images[i];
+        if (i.EndsWith(wxS(".data")))
+          dataFilename = i;
         else {
-          m_images.push_back(std::make_shared<Image>(m_configuration, images[i],
+          m_images.push_back(std::make_shared<Image>(m_configuration, i,
                                                      m_fileSystem, deleteRead));
           if (gnuplotFilename != wxEmptyString) {
             if (m_images.back())
@@ -247,48 +248,41 @@ double AnimationCell::GetHeightList() const {
 }
 
 void AnimationCell::SetMaxWidth(double width) {
-  for (std::vector<std::shared_ptr<Image>>::iterator i = m_images.begin();
-       i != m_images.end(); i++)
-    (*i)->SetMaxWidth(width);
+  for (const auto &i: m_images)
+    (*i).SetMaxWidth(width);
 }
 
 void AnimationCell::SetMaxHeight(double height) {
-  for (std::vector<std::shared_ptr<Image>>::iterator i = m_images.begin();
-       i != m_images.end(); i++)
-    (*i)->SetMaxHeight(height);
+  for (const auto &i: m_images)
+    (*i).SetMaxHeight(height);
 }
 
 void AnimationCell::Recalculate(AFontSize fontsize) {
-  if (!IsOk()) {
-    m_height = m_width = 10;
-    m_center = 0;
-    return;
-  }
-
   // Assuming a minimum size maybe isn't that bad.
-  m_height = m_width = 10;
+  m_height = m_width = 10 + 2 * m_imageBorderWidth;
 
   // Make the cell as big as the biggest image plus its border.
-  for (int i = 0; i < Length(); i++) {
-    if (m_images[i] != NULL) {
-      if (m_configuration->GetPrinting()) {
-        m_images[i]->Recalculate(m_configuration->GetZoomFactor() *
-                                 PRINT_SIZE_MULTIPLIER);
-      } else {
-        m_images[i]->Recalculate();
+  for (auto &i: m_images) {
+    if(i != NULL)
+      {
+	if (m_configuration->GetPrinting()) {
+	  i->Recalculate(m_configuration->GetZoomFactor() *
+			 PRINT_SIZE_MULTIPLIER);
+	} else {
+	  i->Recalculate();
+	}
+	if (m_width < i->m_width + 2 * m_imageBorderWidth)
+	  m_width = i->m_width + 2 * m_imageBorderWidth;
+	if (m_height < i->m_height + 2 * m_imageBorderWidth)
+	  m_height = i->m_height + 2 * m_imageBorderWidth;
       }
-      if (m_width < m_images[i]->m_width + 2 * m_imageBorderWidth)
-        m_width = m_images[i]->m_width + 2 * m_imageBorderWidth;
-      if (m_height < m_images[i]->m_height + 2 * m_imageBorderWidth)
-        m_height = m_images[i]->m_height + 2 * m_imageBorderWidth;
-    }
   }
   m_center = m_height / 2;
   Cell::Recalculate(fontsize);
 }
 
-void AnimationCell::Draw(wxPoint point) {
-  Cell::Draw(point);
+void AnimationCell::Draw(wxPoint point, wxDC *dc, wxDC *antialiassingDC) {
+  Cell::Draw(point, dc, antialiassingDC);
   if (!IsOk())
     return;
   // If the animation leaves the screen the timer is stopped automatically.
@@ -302,17 +296,10 @@ void AnimationCell::Draw(wxPoint point) {
     // will trigger this function and will trigger the animation to be
     // restarted anyway.
     //
-    if (m_configuration->GetPrinting()) {
-      m_images[m_displayed]->Recalculate(m_configuration->GetZoomFactor() *
-                                         PRINT_SIZE_MULTIPLIER);
-    } else {
-      m_images[m_displayed]->Recalculate();
-    }
 
     if (!InUpdateRegion())
       return;
 
-    wxDC *dc = m_configuration->GetDC();
     wxMemoryDC bitmapDC;
 
     // Slide show cells have a red border except if they are selected
@@ -321,7 +308,6 @@ void AnimationCell::Draw(wxPoint point) {
 						 m_configuration->GetColor(TS_SELECTION))));
     else
       dc->SetPen(*wxRED_PEN);
-
     dc->DrawRectangle(wxRect(point.x, point.y - m_center, m_width, m_height));
 
     wxBitmap bitmap =
@@ -344,19 +330,22 @@ void AnimationCell::Draw(wxPoint point) {
              &bitmapDC, imageBorderWidth - m_imageBorderWidth,
              imageBorderWidth - m_imageBorderWidth);
   } else
-    // The cell isn't drawn => No need to keep it's image cache for now.
-    ClearCache();
+    {
+      // The cell isn't drawn => No need to keep it's image cache for now.
+      if(!GetRect().Intersects(m_configuration->GetVisibleRegion()))
+	ClearCache();
+    }
 
   // If we need a selection border on another redraw we will be informed by
   // OnPaint() again.
   m_drawBoundingBox = false;
 }
 
-wxString AnimationCell::ToString() const { return wxT(" << Animation >> "); }
+wxString AnimationCell::ToString() const { return wxS(" << Animation >> "); }
 
-wxString AnimationCell::ToMatlab() const { return wxT(" << Animation >> "); }
+wxString AnimationCell::ToMatlab() const { return wxS(" << Animation >> "); }
 
-wxString AnimationCell::ToTeX() const { return wxT(" << Graphics >> "); }
+wxString AnimationCell::ToTeX() const { return wxS(" << Graphics >> "); }
 
 wxString AnimationCell::ToXML() const {
   if (!IsOk())
@@ -365,60 +354,59 @@ wxString AnimationCell::ToXML() const {
   wxString gnuplotSourceFiles;
   wxString gnuplotDataFiles;
 
-  for (int i = 0; i < Length(); i++) {
+  for (const auto &i: m_images) {
     wxString basename = m_cellPointers->WXMXGetNewFileName();
     // add the file to memory
-    if (m_images[i]) {
+    if (i != NULL) {
       // Anonymize the name of our temp directory for saving
       wxString gnuplotSource;
       wxString gnuplotData;
-      if (m_images[i]->GnuplotData() != wxEmptyString) {
-        wxFileName gnuplotDataFile(m_images[i]->GnuplotData());
+      if (i->GnuplotData() != wxEmptyString) {
+        wxFileName gnuplotDataFile(i->GnuplotData());
         gnuplotData = gnuplotDataFile.GetFullName();
       }
-      if (m_images[i]->GnuplotSource() != wxEmptyString) {
-        wxFileName gnuplotSourceFile(m_images[i]->GnuplotSource());
+      if (i->GnuplotSource() != wxEmptyString) {
+        wxFileName gnuplotSourceFile(i->GnuplotSource());
         gnuplotSource = gnuplotSourceFile.GetFullName();
       }
 
       // Save the gnuplot source, if necessary.
       if (gnuplotSource != wxEmptyString) {
-        gnuplotSourceFiles += gnuplotSource + ".gz;";
-        const wxMemoryBuffer data = m_images[i]->GetCompressedGnuplotSource();
+        gnuplotSourceFiles += gnuplotSource + wxS(".gz;");
+        const wxMemoryBuffer data = i->GetCompressedGnuplotSource();
         if (data.GetDataLen() > 0)
-	  m_configuration->PushFileToSave(gnuplotSource + ".gz", data);
+	  m_configuration->PushFileToSave(gnuplotSource + wxS(".gz"), data);
       }
       if (gnuplotData != wxEmptyString) {
-        gnuplotDataFiles += gnuplotData + ".gz;";
-        const wxMemoryBuffer data = m_images[i]->GetCompressedGnuplotData();
+        gnuplotDataFiles += gnuplotData + wxS(".gz;");
+        const wxMemoryBuffer data = i->GetCompressedGnuplotData();
         if (data.GetDataLen() > 0)
-	  m_configuration->PushFileToSave(gnuplotData + ".gz", data);
+	  m_configuration->PushFileToSave(gnuplotData + wxS(".gz"), data);
       }
 
-      if (m_images[i]->GetCompressedImage())
-	m_configuration->PushFileToSave(basename + m_images[i]->GetExtension(),
-					m_images[i]->GetCompressedImage());
+      if (i->GetCompressedImage())
+	m_configuration->PushFileToSave(basename + i->GetExtension(),
+					i->GetCompressedImage());
+      images += basename + i->GetExtension() + wxS(";");
     }
-
-    images += basename + m_images[i]->GetExtension() + wxT(";");
   }
 
   wxString flags;
-  flags = " gnuplotSources_gz=\"" + gnuplotSourceFiles + "\"";
-  flags += " gnuplotData_gz=\"" + gnuplotDataFiles + "\"";
-  if (Length() > 0)
-    flags += wxString::Format(wxT(" ppi=\"%i\""), m_images[1]->GetPPI());
+  flags = wxS(" gnuplotSources_gz=\"") + gnuplotSourceFiles + wxS("\"");
+  flags += wxS(" gnuplotData_gz=\"") + gnuplotDataFiles + "\"";
+  if ((Length() > 0) && (m_images[0] != NULL))
+    flags += wxString::Format(wxS(" ppi=\"%i\""), m_images[0]->GetPPI());
   if (HasHardLineBreak())
-    flags += wxT(" breakline=\"true\"");
+    flags += wxS(" breakline=\"true\"");
   if (m_animationRunning)
-    flags += wxT(" running=\"true\"");
+    flags += wxS(" running=\"true\"");
   else
-    flags += wxT(" running=\"false\"");
-  flags += wxString::Format(wxT(" frame=\"%i\""), m_displayed);
+    flags += wxS(" running=\"false\"");
+  flags += wxString::Format(wxS(" frame=\"%i\""), m_displayed);
 
   if (m_framerate > 0)
-    flags += wxString::Format(wxT(" fr=\"%i\""), GetFrameRate());
-  return wxT("\n<slide") + flags + wxT(">") + images + wxT("</slide>");
+    flags += wxString::Format(wxS(" fr=\"%i\""), GetFrameRate());
+  return wxS("\n<slide") + flags + wxS(">") + images + wxS("</slide>");
 }
 
 void AnimationCell::SetPPI(int ppi) {
@@ -439,23 +427,23 @@ wxString AnimationCell::ToRTF() const {
   // image.
 
   // Lines that are common to all types of images
-  wxString header = wxT("{\\pict");
-  wxString footer = wxT("}\n");
+  wxString header = wxS("{\\pict");
+  wxString footer = wxS("}\n");
 
   // Extract the description of the image data
   wxString image;
   wxMemoryBuffer imgdata;
-  if (m_images[m_displayed]->GetExtension().Lower() == wxT("png")) {
+  if (m_images[m_displayed]->GetExtension().Lower() == wxS("png")) {
     imgdata = m_images[m_displayed]->GetCompressedImage();
-    image = wxT("\\pngblip\n");
-  } else if ((m_images[m_displayed]->GetExtension().Lower() == wxT("jpg")) ||
-             (m_images[m_displayed]->GetExtension().Lower() == wxT("jpeg"))) {
+    image = wxS("\\pngblip\n");
+  } else if ((m_images[m_displayed]->GetExtension().Lower() == wxS("jpg")) ||
+             (m_images[m_displayed]->GetExtension().Lower() == wxS("jpeg"))) {
     imgdata = m_images[m_displayed]->GetCompressedImage();
-    image = wxT("\\jpegblip\n");
+    image = wxS("\\jpegblip\n");
   } else {
     // Convert any non-rtf-enabled format to .png before adding it to the .rtf
     // file.
-    image = wxT("\\pngblip\n");
+    image = wxS("\\pngblip\n");
     wxImage imagedata =
       m_images[m_displayed]->GetUnscaledBitmap().ConvertToImage();
     wxMemoryOutputStream stream;
@@ -465,13 +453,13 @@ wxString AnimationCell::ToRTF() const {
   }
 
   image += wxString::Format(
-			    wxT("\\picw%lu\\pich%lu "),
+			    wxS("\\picw%lu\\pich%lu "),
 			    (unsigned long)m_images[m_displayed]->GetOriginalWidth(),
 			    (unsigned long)m_images[m_displayed]->GetOriginalHeight());
 
   // Convert the data into a hexadecimal string
   for (size_t i = 0; i <= imgdata.GetDataLen(); i++)
-    image += wxString::Format("%02x", ((unsigned char *)imgdata.GetData())[i]);
+    image += wxString::Format("%02x", (static_cast<unsigned char *>(imgdata.GetData()))[i]);
 
   return header + image + footer;
 }
@@ -497,10 +485,10 @@ wxSize AnimationCell::ToGif(wxString file) {
 
   wxImageArray gifFrames;
 
-  for (int i = 0; i < Length(); i++) {
+  for (const auto &i: m_images) {
     wxImage frame;
     // Reduce the frame to at most 256 colors
-    wxQuantize::Quantize(m_images[i]->GetUnscaledBitmap().ConvertToImage(),
+    wxQuantize::Quantize(i->GetUnscaledBitmap().ConvertToImage(),
                          frame);
     // Gif supports only fully transparent or not transparent at all.
     frame.ConvertAlphaToMask();
@@ -522,9 +510,9 @@ wxSize AnimationCell::ToGif(wxString file) {
 }
 
 void AnimationCell::ClearCache() {
-  for (int i = 0; i < Length(); i++)
-    if (m_images[i] != NULL)
-      m_images[i]->ClearCache();
+  for (auto &i: m_images)
+    if (i != NULL)
+      i->ClearCache();
 }
 
 AnimationCell::GifDataObject::GifDataObject(const wxMemoryOutputStream &str)
@@ -572,10 +560,10 @@ bool AnimationCell::CopyAnimationToClipboard() {
 
     wxImageArray gifFrames;
 
-    for (int i = 0; i < Length(); i++) {
+    for (auto &i: m_images) {
       wxImage frame;
       // Reduce the frame to at most 256 colors
-      wxQuantize::Quantize(m_images[i]->GetUnscaledBitmap().ConvertToImage(),
+      wxQuantize::Quantize(i->GetUnscaledBitmap().ConvertToImage(),
                            frame);
       // Gif supports only fully transparent or not transparent at all.
       frame.ConvertAlphaToMask();
@@ -596,4 +584,4 @@ bool AnimationCell::CopyAnimationToClipboard() {
   return false;
 }
 
-wxDataFormat AnimationCell::m_gifFormat(wxT("image/gif"));
+wxDataFormat AnimationCell::m_gifFormat(wxS("image/gif"));
