@@ -58,7 +58,7 @@ const wxString &Cell::GetToolTip(const wxPoint point) const {
 Cell::Cell(GroupCell *group, Configuration *config)
   : m_group(group), m_configuration(config), m_toolTip(&wxm::emptyString),
     m_fontSize_Scaled(-1) {
-  wxASSERT(group && (group->GetType() == MC_TYPE_GROUP || group == this));
+  wxASSERT((!group) || ((group->GetType() == MC_TYPE_GROUP || group == this)));
   InitBitFields();
   ResetSize();
 }
@@ -76,54 +76,53 @@ void Cell::SetType(CellType type) {
 
   switch (m_type) {
   case MC_TYPE_MAIN_PROMPT:
-    m_textStyle = TS_MAIN_PROMPT;
+    SetStyle(TS_MAIN_PROMPT);
     break;
   case MC_TYPE_PROMPT:
-    m_textStyle = TS_OTHER_PROMPT;
+    SetStyle(TS_OTHER_PROMPT);
     break;
   case MC_TYPE_LABEL:
-    m_textStyle = TS_LABEL;
+    SetStyle(TS_LABEL);
     // FIXME - this code probably intended to line-break here
     // HardLineBreak();
     break;
   case MC_TYPE_INPUT:
-    m_textStyle = TS_INPUT;
+    SetStyle(TS_CODE_DEFAULT);
     break;
   case MC_TYPE_ERROR:
-    m_textStyle = TS_ERROR;
+    SetStyle(TS_ERROR);
     break;
   case MC_TYPE_WARNING:
-    m_textStyle = TS_WARNING;
+    SetStyle(TS_WARNING);
     break;
   case MC_TYPE_TEXT:
-    m_textStyle = TS_TEXT;
+    SetStyle(TS_TEXT);
     break;
   case MC_TYPE_ASCIIMATHS:
-    m_textStyle = TS_ASCIIMATHS;
+    SetStyle(TS_ASCIIMATHS);
     break;
   case MC_TYPE_SUBSUBSECTION:
-    m_textStyle = TS_SUBSUBSECTION;
+    SetStyle(TS_SUBSUBSECTION);
     break;
   case MC_TYPE_HEADING5:
-    m_textStyle = TS_HEADING5;
+    SetStyle(TS_HEADING5);
     break;
   case MC_TYPE_HEADING6:
-    m_textStyle = TS_HEADING6;
+    SetStyle(TS_HEADING6);
     break;
   case MC_TYPE_SUBSECTION:
-    m_textStyle = TS_SUBSECTION;
+    SetStyle(TS_SUBSECTION);
     break;
   case MC_TYPE_SECTION:
-    m_textStyle = TS_SECTION;
+    SetStyle(TS_SECTION);
     break;
   case MC_TYPE_TITLE:
-    m_textStyle = TS_TITLE;
+    SetStyle(TS_TITLE);
     break;
   default:
-    m_textStyle = TS_DEFAULT;
+    SetStyle(TS_MATH);
     break;
   }
-  ResetSize();
   if ((m_group) && (m_group != this))
     GetGroup()->ResetSize();
 }
@@ -139,7 +138,7 @@ void Cell::CopyCommonData(const Cell &cell) {
 
   m_forceBreakLine = cell.m_forceBreakLine;
   m_type = cell.m_type;
-  m_textStyle = cell.m_textStyle;
+  SetStyle(cell.GetTextStyle());
   Hide(cell.m_isHidden);
   m_isHidableMultSign = cell.m_isHidableMultSign;
   if (cell.IsBrokenIntoLines())
@@ -150,7 +149,7 @@ std::unique_ptr<Cell> Cell::CopyList(GroupCell *group) const {
   CellListBuilder<> copy;
   for (auto &src : OnList(this))
     copy.Append(src.Copy(group));
-  return std::move(copy);
+  return copy;
 }
 
 std::unique_ptr<Cell> Cell::CopyList(GroupCell *group, const Cell *cell) {
@@ -202,6 +201,8 @@ bool Cell::NeedsRecalculation(AFontSize fontSize) const {
     return true;
   if (GetType() == MC_TYPE_GROUP)
     return false;
+  if(m_configuration->GetVisibleRegion().GetWidth() != m_visibleRegionWidth_last)
+    return false;
   return !EqualToWithin(Scale_Px(fontSize), m_fontSize_Scaled, 0.1f);
 }
 
@@ -270,20 +271,28 @@ int Cell::GetLineWidth() const {
   To make this work each derived class must draw the content of the cell
   and then call MathCall::Draw(...).
 */
-void Cell::Draw(wxPoint point) {
+void Cell::Draw(wxPoint point, wxDC *dc, wxDC *antialiassingDC) {
+  if(m_configuration->GetDebugmode())
+    {
+      if(!m_isHidden)
+	{
+	  wxASSERT(m_width >= 0);
+	  wxASSERT(m_height >= 0);
+	  wxASSERT(m_center >= 0);
+	}
+    }
   m_configuration->NotifyOfCellRedraw(this);
 
   if ((point.x >= 0) && (point.y >= 0))
     SetCurrentPoint(point);
 
   // Mark all cells that contain tooltips
-  if (!m_toolTip->empty() && (GetStyle() != TS_LABEL) &&
-      (GetStyle() != TS_USERLABEL) && m_configuration->ClipToDrawRegion() &&
+  if (!m_toolTip->empty() && (GetTextStyle() != TS_LABEL) &&
+      (GetTextStyle() != TS_USERLABEL) && m_configuration->ClipToDrawRegion() &&
       !m_configuration->GetPrinting() && !m_group->GetSuppressTooltipMarker() &&
       (!m_configuration->HideMarkerForThisMessage(*m_toolTip))) {
     wxRect rect = Cell::CropToUpdateRegion(GetRect());
     if (m_configuration->InUpdateRegion(rect) && !rect.IsEmpty()) {
-      wxDC *dc = m_configuration->GetDC();
       dc->SetPen(*wxTRANSPARENT_PEN);
       dc->SetBrush(m_configuration->GetTooltipBrush());
       dc->DrawRectangle(rect);
@@ -344,9 +353,15 @@ void Cell::SetAltCopyText(const wxString &text) {
 				GetInfo().GetName()));
 }
 
-void Cell::DrawList(wxPoint point) {
+void Cell::SetIsExponentList() {
+  for (Cell &tmp : OnList(this)) {
+    tmp.SetIsExponent();
+  }
+}
+
+void Cell::DrawList(wxPoint point, wxDC *dc, wxDC *adc) {
   for (Cell &tmp : OnDrawList(this)) {
-    tmp.Draw(point);
+    tmp.Draw(point, dc, adc);
     point.x += tmp.m_width;
   }
 }
@@ -363,12 +378,11 @@ void Cell::ResetSizeList() {
 
 void Cell::Recalculate(AFontSize fontsize) {
   m_fontSize_Scaled = Scale_Px(fontsize);
+  m_visibleRegionWidth_last = m_configuration->GetVisibleRegion().GetWidth();
   ResetCellListSizes();
   m_recalculateWidths = false;
 }
 
-/*! Is this cell currently visible in the window?.
- */
 bool Cell::DrawThisCell(wxPoint point) {
   SetCurrentPoint(point);
 
@@ -394,7 +408,7 @@ bool Cell::HasStaleSize() const {
 }
 
 bool Cell::HasValidPosition() const {
-  return (m_currentPoint.x >= 0) & (m_currentPoint.y >= 0);
+  return (m_currentPoint.x >= 0) && (m_currentPoint.y >= 0);
 }
 
 void Cell::SetConfigurationList(Configuration *config) {
@@ -428,7 +442,7 @@ bool Cell::InUpdateRegion() const {
     // scrolled by the user, or when maxima is updating it.
     wxRect cellRect;
     cellRect.SetPosition(m_currentPoint);
-    cellRect.SetWidth(m_configuration->GetClientWidth() - m_currentPoint.x);
+    cellRect.SetWidth(m_configuration->GetCanvasSize().x - m_currentPoint.x);
     if (m_next && m_next->HasValidPosition())
       cellRect.SetHeight(m_next->m_currentPoint.y - m_currentPoint.y);
     else
@@ -454,14 +468,14 @@ bool Cell::IsCompound() const {
 
 wxString Cell::ToString() const { return {}; }
 
-static const wxString space = wxT(" ");
+static const wxString space = wxS(" ");
 
 wxString Cell::VariablesAndFunctionsList() const {
   wxString retval;
   for (const Cell &tmp : OnDrawList(this)) {
-    if ((tmp.GetStyle() == TS_LABEL) || (tmp.GetStyle() == TS_USERLABEL) ||
-        (tmp.GetStyle() == TS_MAIN_PROMPT) || (tmp.GetStyle() == TS_VARIABLE) ||
-        (tmp.GetStyle() == TS_FUNCTION)) {
+    if ((tmp.GetTextStyle() == TS_LABEL) || (tmp.GetTextStyle() == TS_USERLABEL) ||
+        (tmp.GetTextStyle() == TS_MAIN_PROMPT) || (tmp.GetTextStyle() == TS_VARIABLE) ||
+        (tmp.GetTextStyle() == TS_FUNCTION)) {
       retval << tmp.ToString() << space;
     }
   }
@@ -474,22 +488,22 @@ wxString Cell::ListToString() const {
 
   for (const Cell &tmp : OnList(this)) {
     if ((!firstline) && (tmp.m_forceBreakLine)) {
-      if (!retval.EndsWith(wxT('\n')))
-        retval += wxT("\n");
+      if (!retval.EndsWith(wxS('\n')))
+        retval += wxS("\n");
       // if(
-      //    (tmp.GetStyle() != TS_LABEL) &&
-      //    (tmp.GetStyle() != TS_USERLABEL) &&
-      //    (tmp.GetStyle() != TS_MAIN_PROMPT) &&
-      //    (tmp.GetStyle() != TS_OTHER_PROMPT))
-      //   retval += wxT("\t");
+      //    (tmp.GetTextStyle() != TS_LABEL) &&
+      //    (tmp.GetTextStyle() != TS_USERLABEL) &&
+      //    (tmp.GetTextStyle() != TS_MAIN_PROMPT) &&
+      //    (tmp.GetTextStyle() != TS_OTHER_PROMPT))
+      //   retval += wxS("\t");
     }
     // if(firstline)
     // {
-    //   if((tmp.GetStyle() != TS_LABEL) &&
-    //      (tmp.GetStyle() != TS_USERLABEL) &&
-    //      (tmp.GetStyle() != TS_MAIN_PROMPT) &&
-    //      (tmp.GetStyle() != TS_OTHER_PROMPT))
-    //     retval += wxT("\t");
+    //   if((tmp.GetTextStyle() != TS_LABEL) &&
+    //      (tmp.GetTextStyle() != TS_USERLABEL) &&
+    //      (tmp.GetTextStyle() != TS_MAIN_PROMPT) &&
+    //      (tmp.GetTextStyle() != TS_OTHER_PROMPT))
+    //     retval += wxS("\t");
     // }
     retval += tmp.ToString();
 
@@ -506,22 +520,22 @@ wxString Cell::ListToMatlab() const {
 
   for (const Cell &tmp : OnDrawList(this)) {
     if ((!firstline) && (tmp.m_forceBreakLine)) {
-      if (!retval.EndsWith(wxT('\n')))
-        retval += wxT("\n");
+      if (!retval.EndsWith(wxS('\n')))
+        retval += wxS("\n");
       // if(
-      //    (tmp.GetStyle() != TS_LABEL) &&
-      //    (tmp.GetStyle() != TS_USERLABEL) &&
-      //    (tmp.GetStyle() != TS_MAIN_PROMPT) &&
-      //    (tmp.GetStyle() != TS_OTHER_PROMPT))
-      //   retval += wxT("\t");
+      //    (tmp.GetTextStyle() != TS_LABEL) &&
+      //    (tmp.GetTextStyle() != TS_USERLABEL) &&
+      //    (tmp.GetTextStyle() != TS_MAIN_PROMPT) &&
+      //    (tmp.GetTextStyle() != TS_OTHER_PROMPT))
+      //   retval += wxS("\t");
     }
     // if(firstline)
     // {
-    //   if((tmp.GetStyle() != TS_LABEL) &&
-    //      (tmp.GetStyle() != TS_USERLABEL) &&
-    //      (tmp.GetStyle() != TS_MAIN_PROMPT) &&
-    //      (tmp.GetStyle() != TS_OTHER_PROMPT))
-    //     retval += wxT("\t");
+    //   if((tmp.GetTextStyle() != TS_LABEL) &&
+    //      (tmp.GetTextStyle() != TS_USERLABEL) &&
+    //      (tmp.GetTextStyle() != TS_MAIN_PROMPT) &&
+    //      (tmp.GetTextStyle() != TS_OTHER_PROMPT))
+    //     retval += wxS("\t");
     // }
     retval += tmp.ToMatlab();
 
@@ -536,9 +550,9 @@ wxString Cell::ToTeX() const { return {}; }
 wxString Cell::ListToTeX() const {
   wxString retval;
   for (const Cell &tmp : OnList(this)) {
-    if (((!retval.IsEmpty()) && (tmp.m_textStyle == TS_LABEL)) ||
+    if (((!retval.IsEmpty()) && (tmp.GetTextStyle() == TS_LABEL)) ||
         (tmp.BreakLineHere()))
-      retval += wxT("\\]\\[");
+      retval += wxS("\\]\\[");
     retval += tmp.ToTeX();
   }
   return retval;
@@ -570,23 +584,23 @@ wxString Cell::ListToMathML(bool startofline) const {
   for (const Cell &tmp : OnList(this)) {
     // Do we need to end a highlighting region?
     if ((!tmp.m_highlight) && (highlight))
-      retval += wxT("</mrow>");
+      retval += wxS("</mrow>");
 
     // Handle linebreaks
     if ((&tmp != this) && (tmp.HasHardLineBreak()))
       retval +=
-	wxT("</mtd></mlabeledtr>\n<mlabeledtr columnalign=\"left\"><mtd>");
+	wxS("</mtd></mlabeledtr>\n<mlabeledtr columnalign=\"left\"><mtd>");
 
     // If a linebreak isn't followed by a label we need to introduce an empty
     // one.
     if ((((tmp.HasHardLineBreak()) || (startofline && (this == &tmp))) &&
-         ((tmp.GetStyle() != TS_LABEL) && (tmp.GetStyle() != TS_USERLABEL))) &&
+         ((tmp.GetTextStyle() != TS_LABEL) && (tmp.GetTextStyle() != TS_USERLABEL))) &&
         (needsTable))
-      retval += wxT("<mtext></mtext></mtd><mtd>");
+      retval += wxS("<mtext></mtext></mtd><mtd>");
 
     // Do we need to start a highlighting region?
     if ((tmp.m_highlight) && (!highlight))
-      retval += wxT("<mrow mathcolor=\"red\">");
+      retval += wxS("<mrow mathcolor=\"red\">");
     highlight = tmp.m_highlight;
 
     retval += tmp.ToMathML();
@@ -595,17 +609,17 @@ wxString Cell::ListToMathML(bool startofline) const {
   // If the region we converted to MathML ended within a highlighted region
   // we need to close this region now.
   if (highlight)
-    retval += wxT("</mrow>");
+    retval += wxS("</mrow>");
 
   // If we grouped multiple cells as a single object we need to cose this group
   // now
   if ((multiCell) && (!needsTable))
-    retval = wxT("<mrow>") + retval + wxT("</mrow>\n");
+    retval = wxS("<mrow>") + retval + wxS("</mrow>\n");
 
   // If we put the region we exported into a table we need to end this table now
   if (needsTable)
-    retval = wxT("<mtable>\n<mlabeledtr columnalign=\"left\"><mtd>") + retval +
-      wxT("</mtd></mlabeledtr>\n</mtable>");
+    retval = wxS("<mtable>\n<mlabeledtr columnalign=\"left\"><mtd>") + retval +
+      wxS("</mtd></mlabeledtr>\n</mtable>");
   return retval;
 }
 
@@ -615,14 +629,14 @@ wxString Cell::OMML2RTF(wxXmlNode *node) {
   while (node != NULL) {
     if (node->GetType() == wxXML_ELEMENT_NODE) {
       wxString ommlname = node->GetName();
-      result += wxT("{\\m") + ommlname.Right(ommlname.Length() - 2);
+      result += wxS("{\\m") + ommlname.Right(ommlname.Length() - 2);
 
       // Convert the attributes
       wxXmlAttribute *attributes = node->GetAttributes();
       while (attributes != NULL) {
         wxString ommlatt = attributes->GetName();
-        result += wxT("{\\m") + ommlatt.Right(ommlatt.Length() - 2) + wxT(" ") +
-	  attributes->GetValue() + wxT("}");
+        result += wxS("{\\m") + ommlatt.Right(ommlatt.Length() - 2) + wxS(" ") +
+	  attributes->GetValue() + wxS("}");
         attributes = attributes->GetNext();
       }
 
@@ -630,9 +644,9 @@ wxString Cell::OMML2RTF(wxXmlNode *node) {
       if (node->GetChildren() != NULL) {
         result += OMML2RTF(node->GetChildren());
       }
-      result += wxT("}");
+      result += wxS("}");
     } else
-      result += wxT(" ") + RTFescape(node->GetContent());
+      result += wxS(" ") + RTFescape(node->GetContent());
 
     node = node->GetNext();
   }
@@ -645,49 +659,49 @@ wxString Cell::OMML2RTF(wxString ommltext) {
 
   wxString result;
   wxXmlDocument ommldoc;
-  ommltext = wxT("<m:r>") + ommltext + wxT("</m:r>");
+  ommltext = wxS("<m:r>") + ommltext + wxS("</m:r>");
 
   wxStringInputStream ommlStream(ommltext);
 
-  ommldoc.Load(ommlStream, wxT("UTF-8"));
+  ommldoc.Load(ommlStream, wxS("UTF-8"));
 
   wxXmlNode *node = ommldoc.GetRoot();
   result += OMML2RTF(node);
 
-  if (!result.empty() && (result != wxT("\\mr"))) {
-    result = wxT("{\\mmath {\\*\\moMath") + result + wxT("}}");
+  if (!result.empty() && (result != wxS("\\mr"))) {
+    result = wxS("{\\mmath {\\*\\moMath") + result + wxS("}}");
   }
   return result;
 }
 
 wxString Cell::XMLescape(wxString input) {
-  input.Replace(wxT("&"), wxT("&amp;"));
-  input.Replace(wxT("<"), wxT("&lt;"));
-  input.Replace(wxT(">"), wxT("&gt;"));
-  input.Replace(wxT("'"), wxT("&apos;"));
-  input.Replace(wxT("\""), wxT("&quot;"));
+  input.Replace(wxS("&"), wxS("&amp;"));
+  input.Replace(wxS("<"), wxS("&lt;"));
+  input.Replace(wxS(">"), wxS("&gt;"));
+  input.Replace(wxS("'"), wxS("&apos;"));
+  input.Replace(wxS("\""), wxS("&quot;"));
   return input;
 }
 
 wxString Cell::RTFescape(wxString input, bool MarkDown) {
   // Characters with a special meaning in RTF
-  input.Replace("\\", "\\\\");
-  input.Replace("{", "\\{");
-  input.Replace("}", "\\}");
-  input.Replace(wxT("\r"), "\n");
+  input.Replace(wxS("\\"), wxS("\\\\"));
+  input.Replace(wxS("{"), wxS("\\{"));
+  input.Replace(wxS("}"), wxS("\\}"));
+  input.Replace(wxS("\r"), wxS("\n"));
 
   // The Character we will use as a soft line break
-  input.Replace("\r", wxm::emptyString);
+  input.Replace(wxS("\r"), wxm::emptyString);
 
   // Encode unicode characters in a rather mind-boggling way
   wxString output;
   for (size_t i = 0; i < input.Length(); i++) {
     wxChar ch = input[i];
-    if (ch == wxT('\n')) {
-      if (((i > 0) && (input[i - 1] == wxT('\n'))) || !MarkDown)
-        output += wxT("\\par}\n{\\pard ");
+    if (ch == wxS('\n')) {
+      if (((i > 0) && (input[i - 1] == wxS('\n'))) || !MarkDown)
+        output += wxS("\\par}\n{\\pard ");
       else
-        output += wxT("\n");
+        output += wxS("\n");
     } else {
       if ((ch < 128) && (ch > 0)) {
         output += ch;
@@ -729,7 +743,7 @@ wxString Cell::ListToOMML(bool WXUNUSED(startofline)) const {
   }
 
   if (multiCell && !retval.empty())
-    return wxT("<m:r>") + retval + wxT("</m:r>");
+    return wxS("<m:r>") + retval + wxS("</m:r>");
   else
     return retval;
 }
@@ -740,15 +754,15 @@ wxString Cell::ListToRTF(bool startofline) const {
   for (const Cell *tmp = this; tmp != NULL;) {
     wxString rtf = tmp->ToRTF();
     if (!rtf.empty()) {
-      if ((GetStyle() == TS_LABEL) || ((GetStyle() == TS_USERLABEL))) {
+      if ((GetTextStyle() == TS_LABEL) || ((GetTextStyle() == TS_USERLABEL))) {
         retval +=
-	  wxT("\\par}\n{\\pard\\s22\\li1105\\lin1105\\fi-1105\\f0\\fs24 ") +
-	  rtf + wxT("\\tab");
+	  wxS("\\par}\n{\\pard\\s22\\li1105\\lin1105\\fi-1105\\f0\\fs24 ") +
+	  rtf + wxS("\\tab");
         startofline = false;
       } else {
         if (startofline)
-          retval += wxT("\\par}\n{\\pard\\s21\\li1105\\lin1105\\f0\\fs24 ") +
-	    rtf + wxT("\\n");
+          retval += wxS("\\par}\n{\\pard\\s21\\li1105\\lin1105\\f0\\fs24 ") +
+	    rtf + wxS("\\n");
         startofline = true;
       }
       tmp = tmp->GetNext();
@@ -758,7 +772,7 @@ wxString Cell::ListToRTF(bool startofline) const {
 
         // set the style for this line.
         if (startofline)
-          retval += wxT("\\pard\\s21\\li1105\\lin1105\\f0\\fs24 ");
+          retval += wxS("\\pard\\s21\\li1105\\lin1105\\f0\\fs24 ");
 
         retval += OMML2RTF(tmp->ListToOMML());
 
@@ -798,12 +812,12 @@ wxString Cell::ListToXML() const {
 
   for (const Cell &tmp : OnList(this)) {
     if ((tmp.GetHighlight()) && (!highlight)) {
-      retval += wxT("<hl boxname=\"highlight\">\n");
+      retval += wxS("<hl boxname=\"highlight\">\n");
       highlight = true;
     }
 
     if ((!tmp.GetHighlight()) && (highlight)) {
-      retval += wxT("</hl>\n");
+      retval += wxS("</hl>\n");
       highlight = false;
     }
 
@@ -811,22 +825,18 @@ wxString Cell::ListToXML() const {
   }
 
   if (highlight) {
-    retval += wxT("</hl>\n");
+    retval += wxS("</hl>\n");
   }
 
   return retval;
 }
 
-/***
- * Get the part for diff tag support - only ExptCell and SubSupCell override
- * this.
- */
 wxString Cell::GetDiffPart() const {
   wxString s = ToString();
   if (s == wxEmptyString)
     return s;
 
-  return wxT(",") + s + wxT(",1");
+  return wxS(",") + s + wxS(",1");
 }
 
 Cell::Range Cell::GetCellsInRect(const wxRect &rect) const {
@@ -889,9 +899,9 @@ void Cell::ResetDataList() {
 }
 
 void Cell::ResetCellListSizesList() {
-  for (Cell &cell : OnList(this)) {
+  for (const Cell &cell : OnList(this)) {
     cell.ResetCellListSizes();
-    for (Cell &tmp : OnList(&cell))
+    for (const Cell &tmp : OnList(&cell))
       tmp.ResetCellListSizes();
   }
 }
@@ -904,7 +914,7 @@ void Cell::ResetSize() {
   m_maxDrop.Invalidate();
 }
 
-void Cell::ResetCellListSizes() {
+void Cell::ResetCellListSizes() const {
   m_fullWidth.Invalidate();
   m_lineWidth.Invalidate();
   m_maxCenter.Invalidate();
@@ -949,15 +959,12 @@ void Cell::Unbreak() {
   if (m_isBrokenIntoLines) {
     ResetData();
     m_recalculateWidths = true;
+    m_isBrokenIntoLines = false;
+    // Unbreak the inner cells, too
+    for (Cell &cell : OnInner(this))
+      cell.UnbreakList();
+    SetNextToDraw(m_next);
   }
-
-  m_isBrokenIntoLines = false;
-  SetNextToDraw(m_next);
-
-  // Unbreak the inner cells, too
-  for (Cell &cell : OnInner(this))
-    for (Cell &tmp : OnList(&cell))
-      tmp.Unbreak();
 }
 
 void Cell::UnbreakList() {
@@ -969,12 +976,8 @@ wxColour Cell::GetForegroundColor() const {
   wxColour color;
   if (m_highlight)
     color = m_configuration->GetColor(TS_HIGHLIGHT);
-  else if (m_type == MC_TYPE_PROMPT)
-    color = m_configuration->GetColor(TS_OTHER_PROMPT);
-  else if (m_type == MC_TYPE_INPUT)
-    color = m_configuration->GetColor(TS_INPUT);
-  else
-    color = m_configuration->GetColor(TS_DEFAULT);
+  else 
+    color = m_configuration->GetColor(GetTextStyle());
 
   return color;
 }
@@ -982,33 +985,23 @@ wxColour Cell::GetForegroundColor() const {
 // cppcheck-suppress functionStatic
 // cppcheck-suppress functionConst
 // Set the pen in device context according to the style of the cell.
-void Cell::SetPen(double lineWidth) const {
-  wxDC *dc = m_configuration->GetDC();
-
+void Cell::SetPen(wxDC *dc, double lineWidth) const {
   wxPen pen = *(wxThePenList->FindOrCreatePen(
-					      GetForegroundColor(), lineWidth * m_configuration->GetDefaultLineWidth(),
+					      GetForegroundColor(),
+					      lineWidth * m_configuration->GetDefaultLineWidth(),
 					      wxPENSTYLE_SOLID));
   dc->SetPen(pen);
-
-  if (m_configuration->GetAntialiassingDC() != dc)
-    m_configuration->GetAntialiassingDC()->SetPen(pen);
 }
 
-void Cell::SetBrush() const {
-  wxDC *dc = m_configuration->GetDC();
-
+void Cell::SetBrush(wxDC *dc) const {  
   wxBrush brush = *(wxTheBrushList->FindOrCreateBrush(GetForegroundColor()));
   dc->SetBrush(brush);
-
-  if (m_configuration->GetAntialiassingDC() != dc)
-    m_configuration->GetAntialiassingDC()->SetBrush(brush);
 }
 
 const wxString &Cell::GetValue() const { return wxm::emptyString; }
 
-void Cell::SetForeground() {
+void Cell::SetTextColor(wxDC *dc) {
   wxColour color;
-  wxDC *dc = m_configuration->GetDC();
   if (m_highlight) {
     color = m_configuration->GetColor(TS_HIGHLIGHT);
   } else {
@@ -1020,7 +1013,7 @@ void Cell::SetForeground() {
       color = m_configuration->GetColor(TS_MAIN_PROMPT);
       break;
     case MC_TYPE_ERROR:
-      color = wxColour(wxT("red"));
+      color = wxColour(wxS("red"));
       break;
     case MC_TYPE_WARNING:
       color = m_configuration->GetColor(TS_WARNING);
@@ -1029,17 +1022,16 @@ void Cell::SetForeground() {
       color = m_configuration->GetColor(TS_LABEL);
       break;
     default:
-      color = m_configuration->GetColor(m_textStyle);
+      color = m_configuration->GetColor(GetTextStyle());
       break;
     }
   }
-
   dc->SetTextForeground(color);
 }
 
 bool Cell::IsMath() const {
-  return !(m_textStyle == TS_LABEL || m_textStyle == TS_USERLABEL ||
-           m_textStyle == TS_INPUT);
+  return !(GetTextStyle() == TS_LABEL || GetTextStyle() == TS_USERLABEL ||
+           GetTextStyle() == TS_CODE_DEFAULT);
 }
 
 #if wxUSE_ACCESSIBILITY
@@ -1114,7 +1106,7 @@ wxAccStatus CellAccessible::GetChildCount(int *childCount) {
     return wxACC_FAIL;
 
   int count = 0;
-  for (Cell &cell : OnInner(m_cell))
+  for (const Cell &cell : OnInner(m_cell))
     ++count;
 
   return (*childCount = count), wxACC_OK;
