@@ -101,10 +101,10 @@ class Observed
     void LogDeref(const CellPtrBase *) const;
     void LogDestruct() const;
 #else
-    void LogConstruct(const Observed *) const {}
-    void LogRef(const CellPtrBase *) const {}
-    void LogDeref(const CellPtrBase *) const {}
-    void LogDestruct() const {}
+    static void LogConstruct(const Observed *) {}
+    static void LogRef(const CellPtrBase *) {}
+    static void LogDeref(const CellPtrBase *) {}
+    static void LogDestruct() {}
 #endif
 
   public:
@@ -167,6 +167,8 @@ class Observed
       to_MASK = 3,
       to_MASK_OUT = uintptr_t(-intptr_t(to_MASK + 1)),
     };
+    // TODO: Does this make sense? "| to_Observed" is "| 0". Is this a bug or is
+    // it meant as a readable zero?
     static uintptr_t ReprFor(Observed *ptr) noexcept
       { return reinterpret_cast<uintptr_t>(ptr) | to_Observed; }
     static uintptr_t ReprFor(ControlBlock *ptr) noexcept
@@ -228,8 +230,8 @@ class Observed
   void LogRef(const CellPtrBase *) const;
   void LogDeref(const CellPtrBase *) const;
 #else
-  void LogRef(const CellPtrBase *) const {}
-  void LogDeref(const CellPtrBase *) const {}
+  static void LogRef(const CellPtrBase *) {}
+  static void LogDeref(const CellPtrBase *) {}
 #endif
 
 protected:
@@ -270,6 +272,7 @@ class GroupCell;
  * 3. One of many pointers to the object: its m_ptr points to the Observed::ControlBlock,
  *    and the observed's m_ptr *also* points to the control block.
  */
+// cppcheck-suppress ctuOneDefinitionRuleViolation
 class CellPtrBase
 {
   using CellPtrImplPointer = Observed::CellPtrImplPointer;
@@ -302,10 +305,10 @@ class CellPtrBase
   void LogAssignment(const CellPtrBase &o) const;
   void LogDestruction() const;
 #else
-  inline void LogConstruction(Observed *) const {}
-  inline void LogMove(const CellPtrBase &) const {}
-  inline void LogAssignment(const CellPtrBase &) const {}
-  inline void LogDestruction() const {}
+  static inline void LogConstruction(Observed *) {}
+  static inline void LogMove(const CellPtrBase &) {}
+  static inline void LogAssignment(const CellPtrBase &) {}
+  static inline void LogDestruction() {}
 #endif
 
 protected:
@@ -663,7 +666,7 @@ std::unique_ptr<Derived> dynamic_unique_ptr_cast(std::unique_ptr<Base>&& p) noex
 {
   auto d = dynamic_cast<Derived *>(p.get());
   if (d)
-    p.release();
+    (void) p.release();
   return std::unique_ptr<Derived>(d);
   // Note: We don't move the deleter, since it's not special.
 }
