@@ -39,16 +39,16 @@ DigitCell::DigitCell(GroupCell *group, Configuration *config,
   : TextCell(group, config, text, style) {}
 
 DigitCell::DigitCell(GroupCell *group, const DigitCell &cell)
-  : DigitCell(group, cell.m_configuration, cell.m_text, cell.GetStyle()) {}
+  : DigitCell(group, cell.m_configuration, cell.m_text, cell.GetTextStyle()) {}
 
 DEFINE_CELL(DigitCell)
 
 void DigitCell::Recalculate(AFontSize fontsize) {
   if (NeedsRecalculation(fontsize)) {
     Cell::Recalculate(fontsize);
-    SetFont(m_fontSize_Scaled);
+    SetFont(m_configuration->GetRecalcDC(), m_fontSize_Scaled);
     wxSize sz =
-      CalculateTextSize(m_configuration->GetDC(), m_displayedText, cellText);
+      CalculateTextSize(m_configuration->GetRecalcDC(), m_displayedText, cellText);
     m_width = sz.GetWidth();
     m_height = sz.GetHeight();
     m_height += 2 * MC_TEXT_PADDING;
@@ -56,12 +56,11 @@ void DigitCell::Recalculate(AFontSize fontsize) {
   }
 }
 
-void DigitCell::Draw(wxPoint point) {
-  Cell::Draw(point);
+void DigitCell::Draw(wxPoint point, wxDC *dc, wxDC *antialiassingDC) {
+  Cell::Draw(point, dc, antialiassingDC);
   if (DrawThisCell(point)) {
-    wxDC *dc = m_configuration->GetDC();
-    SetForeground();
-    SetFont(m_fontSize_Scaled);
+    SetTextColor(dc);
+    SetFont(dc, m_fontSize_Scaled);
     dc->DrawText(m_text, point.x, point.y - m_center + MC_TEXT_PADDING);
   }
 }
