@@ -40,7 +40,7 @@ public:
   const CellTypeInfo &GetInfo() override;
 
   void Recalculate(AFontSize fontsize) override;
-  void Draw(wxPoint point) override;
+  void Draw(wxPoint point, wxDC *dc, wxDC *antialiassingDC) override;
 };
 
 #endif // DIGITCELL_H
