@@ -29,6 +29,7 @@
 #include "MaximaTokenizer.h"
 #include <vector>
 #include <list>
+#include <unordered_map>
 
 /*! \file
 
@@ -113,7 +114,7 @@ public:
     \param posInLine The number of characters that come before the input in the same line
     \todo Implement the actual TAB expansion
   */
-  static wxString TabExpand(const wxString &input, long posInLine);
+  static wxString TabExpand(const wxString &input_, long posInLine);
 
   //! Escape all chars that cannot be used in HTML otherwise
   static wxString EscapeHTMLChars(wxString input);
@@ -123,7 +124,7 @@ public:
 
   void Recalculate(AFontSize fontsize) override;
 
-  virtual void Draw(wxPoint point) override;
+  virtual void Draw(wxPoint point, wxDC *dc, wxDC *antialiassingDC) override;
 
   //! Convert the current cell to HTML code.
   wxString ToHTML() const;
@@ -145,11 +146,15 @@ public:
   //! Convert the current cell to XML code for inclusion in a .wxmx file.
   wxString ToXML() const override;
 
+  //! Get the font that matches this cell's formatting
+  const wxFont &GetFont() const {
+    return m_configuration->GetStyle(GetTextStyle())->GetFont(m_fontSize_Scaled);
+  }
   //! Set the currently used font to the one that matches this cell's formatting
-  void SetFont();
+  void SetFont(wxDC *dc) const;
 
   //! Sets the current color to this cell's foreground color
-  void SetForeground();
+  void SetForeground(wxDC *dc);
 
   /*! Sets the text that is to be displayed.
     
@@ -185,8 +190,10 @@ public:
     
     Automatically calls DeactivateCursor on an eventual cell the cursor currently is in.
     Normally Mathctrl::SetActiveCell() is used in order to get this function called.
+
+    \return true, if recalculation is needed.
   */
-  void ActivateCursor();
+  bool ActivateCursor();
 
   //! Deactivate the blinking cursor in the EditorCell it is in.
   void DeactivateCursor();
@@ -359,6 +366,7 @@ public:
   /*! Replaces all occurrences of a given string
    */
   int ReplaceAll(wxString oldString, const wxString &newString, bool ignoreCase);
+  int ReplaceAll_RegEx(wxString oldString, const wxString &newString);
 
   /*! Finds the next occurrences of a string
 
@@ -371,6 +379,7 @@ public:
     - false: Case-sensitive search
   */
   bool FindNext(wxString str, const bool &down, const bool &ignoreCase);
+  bool FindNext_RegEx(wxString str, const bool &down);
 
   bool IsSelectionChanged() const { return m_selectionChanged; }
 
@@ -397,6 +406,7 @@ public:
   bool ReplaceSelection(const wxString &oldStr, const wxString &newString,
                         bool keepSelected = false, bool ignoreCase = false,
                         bool replaceMaximaString = false);
+  bool ReplaceSelection_RegEx(const wxString &oldStr, const wxString &newString);
 
   //! Convert the current selection to a string
   wxString GetSelectionString() const;
@@ -466,11 +476,11 @@ public:
     }
 
   //! Get the list of commands, parenthesis, strings and whitespaces in a code cell
-  const MaximaTokenizer::TokenList &GetTokens();
+  const MaximaTokenizer::TokenList &GetDisplayedTokens();
+  //! Get the list of commands, parenthesis, strings and whitespaces including hidden ones
+  const MaximaTokenizer::TokenList &GetAllTokens();
 
 private:
-  MaximaTokenizer::TokenList m_tokens_including_hidden;
-
   //! Did the zoom factor change since the last recalculation?
   bool IsZoomFactorChanged() const;
   //! The zoom factor we had the last time we recalculated this cell.
@@ -488,7 +498,8 @@ private:
   class StyledText
   {
   private:
-    //! The text of this text portion
+    /*! The text of this text portion
+     */
     wxString m_text;
     //! Chars that mark continued indentation
     wxString m_indentChar;
@@ -497,7 +508,7 @@ private:
     //! By How many pixels we want to indent this line?
     int m_indentPixels = 0;
     //! The color of this text portion
-    TextStyle m_style = TS_DEFAULT;
+    TextStyle m_style = TS_CODE_DEFAULT;
     //! Do we really want to style this text portion different than the default?
     bool m_styleThisText = false;
   public:
@@ -529,7 +540,7 @@ private:
     const wxString &GetIndentChar() const { return m_indentChar; }
     //! If IsStyleSet() is true this function returns the style of this text
     //! portion
-    TextStyle GetStyle() const { return m_style; }
+    TextStyle GetTextStyle() const { return m_style; }
     // Has an individual text style been set for this text portion?
     bool IsStyleSet() const { return m_styleThisText; }
   };
@@ -569,10 +580,10 @@ private:
     TextCell::ToTeX and EditorCell::ToTeX. They can also be
     converted to maxima strings in wxMaxima::SendMaxima.
   */
-  wxString InterpretEscapeString(const wxString &txt) const;
+  static wxString InterpretEscapeString(const wxString &txt);
 
   //! Draw a box that marks the current selection
-  void MarkSelection(long start, long end, TextStyle style);
+  void MarkSelection(wxDC *dc, long start, long end, TextStyle style);
 
   //! Determines the size of a text snippet
   wxSize GetTextSize(const wxString &text);
@@ -591,10 +602,15 @@ private:
   void SetState(const HistoryEntry &state);
   //! Append the editor's state to the history
   void AppendStateToHistory();
+  std::vector<StyledText> &GetStyledText();
 
 //** Large fields
 //**
+#if wxCHECK_VERSION(3, 3, 0) || wxUSE_STL
+  typedef std::unordered_map <wxString, wxSize> StringHash;
+#else
   WX_DECLARE_STRING_HASH_MAP(wxSize, StringHash);
+#endif
   //! Cached widths of text snippets, one width per style
   StringHash m_widths;
 
@@ -602,8 +618,12 @@ private:
   std::vector<wxString> m_wordList;
 
   //! The individual commands, parenthesis, strings and whitespaces a code cell consists of
-  MaximaTokenizer::TokenList m_tokens;
+   MaximaTokenizer::TokenList m_tokens;
+  //! The individual commands, parenthesis, strings and whitespaces including hidden lines
+  MaximaTokenizer::TokenList m_tokens_including_hidden;
 
+  /*! The text this Editor contains
+   */
   wxString m_text;
   std::vector<StyledText> m_styledText;
 
@@ -611,7 +631,6 @@ private:
 
 //** 8/4 bytes
 //**
-  AFontName m_fontName;
   CellPointers *const m_cellPointers = GetCellPointers();
 
 //** 4 bytes
@@ -655,6 +674,13 @@ private:
   AFontStyle m_fontStyle;
   AFontWeight m_fontWeight;
 
+
+  //! Does the list of tokens including hidden items need to be recalculated?
+  bool m_tokens_including_hidden_valid = false;
+  //! Does the list of displayed tokens need to be recalculated?
+  bool m_tokens_valid = false;
+
+
 //** Bitfield objects (2 bytes)
 //**
   void InitBitFields()
