@@ -65,7 +65,7 @@ public:
 
   void Recalculate(AFontSize fontsize) override;
 
-  void Draw(wxPoint point) override;
+  void Draw(wxPoint point, wxDC *dc, wxDC *antialiassingDC) override;
 
   wxString ToMathML() const override;
   wxString ToMatlab() const override;
@@ -94,7 +94,7 @@ private:
 
 //** Bitfield objects (0 bytes)
 //**
-  void InitBitFields()
+  static void InitBitFields()
     { // Keep the initialization order below same as the order
       // of bit fields in this class!
     }
