@@ -70,7 +70,7 @@ int ImgCell::s_counter = 0;
 
 // constructor which load image
 ImgCell::ImgCell(GroupCell *group, Configuration *config, const wxString &image,
-                 std::shared_ptr<wxFileSystem> filesystem, bool remove)
+                 std::shared_ptr<wxFileSystem> &filesystem, bool remove)
   : ImgCellBase(group, config), m_imageBorderWidth(1) {
   InitBitFields();
   m_type = MC_TYPE_IMAGE;
@@ -98,7 +98,7 @@ ImgCell::ImgCell(GroupCell *group, const ImgCell &cell)
 DEFINE_CELL(ImgCell)
 
 void ImgCell::ReloadImage(const wxString &image,
-                          std::shared_ptr<wxFileSystem> filesystem) {
+                          std::shared_ptr<wxFileSystem> &filesystem) {
   // Store old size limits
   double width = m_image->GetMaxWidth();
   double height = m_image->GetHeightList();
@@ -168,20 +168,19 @@ void ImgCell::Recalculate(AFontSize fontsize) {
   Cell::Recalculate(fontsize);
 }
 
-void ImgCell::Draw(wxPoint point) {
-  Cell::Draw(point);
+void ImgCell::Draw(wxPoint point, wxDC *dc, wxDC *antialiassingDC) {
+  Cell::Draw(point, dc, antialiassingDC);
   if (DrawThisCell(point) && (m_image != NULL)) {
     if (!InUpdateRegion())
       return;
 
-    wxDC *dc = m_configuration->GetDC();
     wxMemoryDC bitmapDC;
 
     if (m_drawBoundingBox)
-      dc->SetBrush(*(wxTheBrushList->FindOrCreateBrush(
-						       m_configuration->GetColor(TS_SELECTION))));
+	dc->SetBrush(*(wxTheBrushList->FindOrCreateBrush(
+							 m_configuration->GetColor(TS_SELECTION))));
     else
-      SetPen();
+      SetPen(dc);
 
     if (m_drawRectangle || m_drawBoundingBox)
       dc->DrawRectangle(wxRect(point.x, point.y - m_center, m_width, m_height));
@@ -211,8 +210,11 @@ void ImgCell::Draw(wxPoint point) {
     } else
       dc->Blit(xDst, yDst, widthDst, heightDst, &bitmapDC, xSrc, ySrc);
   } else
-    // The cell isn't drawn => No need to keep it's image cache for now.
-    ClearCache();
+    {
+      // The cell isn't drawn => No need to keep it's image cache for now.
+      if(!GetRect().Intersects(m_configuration->GetVisibleRegion()))
+	ClearCache();
+    }
 
   // The next time we need to draw a bounding box we will be informed again.
   m_drawBoundingBox = false;
@@ -230,7 +232,7 @@ wxSize ImgCell::ToImageFile(wxString filename) {
 
 static void writeHex(void *data, size_t length, wxStringBuffer::CharType *out) {
   using char_t = std::remove_reference_t<decltype(*out)>;
-  char *const end = static_cast<char *>(data) + length;
+  const char *const end = static_cast<char *>(data) + length;
   for (char *in = static_cast<char *>(data); in != end; in++) {
     char c = *in;
     unsigned char const h = (c >> 4) & 0xF, l = c & 0xF;
@@ -247,23 +249,23 @@ static void writeHex(void *data, size_t length, wxStringBuffer::CharType *out) {
 
 wxString ImgCell::ToRTF() const {
   // Lines that are common to all types of images
-  wxString header = wxT("{\\pict");
-  wxString footer = wxT("}\n");
+  wxString header = wxS("{\\pict");
+  wxString footer = wxS("}\n");
 
   // Extract the description of the image data
   wxString image;
   wxMemoryBuffer imgdata;
-  if (m_image->GetExtension().Lower() == wxT("png")) {
+  if (m_image->GetExtension().Lower() == wxS("png")) {
     imgdata = GetCompressedImage();
-    image = wxT("\\pngblip");
-  } else if ((m_image->GetExtension().Lower() == wxT("jpg")) ||
-             (m_image->GetExtension().Lower() == wxT("jpeg"))) {
+    image = wxS("\\pngblip");
+  } else if ((m_image->GetExtension().Lower() == wxS("jpg")) ||
+             (m_image->GetExtension().Lower() == wxS("jpeg"))) {
     imgdata = GetCompressedImage();
-    image = wxT("\\jpegblip");
+    image = wxS("\\jpegblip");
   } else {
     // Convert any non-rtf-enabled format to .png before adding it to the .rtf
     // file.
-    image = wxT("\\pngblip");
+    image = wxS("\\pngblip");
     wxImage imagedata = m_image->GetUnscaledBitmap().ConvertToImage();
     wxMemoryOutputStream stream;
     imagedata.SaveFile(stream, wxBITMAP_TYPE_PNG);
@@ -271,7 +273,7 @@ wxString ImgCell::ToRTF() const {
                        stream.GetOutputStreamBuffer()->GetBufferSize());
   }
 
-  image += wxString::Format(wxT("\\picw%lu\\pich%lu "),
+  image += wxString::Format(wxS("\\picw%lu\\pich%lu "),
                             (unsigned long)m_image->GetOriginalWidth(),
                             (unsigned long)m_image->GetOriginalHeight());
 
@@ -298,23 +300,26 @@ wxString ImgCell::ToXML() const {
 
   wxString flags;
   if (HasHardLineBreak())
-    flags += wxT(" breakline=\"true\"");
+    flags += wxS(" breakline=\"true\"");
 
-  flags += wxString::Format(wxT(" ppi=\"%i\""), m_image->GetPPI());
+  if (m_image)
+    flags += wxString::Format(wxS(" ppi=\"%i\""), m_image->GetPPI());
 
   if (!m_drawRectangle)
-    flags += wxT(" rect=\"false\"");
-
-  if (m_image->GetMaxWidth() > 0)
-    flags += wxString::Format(wxT(" maxWidth=\"%f\""), m_image->GetMaxWidth());
-
-  if (m_image->GetHeightList() > 0)
-    flags +=
-      wxString::Format(wxT(" maxHeight=\"%f\""), m_image->GetHeightList());
+    flags += wxS(" rect=\"false\"");
 
+  if (m_image)
+    {
+      if (m_image->GetMaxWidth() > 0)
+	flags += wxString::Format(wxS(" maxWidth=\"%f\""), m_image->GetMaxWidth());
+      if (m_image->GetHeightList() > 0)
+	flags +=
+	  wxString::Format(wxS(" maxHeight=\"%f\""), m_image->GetHeightList());
+    }
+  
   if (m_origImageFile != wxEmptyString) {
     if (m_configuration->SaveImgFileName()) {
-      flags += wxString::Format(wxT(" origImageFile=\"%s\""),
+      flags += wxString::Format(wxS(" origImageFile=\"%s\""),
                                 XMLescape(m_origImageFile));
     }
   }
@@ -323,22 +328,27 @@ wxString ImgCell::ToXML() const {
     // Anonymize the name of our temp directory for saving
     if (m_image->GnuplotData() != wxEmptyString) {
       wxFileName gnuplotDataFile(m_image->GnuplotData());
-      wxString gnuplotData = gnuplotDataFile.GetFullName() + wxT(".gz");
+      wxString gnuplotData = gnuplotDataFile.GetFullName() + wxS(".gz");
       m_configuration->PushFileToSave(gnuplotData,
 				      m_image->GetCompressedGnuplotData());
-      flags += " gnuplotdata_gz=\"" + gnuplotData + "\"";
+      flags += wxS(" gnuplotdata_gz=\"") + gnuplotData + wxS("\"");
     }
     if (m_image->GnuplotSource() != wxEmptyString) {
       wxFileName gnuplotSourceFile(m_image->GnuplotSource());
-      wxString gnuplotSource = gnuplotSourceFile.GetFullName() + wxT(".gz");
+      wxString gnuplotSource = gnuplotSourceFile.GetFullName() + wxS(".gz");
       m_configuration->PushFileToSave(gnuplotSource,
 				      m_image->GetCompressedGnuplotSource());
-      flags += " gnuplotsource_gz=\"" + gnuplotSource + "\"";
+      flags += wxS(" gnuplotsource_gz=\"") + gnuplotSource + wxS("\"");
     }
-  }
 
-  return (wxT("<img") + flags + wxT(">") + basename + m_image->GetExtension() +
-          wxT("</img>"));
+    wxString extension;
+    extension = m_image->GetExtension();
+    return (wxS("<img") + flags + wxS(">") + basename + extension +
+	    wxS("</img>"));
+  }
+  else
+    return  (wxS("<img") + flags + wxS(">") +
+          wxS("</img>"));
 }
 
 void ImgCell::DrawBoundingBox(wxDC &WXUNUSED(dc), bool WXUNUSED(all)) {
