@@ -86,8 +86,8 @@ void IntCell::MakeBreakUpCells() {
 void IntCell::Recalculate(AFontSize fontsize) {
   wxASSERT(fontsize.IsValid());
 
-  m_signHeight = Scale_Px(35 * m_configuration->GetZoomFactor());
-  m_signWidth = Scale_Px(18 * m_configuration->GetZoomFactor());
+  m_signHeight = Scale_Px(35);
+  m_signWidth = Scale_Px(18);
   if (m_signWidth < 4)
     m_signWidth = 4;
 
@@ -104,6 +104,9 @@ void IntCell::Recalculate(AFontSize fontsize) {
   } else {
     m_under->RecalculateList({MC_MIN_SIZE, fontsize - 5});
     m_over->RecalculateList({MC_MIN_SIZE, fontsize - 5});
+    if (m_intStyle == INT_DEF) {
+      m_signHeight = Scale_Px(35) + m_over->GetHeightList() + m_under->GetHeightList();
+    }
   }
 
   if (IsBrokenIntoLines()) {
@@ -111,65 +114,14 @@ void IntCell::Recalculate(AFontSize fontsize) {
     m_height = 0;
     m_width = 0;
   } else {
-    if (m_configuration->CheckTeXFonts()) {
-      wxDC *dc = m_configuration->GetDC();
-      auto fontsize1 = AFontSize(Scale_Px(fontsize * 1.5));
-      wxASSERT(fontsize1.IsValid());
-
-      Style style = Style(fontsize1).FontName(m_configuration->GetTeXCMEX());
-      if (!style.IsFontOk()) {
-        style = Style::FromStockFont(wxStockGDI::FONT_NORMAL);
-        style.SetFontSize(fontsize1);
-      }
-
-      dc->SetFont(style.GetFont());
-      dc->GetTextExtent(wxT("\u005A"), &m_signWidth, &m_signHeight);
-
-#if defined __WXMSW__
-      m_signWidth = m_signWidth / 2;
-#endif
-      m_signTop = m_signHeight / 2;
-      m_signHeight = (85 * m_signHeight) / 100;
-
-      m_width =
-	m_signWidth +
-	wxMax(m_over->GetFullWidth() + m_signWidth, m_under->GetFullWidth()) +
-	m_base->GetFullWidth() + m_var->GetFullWidth() + Scale_Px(4);
-    } else {
-#if defined __WXMSW__
-      wxDC *dc = m_configuration->GetDC();
-      auto fontsize1 = Scale_Px(INTEGRAL_FONT_SIZE);
-      wxASSERT(fontsize1.IsValid());
-
-      Style style =
-	Style(fontsize1).FontName(m_configuration->GetSymbolFontName());
-
-      if (!style.IsFontOk()) {
-        style = Style::FromStockFont(wxStockGDI::FONT_NORMAL);
-        style.SetFontSize(fontsize1);
-      }
-
-      dc->SetFont(style.GetFont());
-      dc->GetTextExtent(INTEGRAL_TOP, &m_charWidth, &m_charHeight);
-
-      m_width = m_signWidth + m_base->GetFullWidth() +
-	wxMax(m_over->GetFullWidth(), m_under->GetFullWidth()) +
-	m_var->GetFullWidth() + Scale_Px(4);
-#else
-      m_width = m_signWidth + m_base->GetFullWidth() +
-	wxMax(m_over->GetFullWidth(), m_under->GetFullWidth()) +
-	m_var->GetFullWidth() + Scale_Px(4);
-      if (m_signHeight < Scale_Px(35))
-        m_signHeight = Scale_Px(35);
-#endif
-    }
-
+    m_width = m_signWidth + m_base->GetFullWidth() +
+      wxMax(m_over->GetFullWidth(), m_under->GetFullWidth()) +
+      m_var->GetFullWidth() + Scale_Px(4);
+    // cppcheck-suppress duplicateBranch
     if (m_intStyle == INT_DEF) {
-      m_center = wxMax(m_over->GetHeightList() + Scale_Px(4) +
-		       m_signHeight / 2 - m_signHeight / 3,
+      m_center = wxMax(m_signHeight / 2,
                        m_base->GetCenterList());
-      m_height = m_center + wxMax(m_under->GetHeightList() + Scale_Px(4) +
-				  m_signHeight / 2 - m_signHeight / 3,
+      m_height = m_center + wxMax(m_signHeight / 2,
                                   m_base->GetMaxDrop());
     } else {
       m_center = wxMax(m_signHeight / 2, m_base->GetCenterList());
@@ -178,12 +130,12 @@ void IntCell::Recalculate(AFontSize fontsize) {
   }
 }
 
-void IntCell::Draw(wxPoint point) {
-  Cell::Draw(point);
+void IntCell::Draw(wxPoint point, wxDC *dc, wxDC *antialiassingDC) {
+  Cell::Draw(point, dc, antialiassingDC);
   if (DrawThisCell(point)) {
     wxPoint base(point), under(point), over(point), var(point), sign(point);
 
-    SetPen(1.5);
+    SetPen(antialiassingDC, 1.5);
     // top decoration
     int m_signWCenter = m_signWidth / 2;
     wxPoint points[7] = {
@@ -205,58 +157,34 @@ void IntCell::Draw(wxPoint point) {
       {sign.x + m_signWCenter - 2 * (m_signWidth / 4),
        sign.y + (m_signHeight - Scale_Px(1)) / 2 - m_signWidth / 4}};
 
-    m_configuration->GetAntialiassingDC()->DrawSpline(7, points);
-    points[1] = {sign.x + m_signWCenter + m_signWidth / 4,
-      sign.y - (m_signHeight - Scale_Px(1.25)) / 2};
-    points[2] = {sign.x + m_signWCenter,
-      sign.y - (m_signHeight - Scale_Px(1)) / 2 +
-      2 * (m_signWidth / 4) - Scale_Px(.35)};
-    points[3] = {sign.x + m_signWCenter - Scale_Px(.5), sign.y};
-    points[4] = {sign.x + m_signWCenter,
-      sign.y + (m_signHeight - Scale_Px(1)) / 2 -
-      2 * (m_signWidth / 4) + Scale_Px(.35)};
-    points[5] = {sign.x + m_signWCenter - m_signWidth / 4,
-      sign.y + (m_signHeight - Scale_Px(1.25)) / 2};
-    m_configuration->GetAntialiassingDC()->DrawSpline(7, points);
+    antialiassingDC->DrawSpline(7, points);
     // line
 
     if (m_intStyle == INT_DEF) {
       under.x += m_signWidth;
-      under.y = point.y + m_signHeight / 2 + m_under->GetCenterList() +
-	Scale_Px(2) - m_signHeight / 3;
-      m_under->DrawList(under);
+      under.y = point.y + m_signHeight / 2 - m_under->GetMaxDrop();
+      m_under->DrawList(under, dc, antialiassingDC);
 
-      if (m_configuration->CheckTeXFonts())
-        over.x += 2 * m_signWidth;
-      else
-        over.x += m_signWidth;
+      over.x += m_signWidth;
+      
+      over.y = point.y - m_signHeight / 2 + m_over->GetHeightList() - m_over->GetCenterList();
+      m_over->DrawList(over, dc, antialiassingDC);
 
-      over.y = point.y - m_signHeight / 2 - m_over->GetMaxDrop() - Scale_Px(2) +
-	m_signHeight / 3;
-      m_over->DrawList(over);
-
-      if (m_configuration->CheckTeXFonts()) {
-        base.x += m_signWidth + wxMax(m_over->GetFullWidth() + m_signWidth,
-                                      m_under->GetFullWidth());
-      } else
-        base.x += m_signWidth +
-	  wxMax(m_over->GetFullWidth(), m_under->GetFullWidth());
+      base.x += m_signWidth +
+	wxMax(m_over->GetFullWidth(), m_under->GetFullWidth());
     }
-
-    else if (m_configuration->CheckTeXFonts())
-      base.x += 2 * m_signWidth;
     else
       base.x += m_signWidth;
 
-    m_base->DrawList(base);
+    m_base->DrawList(base, dc, antialiassingDC);
 
     var.x = base.x + m_base->GetFullWidth();
-    m_var->DrawList(var);
+    m_var->DrawList(var, dc, antialiassingDC);
   }
 }
 
 wxString IntCell::ToString() const {
-  wxString s = wxT("integrate(");
+  wxString s = wxS("integrate(");
 
   s += m_base->ListToString();
 
@@ -270,16 +198,16 @@ wxString IntCell::ToString() const {
   wxString to = m_over->ListToString();
   wxString from = m_under->ListToString();
 
-  s += wxT(",") + var;
+  s += wxS(",") + var;
   if (m_intStyle == INT_DEF)
-    s += wxT(",") + from + wxT(",") + to;
+    s += wxS(",") + from + wxS(",") + to;
 
-  s += wxT(")");
+  s += wxS(")");
   return s;
 }
 
 wxString IntCell::ToMatlab() const {
-  wxString s = wxT("integrate(");
+  wxString s = wxS("integrate(");
 
   s += m_base->ListToMatlab();
 
@@ -292,29 +220,29 @@ wxString IntCell::ToMatlab() const {
   wxString to = m_over->ListToMatlab();
   wxString from = m_under->ListToMatlab();
 
-  s += wxT(",") + var;
+  s += wxS(",") + var;
   if (m_intStyle == INT_DEF)
-    s += wxT(",") + from + wxT(",") + to;
+    s += wxS(",") + from + wxS(",") + to;
 
-  s += wxT(")");
+  s += wxS(")");
   return s;
 }
 
 wxString IntCell::ToTeX() const {
-  wxString s = wxT("\\int");
+  wxString s = wxS("\\int");
 
   wxString to = m_over->ListToTeX();
   wxString from = m_under->ListToTeX();
 
   if (m_intStyle == INT_DEF)
-    s += wxT("_{") + from + wxT("}^{") + to + wxT("}");
+    s += wxS("_{") + from + wxS("}^{") + to + wxS("}");
   else
-    s += wxT(" ");
+    s += wxS(" ");
 
-  s += wxT("{\\left. ");
+  s += wxS("{\\left. ");
   s += m_base->ListToTeX();
   s += m_var->ListToTeX();
-  s += wxT("\\right.}");
+  s += wxS("\\right.}");
 
   return s;
 }
@@ -336,18 +264,18 @@ wxString IntCell::ToMathML() const {
 
   wxString retval;
   if (from.IsEmpty() && to.IsEmpty())
-    retval = wxT("<mo>&#x222B;</mo>") + base;
+    retval = wxS("<mo>&#x222B;</mo>") + base;
   if (from.IsEmpty() && !to.IsEmpty())
-    retval = wxT("<mover><mo>&#x222B;</mo>") + to + wxT("</mover>") + base;
+    retval = wxS("<mover><mo>&#x222B;</mo>") + to + wxS("</mover>") + base;
   if (!from.IsEmpty() && to.IsEmpty())
-    retval = wxT("<munder><mo>&#x222B;</mo>") + from + wxT("</munder>") + base;
+    retval = wxS("<munder><mo>&#x222B;</mo>") + from + wxS("</munder>") + base;
   if (!from.IsEmpty() && !to.IsEmpty())
-    retval = wxT("<munderover><mo>&#x222B;</mo>") + from + to +
-      wxT("</munderover>\n") + base;
+    retval = wxS("<munderover><mo>&#x222B;</mo>") + from + to +
+      wxS("</munderover>\n") + base;
   if (!var.IsEmpty())
     retval = retval + var;
 
-  return (wxT("<mrow>") + retval + wxT("</mrow>"));
+  return (wxS("<mrow>") + retval + wxS("</mrow>"));
 }
 
 wxString IntCell::ToOMML() const {
@@ -367,12 +295,12 @@ wxString IntCell::ToOMML() const {
 
   wxString retval;
 
-  retval = wxT("<m:nary><m:naryPr><m:chr>\u222b</m:chr></m:naryPr>");
+  retval = wxS("<m:nary><m:naryPr><m:chr>\u222b</m:chr></m:naryPr>");
   if (from != wxEmptyString)
-    retval += wxT("<m:sub>") + from + wxT("</m:sub>");
+    retval += wxS("<m:sub>") + from + wxS("</m:sub>");
   if (to != wxEmptyString)
-    retval += wxT("<m:sup>") + to + wxT("</m:sup>");
-  retval += wxT("<m:e><m:r>") + base + var + wxT("</m:r></m:e></m:nary>");
+    retval += wxS("<m:sup>") + to + wxS("</m:sup>");
+  retval += wxS("<m:e><m:r>") + base + var + wxS("</m:r></m:e></m:nary>");
 
   return retval;
 }
@@ -381,33 +309,33 @@ wxString IntCell::ToXML() const {
   wxString from;
   if (m_under != NULL)
     from = m_under->ListToXML();
-  from = wxT("<r>") + from + wxT("</r>");
+  from = wxS("<r>") + from + wxS("</r>");
 
   wxString to;
   if (m_over != NULL)
     to = m_over->ListToXML();
-  to = wxT("<r>") + to + wxT("</r>");
+  to = wxS("<r>") + to + wxS("</r>");
 
   wxString base;
   if (m_base != NULL)
     base = m_base->ListToXML();
-  base = wxT("<r>") + base + wxT("</r>");
+  base = wxS("<r>") + base + wxS("</r>");
 
   wxString var;
   if (m_var != NULL)
     var = m_var->ListToXML();
-  var = wxT("<r>") + var + wxT("</r>");
+  var = wxS("<r>") + var + wxS("</r>");
 
   wxString flags;
   if (HasHardLineBreak())
-    flags += wxT(" breakline=\"true\"");
+    flags += wxS(" breakline=\"true\"");
 
   if (m_intStyle != INT_DEF) {
-    flags += wxT(" def=\"false\">");
-    return wxT("<in") + flags + wxT(">") + base + var + wxT("</in>");
+    flags += wxS(" def=\"false\">");
+    return wxS("<in") + flags + wxS(">") + base + var + wxS("</in>");
   } else
-    return wxT("<in") + flags + wxT(">") + from + to + base + var +
-      wxT("</in>");
+    return wxS("<in") + flags + wxS(">") + from + to + base + var +
+      wxS("</in>");
 }
 
 bool IntCell::BreakUp() {
