@@ -41,7 +41,7 @@ public:
   const CellTypeInfo &GetInfo() override;
 
   void Recalculate(AFontSize fontsize) override;
-  void Draw(wxPoint point) override;
+  void Draw(wxPoint point, wxDC *dc, wxDC *antialiassingDC) override;
   bool NeedsRecalculation(AFontSize fontSize) const override;
   void SetStyle(TextStyle style) override;
   wxString ToString() const override;
@@ -60,22 +60,16 @@ private:
   //! The user-defined label for this label cell.
   wxString m_userDefinedLabel;
 
-//** 2-byte objects (2 bytes)
-//**
-  AFontSize m_fontSize_scaledToFit = {};
-
 //** 1-byte objects (1 byte)
 //**
   Configuration::showLabels m_labelChoice_Last = {};
 
 //** Bitfield objects (0 bytes)
 //**
-  void InitBitFields()
+  static void InitBitFields()
     { // Keep the initialization order below same as the order
       // of bit fields in this class!
     }
-
-  TextIndex GetLabelIndex() const;
 };
 
 #endif // LABELCELL_H
