@@ -33,9 +33,9 @@
 ListCell::ListCell(GroupCell *group, Configuration *config,
                    std::unique_ptr<Cell> &&inner)
   : Cell(group, config),
-    m_open(std::make_unique<TextCell>(group, config, wxT("["))),
+    m_open(std::make_unique<TextCell>(group, config, wxS("["))),
     m_innerCell(std::move(inner)),
-    m_close(std::make_unique<TextCell>(group, config, wxT("]"))) {
+    m_close(std::make_unique<TextCell>(group, config, wxS("]"))) {
   InitBitFields();
   SetStyle(TS_VARIABLE);
 
@@ -100,21 +100,21 @@ void ListCell::Recalculate(AFontSize fontsize) {
   Cell::Recalculate(fontsize);
 }
 
-void ListCell::Draw(wxPoint point) {
-  Cell::Draw(point);
+void ListCell::Draw(wxPoint point, wxDC *dc, wxDC *antialiassingDC) {
+  Cell::Draw(point, dc, antialiassingDC);
   if (DrawThisCell(point)) {
     wxPoint innerCellPos(point);
 
     if (m_drawAsAscii) {
       innerCellPos.x += m_open->GetWidth();
-      m_open->DrawList(point);
+      m_open->DrawList(point, dc, antialiassingDC);
       m_close->DrawList(wxPoint(
-				point.x + m_open->GetWidth() + m_innerCell->GetFullWidth(), point.y));
+				point.x + m_open->GetWidth() + m_innerCell->GetFullWidth(),
+				point.y), dc, antialiassingDC);
     } else {
-      wxDC *adc = m_configuration->GetAntialiassingDC();
       innerCellPos.y +=
 	(m_innerCell->GetCenterList() - m_innerCell->GetHeightList() / 2);
-      SetPen(1.5);
+      SetPen(antialiassingDC, 1.5);
 
       int signWidth = m_signWidth - Scale_Px(2);
       innerCellPos.x = point.x + m_signWidth;
@@ -126,7 +126,7 @@ void ListCell::Draw(wxPoint point) {
 	{point.x + Scale_Px(1), point.y + m_center - Scale_Px(4)},
 	{point.x - Scale_Px(1) + signWidth,
 	 point.y + m_center - Scale_Px(4)}};
-      adc->DrawLines(4, pointsL);
+      antialiassingDC->DrawLines(4, pointsL);
 
       // Right bracket
       const wxPoint pointsR[4] = {
@@ -136,27 +136,27 @@ void ListCell::Draw(wxPoint point) {
 	{point.x + m_width - Scale_Px(1), point.y + m_center - Scale_Px(4)},
 	{point.x + m_width + Scale_Px(1) - signWidth,
 	 point.y + m_center - Scale_Px(4)}};
-      adc->DrawLines(4, pointsR);
+      antialiassingDC->DrawLines(4, pointsR);
     }
 
-    m_innerCell->DrawList(innerCellPos);
+    m_innerCell->DrawList(innerCellPos, dc, antialiassingDC);
   }
 }
 
 wxString ListCell::ToString() const {
   wxString s;
   if (!m_innerCell)
-    return "[]";
+    return wxS("[]");
 
   if (!IsBrokenIntoLines())
-    s = wxT("[") + m_innerCell->ListToString() + wxT("]");
+    s = wxS("[") + m_innerCell->ListToString() + wxS("]");
   return s;
 }
 
 wxString ListCell::ToMatlab() const {
   wxString s;
   if (!IsBrokenIntoLines())
-    s = wxT("[") + m_innerCell->ListToMatlab() + wxT("]");
+    s = wxS("[") + m_innerCell->ListToMatlab() + wxS("]");
   return s;
 }
 
@@ -175,36 +175,36 @@ wxString ListCell::ToTeX() const {
       }
 
     if (needsLeftRight)
-      s = wxT("\\left[ ") + m_innerCell->ListToTeX() + wxT("\\right] ");
+      s = wxS("\\left[ ") + m_innerCell->ListToTeX() + wxS("\\right] ");
     else
-      s = wxT("[") + m_innerCell->ListToTeX() + wxT("]");
+      s = wxS("[") + m_innerCell->ListToTeX() + wxS("]");
   }
   return s;
 }
 
 wxString ListCell::ToOMML() const {
-  return wxT("<m:d><m:dPr m:begChr=\"") + XMLescape(m_open->ToString()) +
-    wxT("\" m:endChr=\"") + XMLescape(m_close->ToString()) +
-    wxT("\" m:grow=\"1\"></m:dPr><m:e>") + m_innerCell->ListToOMML() +
-    wxT("</m:e></m:d>");
+  return wxS("<m:d><m:dPr m:begChr=\"") + XMLescape(m_open->ToString()) +
+    wxS("\" m:endChr=\"") + XMLescape(m_close->ToString()) +
+    wxS("\" m:grow=\"1\"></m:dPr><m:e>") + m_innerCell->ListToOMML() +
+    wxS("</m:e></m:d>");
 }
 
 wxString ListCell::ToMathML() const {
   wxString open = m_open->ToString();
   wxString close = m_close->ToString();
-  return (wxT("<mrow><mo>") + XMLescape(open) + wxT("</mo>") +
-          m_innerCell->ListToMathML() + wxT("<mo>") + XMLescape(close) +
-          wxT("</mo></mrow>\n"));
+  return (wxS("<mrow><mo>") + XMLescape(std::move(open)) + wxS("</mo>") +
+          m_innerCell->ListToMathML() + wxS("<mo>") + XMLescape(close) +
+          wxS("</mo></mrow>\n"));
 }
 
 wxString ListCell::ToXML() const {
   wxString s = m_innerCell->ListToXML();
   wxString flags;
   if (HasHardLineBreak())
-    flags += wxT(" breakline=\"true\"");
-  return (wxT("<r list=\"true\"") + flags +
-          wxT("><t listdelim=\"true\">[</t>") + s +
-          wxT("<t listdelim=\"true\">]</t></r>"));
+    flags += wxS(" breakline=\"true\"");
+  return (wxS("<r list=\"true\"") + flags +
+          wxS("><t listdelim=\"true\">[</t>") + s +
+          wxS("<t listdelim=\"true\">]</t></r>"));
 }
 
 bool ListCell::BreakUp() {
