@@ -39,14 +39,13 @@ public:
   const CellTypeInfo &GetInfo() override;
 
   void Recalculate(AFontSize fontsize) override;
-  void Draw(wxPoint point) override;
+  void Draw(wxPoint point, wxDC *dc, wxDC *antialiassingDC) override;
   bool NeedsRecalculation(AFontSize fontSize) const override;
-  void SetStyle(TextStyle style) override;
   bool BreakUp() override;
   void SetNextToDraw(Cell *next) override;
   int GetInnerCellCount() const override { if(m_innerCell) return 1; else return 0; }
   // cppcheck-suppress objectIndex
-  Cell *GetInnerCell(int index) const override { return (&m_innerCell)[index].get(); }
+  Cell *GetInnerCell(int index) const override;
 
 protected:
   virtual void UpdateDisplayedText() override;
@@ -73,7 +72,7 @@ private:
 
   //** Bitfield objects (0 bytes)
   //**
-  void InitBitFields()
+  static void InitBitFields()
     { // Keep the initialization order below same as the order
       // of bit fields in this class!
     }
