@@ -59,7 +59,7 @@ public:
 
   void Recalculate(AFontSize fontsize) override;
 
-  void Draw(wxPoint point) override;
+  void Draw(wxPoint point, wxDC *dc, wxDC *antialiassingDC) override;
 
   bool BreakUp() override;
 
@@ -91,7 +91,7 @@ private:
 
 //** Bitfield objects (0 bytes)
 //**
-  void InitBitFields()
+  static void InitBitFields()
     { // Keep the initialization order below same as the order
       // of bit fields in this class!
     }
