@@ -35,8 +35,8 @@ Emfout::Emfout(Configuration **configuration, const wxString &filename)
     m_recalculationDc(m_cmn.GetTempFilename(), 3000, 50000) {
   m_cmn.SetRecalculationContext(m_recalculationDc);
   auto &config = m_cmn.GetConfiguration();
-  config.SetContext(m_recalculationDc);
-  config.SetClientWidth(3000);
+  config.SetRecalcContext(m_recalculationDc);
+  config.SetCanvasSize(wxSize(3000,100000));
 }
 
 Emfout::Emfout(Configuration **configuration, std::unique_ptr<Cell> &&tree,
@@ -63,7 +63,7 @@ bool Emfout::Layout() {
   auto &config = m_cmn.GetConfiguration();
   wxEnhMetaFileDC dc(m_cmn.GetFilename(), size.x, size.y);
 
-  config.SetContext(dc);
+  config.SetRecalcContext(dc);
   m_cmn.Draw(m_tree.get());
   m_metaFile.reset(
 		   dc.Close()); // Closing the DC triggers the output of the file.
