@@ -43,12 +43,6 @@ class Printout : public wxPrintout
 public:
   Printout(wxString title, GroupCell *tree, double scaleFactor);
 
-  ~Printout();
-
-  void DestroyTree();
-
-  void DestroyTree(GroupCell *tree);
-
   void SetupData();
 
   void BreakPages();
@@ -65,12 +59,6 @@ public:
 
   virtual void OnPreparePrinting() override;
 
-  void GetPageMargins(int *horizontal, int *vertical);
-
-  int GetHeaderHeight();
-
-  void PrintHeader(int pageNum, wxDC *dc);
-
 private:
   wxString m_title;
   std::unique_ptr<GroupCell> m_tree;
@@ -78,6 +66,8 @@ private:
   Configuration m_configuration;
   Configuration *m_configPointer;
   double m_scaleFactor;
+  // Sets Configuration::Printing() to true while we print
+  Printing m_printing;
 };
 
 #endif // MATHPRINTOUT_H
