@@ -54,8 +54,8 @@ Svgout::Svgout(Configuration **configuration, const wxString &filename,
   m_recalculationDc.SetBitmapHandler(new wxSVGBitmapEmbedHandler());
 #endif
   auto &config = m_cmn.GetConfiguration();
-  config.SetContext(m_recalculationDc);
-  config.SetClientWidth(700 * scale);
+  config.SetRecalcContext(m_recalculationDc);
+  config.SetCanvasSize(wxSize(700 * scale, 100000 * scale));
 }
 
 Svgout::Svgout(Configuration **configuration, std::unique_ptr<Cell> &&tree,
@@ -85,7 +85,7 @@ bool Svgout::Layout() {
   dc.SetBitmapHandler(new wxSVGBitmapEmbedHandler());
 #endif
 
-  config.SetContext(dc);
+  config.SetRecalcContext(dc);
   m_cmn.Draw(m_tree.get());
   config.UnsetContext();
 
@@ -93,7 +93,7 @@ bool Svgout::Layout() {
 }
 
 static wxDataFormat &Format() {
-  static wxDataFormat format(wxT("image/svg+xml"));
+  static wxDataFormat format(wxS("image/svg+xml"));
   return format;
 }
 
