@@ -27,6 +27,7 @@
 
 #include "main.h"
 #include "Dirstructure.h"
+#include "wxMathml.h"
 #include <iostream>
 #include <wx/cmdline.h>
 #include <wx/config.h>
@@ -34,6 +35,10 @@
 #include <wx/fs_zip.h>
 #include <wx/image.h>
 #include <wx/intl.h>
+#include <wx/translation.h>
+#if wxCHECK_VERSION(3, 1, 6)
+#include <wx/uilocale.h>
+#endif
 #include <wx/sysopt.h>
 #include <wx/tipdlg.h>
 #include <wx/utils.h>
@@ -44,11 +49,18 @@
 
 #include "ConfigDialogue.h"
 #include "Version.h"
-#include "examples.h"
+#include "examples/CASvsProgrammingLanguage.h"
+#include "examples/diffEquations.h"
+#include "examples/displaying3DCurves.h"
+#include "examples/fastListAccess.h"
+#include "examples/fittingEquations.h"
+#include "examples/memoizing.h"
+#include "examples/numberFormats.h"
+#include "examples/solvingEquations.h"
+#include "examples/toleranceCalculations.h"
+#include "examples/variableNames.h"
+
 #include "wxMaxima.h"
-#ifdef WXM_INCLUDE_FONTS
-#include "addprivatefonts.h"
-#endif
 
 // On wxGTK2 we support printing only if wxWidgets is compiled with gnome_print.
 // We have to force gnome_print support to be linked in static builds of
@@ -105,6 +117,9 @@ static const wxCmdLineEntryDesc cmdLineDesc[] = {
     {wxCMD_LINE_SWITCH, "", "logtostderr",
      "Log all \"debug messages\" sidebar messages to stderr, too.",
      wxCMD_LINE_VAL_NONE, 0},
+    {wxCMD_LINE_SWITCH, "", "debug",
+     "Enable costly debug checks.",
+     wxCMD_LINE_VAL_NONE, 0},
     {wxCMD_LINE_SWITCH, "", "pipe", "Pipe messages from Maxima to stderr.",
      wxCMD_LINE_VAL_NONE, 0},
     {wxCMD_LINE_SWITCH, "", "exit-on-error",
@@ -126,6 +141,9 @@ static const wxCmdLineEntryDesc cmdLineDesc[] = {
      "Lets Maxima control wxMaxima via interprocess communications. Use this "
      "option with care.",
      wxCMD_LINE_VAL_NONE, 0},
+    {wxCMD_LINE_OPTION, "", "wxmathml-lisp",
+     "Location of wxMathML.lisp (if not the built-in should be used, mainly for developers).",
+     wxCMD_LINE_VAL_STRING, 0},
     {wxCMD_LINE_PARAM, NULL, NULL, "input file", wxCMD_LINE_VAL_STRING,
      wxCMD_LINE_PARAM_OPTIONAL | wxCMD_LINE_PARAM_MULTIPLE},
      wxCMD_LINE_DESC_END};
@@ -157,7 +175,9 @@ int WINAPI WinMain(HINSTANCE hI, HINSTANCE hPrevI, LPSTR lpCmdLine,
 #endif
 
 bool MyApp::OnInit() {
-  // On the Mac if any of these commands outputs text to stderr maxima fails to
+  wxLogStderr noErrorDialogs;
+  m_translations = std::unique_ptr<wxTranslations>(new wxTranslations());
+  wxTranslations::Set(m_translations.get());
   // connect to wxMaxima. We therefore delay all output to the log until there
   // is a window that can display it on the GUI instead.
   wxLogBuffer noStdErr;
@@ -183,14 +203,14 @@ bool MyApp::OnInit() {
 #if wxCHECK_VERSION(3, 1, 1)
     wxStandardPaths::Get().SetFileLayout(wxStandardPaths::FileLayout_Classic);
     wxString configFileOld =
-      wxStandardPaths::Get().GetUserConfigDir() + wxT("/") +
+      wxStandardPaths::Get().GetUserConfigDir() + wxS("/") +
       wxStandardPaths::Get().MakeConfigFileName(
-						wxString(wxT("wxMaxima")), wxStandardPaths::ConfigFileConv_Dot);
+						wxString(wxS("wxMaxima")), wxStandardPaths::ConfigFileConv_Dot);
     wxStandardPaths::Get().SetFileLayout(wxStandardPaths::FileLayout_XDG);
     wxString configFileXDG =
-      wxStandardPaths::Get().GetUserConfigDir() + wxT("/") +
+      wxStandardPaths::Get().GetUserConfigDir() + wxS("/") +
       wxStandardPaths::Get().MakeConfigFileName(
-						wxString(wxT("wxMaxima")), wxStandardPaths::ConfigFileConv_Ext);
+						wxString(wxS("wxMaxima")), wxStandardPaths::ConfigFileConv_Ext);
 
     if (!wxFileExists(configFileXDG)) {
       wxFileName xdgDir(configFileXDG);
@@ -203,6 +223,26 @@ bool MyApp::OnInit() {
 #endif
 #endif
 
+    wxLanguage lang;
+    {
+      long lng = wxLocale::GetSystemLanguage();
+      wxConfig(wxS("wxMaxima"), wxEmptyString, m_configFileName)
+	.Read(wxS("language"), &lng);
+      if (lng == wxLANGUAGE_UNKNOWN)
+	lng = wxLANGUAGE_DEFAULT;
+      lang = static_cast<wxLanguage>(lng);
+    }
+
+    {
+#if wxCHECK_VERSION(3, 1, 6)
+      wxLogNull suppressErrorMessages;
+      wxUILocale::UseDefault();
+#else
+      m_locale = std::unique_ptr<wxLocale>(new wxLocale);
+      m_locale->Init(lang);
+#endif
+    }
+
     // Create the temporary directory if it doesn't exist
     // On some platforms, the temporary directory has an application-specific
     // path element prepended doesn't exist by default in the temporary
@@ -212,42 +252,40 @@ bool MyApp::OnInit() {
     if (!wxDirExists(tempDir))
       wxMkdir(tempDir, 0x700);
 
-    m_locale.AddCatalogLookupPathPrefix(m_dirstruct.LocaleDir());
-    m_locale.AddCatalogLookupPathPrefix(m_dirstruct.LocaleDir() +
-                                        wxT("/wxwin"));
-    m_locale.AddCatalogLookupPathPrefix(wxT("/usr/share/locale"));
-    m_locale.AddCatalogLookupPathPrefix(wxT("/usr/local/share/locale"));
-    long lang = wxLocale::GetSystemLanguage();
-    wxConfig(wxT("wxMaxima"), wxEmptyString, m_configFileName)
-      .Read(wxT("language"), &lang);
-    if (lang == wxLANGUAGE_UNKNOWN)
-      lang = wxLANGUAGE_DEFAULT;
-    m_locale.Init(lang);
+    wxFileTranslationsLoader::AddCatalogLookupPathPrefix(m_dirstruct.LocaleDir());
+    wxFileTranslationsLoader::AddCatalogLookupPathPrefix(m_dirstruct.LocaleDir() +
+							 wxS("/wxwin"));
+    wxFileTranslationsLoader::AddCatalogLookupPathPrefix(wxS("/usr/share/locale"));
+    wxFileTranslationsLoader::AddCatalogLookupPathPrefix(wxS("/usr/local/share/locale"));
 
-    // Do we reckong we improve something if we set maxima's language, as well?
+    if (wxLocale::IsAvailable(lang))
+      wxTranslations::Get()->SetLanguage(lang);
+
+    // Do we reckon we improve something if we set maxima's language, as well?
     if ((wxLocale::IsAvailable(lang)) && (lang != wxLANGUAGE_DEFAULT)) {
       // Set maxima's language, as well.
-      wxString localeName = m_locale.GetCanonicalName();
+      wxString localeName = wxLocale().GetCanonicalName();
       if (lang != wxLocale::GetSystemLanguage()) {
-        if (m_locale.GetSystemEncoding() == wxFONTENCODING_UTF16)
-          localeName += wxT(".UTF-16");
+        if (wxLocale().GetSystemEncoding() == wxFONTENCODING_UTF16)
+          localeName += wxS(".UTF-16");
         else {
-          if (m_locale.GetSystemEncoding() == wxFONTENCODING_UTF32)
-            localeName += wxT(".UTF-32");
+          if (wxLocale().GetSystemEncoding() == wxFONTENCODING_UTF32)
+            localeName += wxS(".UTF-32");
           else {
-            localeName += wxT(".UTF-8");
+            localeName += wxS(".UTF-8");
           }
         }
-        wxSetEnv(wxT("LANG"), localeName);
+        wxSetEnv(wxS("LANG"), localeName);
       }
     }
-    m_locale.AddCatalog(wxT("wxMaxima"));
+    wxTranslations::Get()->AddCatalog(wxS("wxMaxima"));
     /* wxWidgets introduced version suffixes to gettext catalogs, see:
      * https://github.com/wxWidgets/wxWidgets/commit/ded4da5 */
     /* so try to load a catalog with this suffix */
-    m_locale.AddCatalog(
-			"wxstd-" wxSTRINGIZE(wxMAJOR_VERSION) "." wxSTRINGIZE(wxMINOR_VERSION));
-    m_locale.AddCatalog(wxT("wxstd"));
+    wxTranslations::Get()->AddCatalog("wxstd-"
+				      wxSTRINGIZE(wxMAJOR_VERSION) "."
+				      wxSTRINGIZE(wxMINOR_VERSION));
+    wxTranslations::Get()->AddCatalog(wxS("wxstd"));
   }
 
   bool exitAfterEval = false;
@@ -255,10 +293,10 @@ bool MyApp::OnInit() {
 
   int cmdLineError = cmdLineParser.Parse();
 
-  if (cmdLineParser.Found(wxT("single_process")))
+  if (cmdLineParser.Found(wxS("single_process")))
     m_allWindowsInOneProcess = true;
 
-  if (cmdLineParser.Found(wxT("h"))) {
+  if (cmdLineParser.Found(wxS("h"))) {
     std::cout << "A feature-rich graphical user interface for the computer "
       "algebra system Maxima\n";
     std::cout << cmdLineParser.GetUsageString();
@@ -271,41 +309,52 @@ bool MyApp::OnInit() {
   wxString ini, file;
   // Attention: The config file is changed by
   // wxMaximaFrame::wxMaximaFrame::ReReadConfig
-  if (cmdLineParser.Found(wxT("f"), &ini)) {
+  if (cmdLineParser.Found(wxS("f"), &ini)) {
     wxFileName configFile(ini);
     configFile.MakeAbsolute();
     Configuration::m_configfileLocation_override = configFile.GetFullPath();
     wxConfig::Set(
-		  new wxFileConfig(wxT("wxMaxima"), wxEmptyString,
+		  new wxFileConfig(wxS("wxMaxima"), wxEmptyString,
 				   Configuration::m_configfileLocation_override));
   } else
-    wxConfig::Set(new wxConfig(wxT("wxMaxima")));
+    wxConfig::Set(new wxConfig(wxS("wxMaxima")));
 
-  if (cmdLineParser.Found(wxT("logtostderr")))
+  if (cmdLineParser.Found(wxS("logtostderr")))
     ErrorRedirector::LogToStdErr();
 
-  if (cmdLineParser.Found(wxT("pipe")))
+  if (cmdLineParser.Found(wxS("debug")))
+    Configuration::SetDebugmode();
+
+  if (cmdLineParser.Found(wxS("pipe")))
     wxMaxima::PipeToStdout();
 
-  if (cmdLineParser.Found(wxT("exit-on-error")))
+  if (cmdLineParser.Found(wxS("exit-on-error")))
     wxMaxima::ExitOnError();
 
-  if (cmdLineParser.Found(wxT("enableipc")))
+  if (cmdLineParser.Found(wxS("enableipc")))
     wxMaxima::EnableIPC();
 
   wxString extraMaximaArgs;
   wxString arg;
-  if (cmdLineParser.Found(wxT("l"), &arg))
+  if (cmdLineParser.Found(wxS("l"), &arg))
     extraMaximaArgs += " -l " + arg;
 
-  if (cmdLineParser.Found(wxT("X"), &arg))
+  if (cmdLineParser.Found(wxS("X"), &arg))
     extraMaximaArgs += " -X " + arg;
 
-  if (cmdLineParser.Found(wxT("u"), &arg))
+  if (cmdLineParser.Found(wxS("u"), &arg))
     extraMaximaArgs += " -u " + arg;
 
   wxMaxima::ExtraMaximaArgs(extraMaximaArgs);
 
+  if (cmdLineParser.Found(wxS("wxmathml-lisp"), &arg)) {
+    wxMathML::Set_MathML_Filename(arg);
+  }
+
+  if (cmdLineParser.Found(wxS("m"), &arg)) {
+    wxMaxima::Set_Maxima_Commandline_Filename(arg);
+  }
+
   wxImage::AddHandler(new wxPNGHandler);
   wxImage::AddHandler(new wxXPMHandler);
   wxImage::AddHandler(new wxJPEGHandler);
@@ -313,42 +362,17 @@ bool MyApp::OnInit() {
 
   wxFileSystem::AddHandler(new wxZipFSHandler);
 
-#ifdef WXM_INCLUDE_FONTS
-  addprivatefonts();
-#endif
-
 #ifdef __WXMSW__
   wxString oldWorkingDir = wxGetCwd();
-  if (!wxGetEnv(wxT("BUILD_DIR"), NULL)) {
+  if (!wxGetEnv(wxS("BUILD_DIR"), NULL)) {
     wxString dir = wxPathOnly(wxStandardPaths::Get().GetExecutablePath());
     if (dir != wxEmptyString)
       wxSetWorkingDirectory(
 			    wxPathOnly(wxStandardPaths::Get().GetExecutablePath()));
   }
 #if wxCHECK_VERSION(3, 1, 1)
-  wxString fontPrefix = m_dirstruct.FontDir() + wxT("/");
+  wxString fontPrefix = m_dirstruct.FontDir() + wxS("/");
 
-#ifdef WXM_INCLUDE_FONTS
-  /* Add private Libertine fonts, if they exist */
-  if (wxFileExists(fontPrefix + wxT(LIBERTINE1)))
-    wxFont::AddPrivateFont(fontPrefix + wxT(LIBERTINE1));
-  if (wxFileExists(fontPrefix + wxT(LIBERTINE2)))
-    wxFont::AddPrivateFont(fontPrefix + wxT(LIBERTINE2));
-  if (wxFileExists(fontPrefix + wxT(LIBERTINE3)))
-    wxFont::AddPrivateFont(fontPrefix + wxT(LIBERTINE3));
-  if (wxFileExists(fontPrefix + wxT(LIBERTINE4)))
-    wxFont::AddPrivateFont(fontPrefix + wxT(LIBERTINE4));
-  if (wxFileExists(fontPrefix + wxT(LIBERTINE5)))
-    wxFont::AddPrivateFont(fontPrefix + wxT(LIBERTINE5));
-  if (wxFileExists(fontPrefix + wxT(LIBERTINE6)))
-    wxFont::AddPrivateFont(fontPrefix + wxT(LIBERTINE6));
-  if (wxFileExists(fontPrefix + wxT(LIBERTINE7)))
-    wxFont::AddPrivateFont(fontPrefix + wxT(LIBERTINE7));
-  if (wxFileExists(fontPrefix + wxT(LIBERTINE8)))
-    wxFont::AddPrivateFont(fontPrefix + wxT(LIBERTINE8));
-  if (wxFileExists(fontPrefix + wxT(LIBERTINE9)))
-    wxFont::AddPrivateFont(fontPrefix + wxT(LIBERTINE9));
-#endif
   wxSetWorkingDirectory(oldWorkingDir);
 #endif
 #endif
@@ -357,8 +381,8 @@ bool MyApp::OnInit() {
 
 #if defined __WXOSX__
   wxString path;
-  wxGetEnv(wxT("PATH"), &path);
-  wxSetEnv(wxT("PATH"), path << wxT(":/usr/local/bin"));
+  wxGetEnv(wxS("PATH"), &path);
+  wxSetEnv(wxS("PATH"), path << wxS(":/usr/local/bin"));
 
   //! The macintosh global menu
   wxMenuBar *menubar = new wxMenuBar;
@@ -378,7 +402,7 @@ bool MyApp::OnInit() {
   wxApp::SetExitOnFrameDelete(false);
 #endif
 
-  if (cmdLineParser.Found(wxT("v"))) {
+  if (cmdLineParser.Found(wxS("v"))) {
     std::cout << "wxMaxima ";
     std::cout << GITVERSION;
 #if defined(WXMAXIMA_GIT_VERSION)
@@ -388,17 +412,17 @@ bool MyApp::OnInit() {
     exit(0);
   }
 
-  if (cmdLineParser.Found(wxT("b"))) {
+  if (cmdLineParser.Found(wxS("b"))) {
     evalOnStartup = true;
     exitAfterEval = true;
   }
 
-  if (cmdLineParser.Found(wxT("e")))
+  if (cmdLineParser.Found(wxS("e")))
     evalOnStartup = true;
 
   bool windowOpened = false;
 
-  if (cmdLineParser.Found(wxT("o"), &file)) {
+  if (cmdLineParser.Found(wxS("o"), &file)) {
     wxFileName FileName = file;
     FileName.MakeAbsolute();
     wxString canonicalFilename = FileName.GetFullPath();
@@ -424,13 +448,14 @@ bool MyApp::OnInit() {
   // std::cerr confusing the mac.
   wxString logMessagesSoFar = noStdErr.GetBuffer();
   if (!logMessagesSoFar.IsEmpty())
-    wxLogMessage("Log messages during early startup: " + logMessagesSoFar);
+    wxLogMessage("Log messages during early startup: %s", logMessagesSoFar.mb_str());
   return true;
 }
 
 int MyApp::OnExit() { return 0; }
 
 int MyApp::OnRun() {
+  wxLogStderr noErrorDialogs;
   wxApp::OnRun();
   return 0;
 }
@@ -438,7 +463,7 @@ int MyApp::OnRun() {
 void MyApp::NewWindow(const wxString &file, bool evalOnStartup,
                       bool exitAfterEval, unsigned char *wxmData,
                       size_t wxmLen) {
-  int numberOfWindows = wxMaxima::m_topLevelWindows.size();
+  int numberOfWindows = wxMaximaFrame::m_topLevelWindows.size();
 
   wxString title = _("wxMaxima");
   if (file.Length() > 0)
@@ -447,7 +472,7 @@ void MyApp::NewWindow(const wxString &file, bool evalOnStartup,
   if (numberOfWindows > 1)
     title = wxString::Format(_("wxMaxima %d"), numberOfWindows);
 
-  wxMaxima *frame = new wxMaxima(NULL, -1, &m_locale, title, file);
+  wxMaxima *frame = new wxMaxima(NULL, -1, title, file);
   if (wxmData) {
     // Unzip the .wxm file
     wxMemoryInputStream istream(wxmData, wxmLen);
@@ -469,7 +494,7 @@ void MyApp::NewWindow(const wxString &file, bool evalOnStartup,
   }
 
   frame->EvalOnStartup(evalOnStartup);
-  wxMaxima::m_topLevelWindows.push_back(frame);
+  wxMaximaFrame::m_topLevelWindows.push_back(frame);
   frame->ExitAfterEval(exitAfterEval);
 
   SetTopWindow(frame);
@@ -515,9 +540,12 @@ void MyApp::OnFileMenu(wxCommandEvent &ev) {
   else if(ev.GetId() == EventIDs::menu_help_memoizing) {
     NewWindow(wxEmptyString, false, false, MEMOIZING_WXM, MEMOIZING_WXM_SIZE);
   }
+  else if(ev.GetId() == EventIDs::menu_help_casvsprogramming) {
+    NewWindow(wxEmptyString, false, false, CASVSPROGRAMMINGLANGUAGE_WXM, CASVSPROGRAMMINGLANGUAGE_WXM_SIZE);
+  }
   else if(ev.GetId() == wxID_OPEN) {
     wxString lastPath;
-    wxConfig::Get()->Read(wxT("lastPath"), &lastPath);
+    wxConfig::Get()->Read(wxS("lastPath"), &lastPath);
     wxString file =
       wxFileSelector(_("Open"), wxEmptyString, wxEmptyString, wxEmptyString,
 		     _("All openable types (*.wxm, *.wxmx, *.mac, *.out, "
@@ -531,7 +559,7 @@ void MyApp::OnFileMenu(wxCommandEvent &ev) {
       // On the mac the "File/New" menu item by default opens a new window
       // instead of reusing the old one.
       NewWindow(file);
-    } 
+    }
   }
   else if(ev.GetId() == wxID_NEW) {
       // Mac computers insist that all instances of a new application need to
@@ -541,14 +569,56 @@ void MyApp::OnFileMenu(wxCommandEvent &ev) {
     if (m_allWindowsInOneProcess)
       NewWindow();
     else {
-      wxString args;
+      // Compile a list of arguments we want to pass to the new process
+      std::vector<wxString> args;
       if (Configuration::m_configfileLocation_override != wxEmptyString)
-	args += " -f \"" + Configuration::m_configfileLocation_override + "\"";
-      if (Configuration::m_maximaLocation_override != wxEmptyString)
-	args += " -m \"" + Configuration::m_maximaLocation_override + "\"";
-      
-      wxExecute(wxT("\"") + wxStandardPaths::Get().GetExecutablePath() +
-		wxT("\"") + args);
+	{
+	  args.push_back("-f");
+	  args.push_back(Configuration::m_configfileLocation_override);
+	}
+      if (wxMaxima::Get_Maxima_Commandline_Filename() != wxEmptyString)
+	{
+	  args.push_back("-m");
+	  args.push_back(wxMaxima::Get_Maxima_Commandline_Filename());
+	}
+      if (ErrorRedirector::LoggingToStdErr())
+	  args.push_back("--logtostderr");
+      if (Configuration::GetDebugmode())
+	  args.push_back("--debug");
+      if (wxMaxima::GetPipeToStdout())
+	  args.push_back("--pipe");
+      if (wxMaxima::GetExitOnError())
+	  args.push_back("--exit-on-error");
+      if (wxMaxima::GetEnableIPC())
+	  args.push_back("--enableipc");
+      if (!wxMaxima::ExtraMaximaArgs().IsEmpty())
+	{
+	  args.push_back("-u");
+	  args.push_back(wxMaxima::ExtraMaximaArgs());
+	}
+
+      // wxExecute wants the arguments as C strings, not as wxStrings =>
+      // generate those C strings
+      std::vector<wxCharBuffer> args_c_strings;
+      for(const auto &i : args)
+	args_c_strings.push_back(wxCharBuffer(i.mb_str()));
+
+      // Additionally wxExecute expects these C strings in a C array.
+      // Let's generate an unique pointer to that one so C++ automatically destroys it
+      // once it is no more needed.
+      std::unique_ptr<char *> args_array(new char*[args.size() + 2]);
+      wxCharBuffer executableName(wxStandardPaths::Get().GetExecutablePath().mb_str());
+      args_array.get()[0] = executableName.data();;
+      args_array.get()[args.size() + 1] = NULL;
+      for(size_t i = 0; i< args.size(); i++)
+	args_array.get()[i + 1] = args_c_strings[i].data();
+      wxExecute(args_array.get());
+
+      wxString command;
+      for(size_t i = 0; i< args.size() + 1; i++)
+	command += wxString::FromUTF8(args_array.get()[i]) + "\n";
+      command.Trim();
+      wxLogMessage(_("Starting a new wxMaxima process as: %s"), command.mb_str());
     }
   }
   else if(ev.GetId() == wxID_PREFERENCES) {
@@ -557,19 +627,19 @@ void MyApp::OnFileMenu(wxCommandEvent &ev) {
     configW->Centre(wxBOTH);
     if (configW->ShowModal() == wxID_OK)
       configW->WriteSettings();
-    
+
     configW->Destroy();
     wxConfig::Get()->Flush();
   }
   else if(ev.GetId() ==  wxID_EXIT) {
-    for (wxMaxima *win : wxMaxima::m_topLevelWindows) {
+    for (wxMaximaFrame *win : wxMaximaFrame::m_topLevelWindows) {
       wxASSERT(win);
       wxCloseEvent *event = new wxCloseEvent(wxEVT_CLOSE_WINDOW);
       event->SetCanVeto(true);
       event->SetLoggingOff(false);
       win->GetEventHandler()->QueueEvent(event);
     }
-    if (wxMaxima::m_topLevelWindows.empty())
+    if (wxMaximaFrame::m_topLevelWindows.empty())
       wxExit();
   }
 }
