@@ -38,12 +38,18 @@ GenWizPanel::GenWizPanel(
 			 wxString defaultval7, wxString tooltip7, wxString label8,
 			 wxString defaultval8, wxString tooltip8, wxString label9,
 			 wxString defaultval9, wxString tooltip9)
-: GenWizPanel(parent, cfg, manual, description, description_tooltip,
-	      commandRule, false, label1, defaultval1, tooltip1, label2,
-	      defaultval2, tooltip2, label3, defaultval3, tooltip3, label4,
-	      defaultval4, tooltip4, label5, defaultval5, tooltip5, label6,
-	      defaultval6, tooltip6, label7, defaultval7, tooltip7, label8,
-	      defaultval8, tooltip8, label9, defaultval9, tooltip9) {}
+: GenWizPanel(std::move(parent), std::move(cfg), std::move(manual),
+	      std::move(description), std::move(description_tooltip),
+	      std::move(commandRule), false, std::move(label1),
+	      std::move(defaultval1), std::move(tooltip1), std::move(label2),
+	      std::move(defaultval2), std::move(tooltip2), std::move(label3),
+	      std::move(defaultval3), std::move(tooltip3), std::move(label4),
+	      std::move(defaultval4), std::move(tooltip4), std::move(label5),
+	      std::move(defaultval5), std::move(tooltip5), std::move(label6),
+	      std::move(defaultval6), std::move(tooltip6), std::move(label7),
+	      std::move(defaultval7), std::move(tooltip7), std::move(label8),
+	      std::move(defaultval8), std::move(tooltip8), std::move(label9),
+	      std::move(defaultval9), std::move(tooltip9)) {}
 
 GenWizPanel::GenWizPanel(
 			 wxWindow *parent, Configuration *cfg, MaximaManual *manual,
@@ -129,11 +135,11 @@ GenWizPanel::GenWizPanel(
             tooltip5, label6, defaultval6, tooltip6, label7, defaultval7,
             tooltip7, label8, defaultval8, tooltip8, label9, defaultval9,
             tooltip9);
-  SetSizer(vbox);
   Connect(wxEVT_SIZE, wxSizeEventHandler(GenWizPanel::OnSize), NULL, this);
   m_notebook->Connect(wxEVT_NOTEBOOK_PAGE_CHANGED,
                       wxBookCtrlEventHandler(GenWizPanel::OnNotebookPageChange),
                       NULL, this);
+  SetSizer(vbox);
   FitInside();
 }
 
@@ -157,39 +163,39 @@ void GenWizPanel::NewWizard(
   m_manualKeywords.clear();
   while (it < commandRule.end()) {
     while ((it < commandRule.end()) && (!wxIsalpha(*it)) && (!(*it == '_')))
-      it++;
+      ++it;
     wxString word;
     while (((it < commandRule.end()) && (wxIsalpha(*it))) || ((*it == '_'))) {
       word += *it;
-      it++;
+      ++it;
     }
     if (!m_maximaManual->GetHelpfileAnchorName(word).IsEmpty())
       m_manualKeywords[word] = 1;
   }
-  if (commandRule.Contains(wxT("''")))
-    m_manualKeywords[wxT("''")] = 1;
-  if (commandRule.Contains(wxT("'")))
-    m_manualKeywords[wxT("'")] = 1;
-  if (commandRule.Contains(wxT("!")))
-    m_manualKeywords[wxT("!")] = 1;
-  if (commandRule.Contains(wxT(";")))
-    m_manualKeywords[wxT(";")] = 1;
-  if (commandRule.Contains(wxT("$")))
-    m_manualKeywords[wxT("$")] = 1;
-  if (commandRule.Contains(wxT("\\")))
-    m_manualKeywords[wxT("\\")] = 1;
+  if (commandRule.Contains(wxS("''")))
+    m_manualKeywords[wxS("''")] = 1;
+  if (commandRule.Contains(wxS("'")))
+    m_manualKeywords[wxS("'")] = 1;
+  if (commandRule.Contains(wxS("!")))
+    m_manualKeywords[wxS("!")] = 1;
+  if (commandRule.Contains(wxS(";")))
+    m_manualKeywords[wxS(";")] = 1;
+  if (commandRule.Contains(wxS("$")))
+    m_manualKeywords[wxS("$")] = 1;
+  if (commandRule.Contains(wxS("\\")))
+    m_manualKeywords[wxS("\\")] = 1;
   wxString hashFinder = commandRule;
-  hashFinder.Replace(wxT("#1#"), wxEmptyString);
-  hashFinder.Replace(wxT("#2#"), wxEmptyString);
-  hashFinder.Replace(wxT("#3#"), wxEmptyString);
-  hashFinder.Replace(wxT("#4#"), wxEmptyString);
-  hashFinder.Replace(wxT("#5#"), wxEmptyString);
-  hashFinder.Replace(wxT("#6#"), wxEmptyString);
-  hashFinder.Replace(wxT("#7#"), wxEmptyString);
-  hashFinder.Replace(wxT("#8#"), wxEmptyString);
-  hashFinder.Replace(wxT("#9#"), wxEmptyString);
-  if (hashFinder.Contains(wxT("#")))
-    m_manualKeywords[wxT("#")] = 1;
+  hashFinder.Replace(wxS("#1#"), wxEmptyString);
+  hashFinder.Replace(wxS("#2#"), wxEmptyString);
+  hashFinder.Replace(wxS("#3#"), wxEmptyString);
+  hashFinder.Replace(wxS("#4#"), wxEmptyString);
+  hashFinder.Replace(wxS("#5#"), wxEmptyString);
+  hashFinder.Replace(wxS("#6#"), wxEmptyString);
+  hashFinder.Replace(wxS("#7#"), wxEmptyString);
+  hashFinder.Replace(wxS("#8#"), wxEmptyString);
+  hashFinder.Replace(wxS("#9#"), wxEmptyString);
+  if (hashFinder.Contains(wxS("#")))
+    m_manualKeywords[wxS("#")] = 1;
   m_ignorePageChange = true;
   long page = m_configuration->WizardTab();
   if (page < 0)
@@ -235,13 +241,14 @@ void GenWizPanel::NewWizard(
 		     desc,
 		     wxSizerFlags(1).Border(wxALL, 0 * GetContentScaleFactor()).Expand());
     }
-    int id = wxID_HIGHEST + 5000;
-    int buttonNum = 0;
-    for (auto i : m_manualKeywords) {
+    
+    m_topicButtonID0 = wxWindow::NewControlId(m_manualKeywords.size());
+    int id = m_topicButtonID0;
+    for (const auto &i : m_manualKeywords) {
       wxButton *button = new wxButton(
 				      descriptionpane, id, wxString::Format(_("Help on %s"), i.first));
       pageSizer->Add(button, wxSizerFlags(0).Expand());
-      buttonNum++;
+      m_topicButtonIDs.push_back(id);
       id++;
     }
     descriptionpane->SetSizer(pageSizer);
@@ -308,13 +315,13 @@ void GenWizPanel::NewWizard(
   m_ignorePageChange = false;
 }
 
-wxString GenWizPanel::GetHelpKeyword(unsigned int ID) {
-  if (ID < wxID_HIGHEST + 5000)
+wxString GenWizPanel::GetHelpKeyword(wxWindowID ID) {
+  if (ID < m_topicButtonID0)
     return wxEmptyString;
-  ID -= wxID_HIGHEST + 5000;
-  if (ID >= m_manualKeywords.size())
+  ID -= m_topicButtonID0;
+  if (static_cast<unsigned>(ID) >= m_manualKeywords.size())
     return wxEmptyString;
-  for (auto i : m_manualKeywords) {
+  for (const auto &i : m_manualKeywords) {
     if (ID-- == 0)
       return i.first;
   }
