@@ -32,7 +32,13 @@
 #include <wx/notebook.h>
 #include "MaximaManual.h"
 #include <wx/hashmap.h>
+#include <unordered_map>
 
+
+/*! A dockable, embeddable generic wizard
+
+  The generic wizard dialogue we use almost everywhere where a wizard is needed.
+ */
 class GenWizPanel : public wxPanel
 {
 public:
@@ -61,7 +67,8 @@ public:
               wxString label7 = {}, wxString defaultval7 = {}, wxString tooltip7 = {},
               wxString label8 = {}, wxString defaultval8 = {}, wxString tooltip8 = {},
               wxString label9 = {}, wxString defaultval9 = {}, wxString tooltip9 = {});
-  
+
+  //! Replace the contents of this panel with a new wizard
   void NewWizard(wxString description, const wxString &description_tooltip,
                  const wxString &commandRule,
                  wxString label1, wxString defaultval1, wxString tooltip1,
@@ -73,9 +80,11 @@ public:
                  wxString label7, wxString defaultval7, wxString tooltip7,
                  wxString label8, wxString defaultval8, wxString tooltip8,
                  wxString label9, wxString defaultval9, wxString tooltip9);
-  
+
+  //! Returns the contents of the nth field. 
   wxString operator[](int i) const { return m_textctrl[i]->GetValue(); }
 
+  //! Returns the command the wizard has generated, if commandRule wasn't empty
   wxString GetOutput() const {return m_output->GetValue();}
 
 #if defined __WXMSW__
@@ -86,13 +95,16 @@ public:
   wxButton *GetAbortButton() const {return button_1;}
 #endif
   wxButton *GetInsertButton() const{return m_insertButton;}
-  wxString GetHelpKeyword(unsigned int ID);
+  wxString GetHelpKeyword(wxWindowID ID);
   virtual ~GenWizPanel();
 protected:
+#if wxCHECK_VERSION(3, 3, 0) || wxUSE_STL
+  typedef std::unordered_map <wxString, int> keywordHash;
+#else
   WX_DECLARE_STRING_HASH_MAP(int, keywordHash);
+#endif
 
   void OnSize(wxSizeEvent &event);
-  wxSizer *m_descriptionSizer;
   wxNotebook *m_notebook;
   void UpdateOutput();
   void OnParamChange(wxCommandEvent& event);
@@ -103,7 +115,7 @@ protected:
   std::vector<wxStaticText *> m_label;
   wxButton *button_1;
   wxButton *button_2;
-  wxContextHelpButton *m_helpButton;
+  wxContextHelpButton *m_helpButton = NULL;
   wxButton *m_insertButton;
   wxString m_commandRule;
   wxTextCtrl *m_output;
@@ -113,6 +125,8 @@ protected:
   Configuration *m_configuration;
   MaximaManual *m_maximaManual;
 private:
+  int m_topicButtonID0;
+  std::vector<wxWindowIDRef> m_topicButtonIDs;
   bool m_ignorePageChange = true;
   keywordHash m_manualKeywords;
 };
