@@ -21,6 +21,7 @@
 //  SPDX-License-Identifier: GPL-2.0+
 
 #include "Plot2dWiz.h"
+#include "../EventIDs.h"
 
 #include <wx/artprov.h>
 #include <wx/config.h>
@@ -31,29 +32,37 @@ Plot2DWiz::Plot2DWiz(wxWindow *parent, int id, Configuration *cfg,
                      const wxSize &size, long style)
   : wxDialog(parent, id, title, pos, size, style) {
   m_configuration = cfg;
+
+  Connect(wxEVT_MENU, EventIDs::wizard_parametric_plot,
+	  wxCommandEventHandler(Plot2DWiz::OnPopupMenu), NULL, this);
+  Connect(wxEVT_MENU, EventIDs::wizard_discrete_plot,
+	  wxCommandEventHandler(Plot2DWiz::OnPopupMenu), NULL, this);
+
   label_2 = new wxStaticText(this, -1, _("Expression(s):"));
   text_ctrl_1 = new BTextCtrl(this, -1, cfg, wxEmptyString, wxDefaultPosition,
                               wxSize(300, -1));
-  button_3 = new wxButton(this, special, _("&Special"));
+  button_3 = new wxButton(this, wxID_ANY, _("&Special"));
+  button_3->Connect(wxEVT_BUTTON, wxCommandEventHandler(Plot2DWiz::OnButton), NULL, this);
+
   label_3 = new wxStaticText(this, -1, _("Variable:"));
   text_ctrl_2 =
-    new BTextCtrl(this, -1, cfg, wxT("x"), wxDefaultPosition, wxSize(40, -1));
+    new BTextCtrl(this, -1, cfg, wxS("x"), wxDefaultPosition, wxSize(40, -1));
   label_4 = new wxStaticText(this, -1, _("From:"));
-  text_ctrl_3 = new BTextCtrl(this, -1, cfg, wxT("-5"), wxDefaultPosition,
+  text_ctrl_3 = new BTextCtrl(this, -1, cfg, wxS("-5"), wxDefaultPosition,
                               wxSize(70, -1));
   label_5 = new wxStaticText(this, -1, _("To:"));
   text_ctrl_4 =
-    new BTextCtrl(this, -1, cfg, wxT("5"), wxDefaultPosition, wxSize(70, -1));
+    new BTextCtrl(this, -1, cfg, wxS("5"), wxDefaultPosition, wxSize(70, -1));
   check_box_1 = new wxCheckBox(this, -1, _("logscale"));
   label_6 = new wxStaticText(this, -1, _("Variable:"));
-  text_ctrl_5 = new BTextCtrl(this, -1, cfg, wxT("y"), wxDefaultPosition,
+  text_ctrl_5 = new BTextCtrl(this, -1, cfg, wxS("y"), wxDefaultPosition,
                               wxSize(40, -1), wxTE_READONLY);
   label_7 = new wxStaticText(this, -1, _("From:"));
-  text_ctrl_6 = new BTextCtrl(this, -1, cfg, wxT("-5"), wxDefaultPosition,
+  text_ctrl_6 = new BTextCtrl(this, -1, cfg, wxS("-5"), wxDefaultPosition,
                               wxSize(70, -1));
   label_8 = new wxStaticText(this, -1, _("To:"));
   text_ctrl_7 =
-    new BTextCtrl(this, -1, cfg, wxT("5"), wxDefaultPosition, wxSize(70, -1));
+    new BTextCtrl(this, -1, cfg, wxS("5"), wxDefaultPosition, wxSize(70, -1));
   check_box_2 = new wxCheckBox(this, -1, _("logscale"));
   label_9 = new wxStaticText(this, -1, _("Ticks:"));
   text_ctrl_8 = new wxSpinCtrl(this, -1, wxEmptyString, wxDefaultPosition,
@@ -61,23 +70,27 @@ Plot2DWiz::Plot2DWiz(wxWindow *parent, int id, Configuration *cfg,
   text_ctrl_8->SetValue(10);
   label_10 = new wxStaticText(this, -1, _("Format:"));
   const wxString combo_box_1_choices[] = {_("default"), _("inline"),
-    wxT("gnuplot"), wxT("xmaxima")};
+    wxS("gnuplot"), wxS("xmaxima")};
   combo_box_1 =
     new wxComboBox(this, -1, wxEmptyString, wxDefaultPosition,
 		   wxSize(150, -1), 4, combo_box_1_choices, wxCB_DROPDOWN);
   label_11 = new wxStaticText(this, -1, _("Options:"));
   const wxString combo_box_2_choices[] = {
-    wxT("set zeroaxis;"), wxT("set size ratio 1; set zeroaxis;"),
-    wxT("set grid;"), wxT("set polar; set zeroaxis;")};
+    wxS("set zeroaxis;"), wxS("set size ratio 1; set zeroaxis;"),
+    wxS("set grid;"), wxS("set polar; set zeroaxis;")};
   combo_box_2 =
-    new wxComboBox(this, combobox, wxEmptyString, wxDefaultPosition,
+    new wxComboBox(this, wxID_ANY, wxEmptyString, wxDefaultPosition,
 		   wxSize(280, -1), 4, combo_box_2_choices, wxCB_DROPDOWN);
+  combo_box_2->Connect(wxEVT_COMBOBOX, wxCommandEventHandler(Plot2DWiz::OnCombobox), NULL, this);
+
   label_12 = new wxStaticText(this, -1, _("File:"));
   text_ctrl_9 = new BTextCtrl(this, -1, cfg, wxEmptyString, wxDefaultPosition,
                               wxSize(280, -1));
   button_4 = new wxBitmapButton(
-				this, file_browse_2d,
+				this, wxID_ANY,
 				wxArtProvider::GetBitmap(wxART_FILE_OPEN, wxART_HELP_BROWSER));
+  button_4->Connect(wxEVT_BUTTON, wxCommandEventHandler(Plot2DWiz::OnFileBrowse), NULL, this);
+
   static_line_1 = new wxStaticLine(this, -1);
 #if defined __WXMSW__
   button_1 = new wxButton(this, wxID_OK, _("OK"));
@@ -95,10 +108,10 @@ Plot2DWiz::Plot2DWiz(wxWindow *parent, int id, Configuration *cfg,
 
 void Plot2DWiz::set_properties() {
   SetTitle(_("Plot 2D"));
-  text_ctrl_3->SetValue(wxT("-5"));
-  text_ctrl_4->SetValue(wxT("5"));
-  text_ctrl_6->SetValue(wxT("0"));
-  text_ctrl_7->SetValue(wxT("0"));
+  text_ctrl_3->SetValue(wxS("-5"));
+  text_ctrl_4->SetValue(wxS("5"));
+  text_ctrl_6->SetValue(wxS("0"));
+  text_ctrl_7->SetValue(wxS("0"));
 
   button_4->SetToolTip(_("Browse"));
 #if defined __WXMSW__
@@ -111,10 +124,10 @@ void Plot2DWiz::set_properties() {
   bool sendRanges = false;
   bool logx = false, logy = false;
 
-  wxConfig::Get()->Read(wxT("Wiz/Plot2D/format"), &selection);
-  wxConfig::Get()->Read(wxT("Wiz/Plot2D/sendRanges"), &sendRanges);
-  wxConfig::Get()->Read(wxT("Wiz/Plot2D/logx"), &logx);
-  wxConfig::Get()->Read(wxT("Wiz/Plot2D/logy"), &logy);
+  wxConfig::Get()->Read(wxS("Wiz/Plot2D/format"), &selection);
+  wxConfig::Get()->Read(wxS("Wiz/Plot2D/sendRanges"), &sendRanges);
+  wxConfig::Get()->Read(wxS("Wiz/Plot2D/logx"), &logx);
+  wxConfig::Get()->Read(wxS("Wiz/Plot2D/logy"), &logy);
 
   check_box_1->SetValue(logx);
   check_box_2->SetValue(logy);
@@ -182,9 +195,9 @@ void Plot2DWiz::do_layout() {
 }
 
 void Plot2DWiz::SetValue(wxString s) {
-  if (s.StartsWith(wxT("plot2d")))
+  if (s.StartsWith(wxS("plot2d")))
     Parse(s);
-  else if (s.StartsWith(wxT("wxplot2d"))) {
+  else if (s.StartsWith(wxS("wxplot2d"))) {
     Parse(s.SubString(2, s.Length()));
     combo_box_1->SetValue(_("inline"));
   } else
@@ -253,7 +266,7 @@ void Plot2DWiz::Parse(wxString s) {
       }
       curr.Trim();
       curr.Trim(false);
-      if (curr == wxT("y")) {
+      if (curr == wxS("y")) {
         curr = wxEmptyString;
         i++;
         while (i < s.Length() && s.GetChar(i) != ',') {
@@ -269,7 +282,7 @@ void Plot2DWiz::Parse(wxString s) {
         }
         text_ctrl_7->SetValue(curr);
         i++;
-      } else if (curr == wxT("gnuplot_postamble")) {
+      } else if (curr == wxS("gnuplot_postamble")) {
         while (i < s.Length() && s.GetChar(i) != '"')
           i++;
         i++;
@@ -279,7 +292,7 @@ void Plot2DWiz::Parse(wxString s) {
           i++;
         }
         combo_box_2->SetValue(curr);
-      } else if (curr == wxT("gnuplot_out_file")) {
+      } else if (curr == wxS("gnuplot_out_file")) {
         while (i < s.Length() && s.GetChar(i) != '"')
           i++;
         i++;
@@ -289,7 +302,7 @@ void Plot2DWiz::Parse(wxString s) {
           i++;
         }
         text_ctrl_9->SetValue(curr);
-      } else if (curr == wxT("nticks")) {
+      } else if (curr == wxS("nticks")) {
         curr = wxEmptyString;
         while (i < s.Length() && s.GetChar(i) != ',')
           i++;
@@ -299,11 +312,11 @@ void Plot2DWiz::Parse(wxString s) {
           i++;
         }
         text_ctrl_8->SetValue(curr);
-      } else if (curr == wxT("logx")) {
+      } else if (curr == wxS("logx")) {
         check_box_1->SetValue(true);
         while (i < s.Length() && s.GetChar(i) != ']')
           i++;
-      } else if (curr == wxT("logy")) {
+      } else if (curr == wxS("logy")) {
         check_box_2->SetValue(true);
         while (i < s.Length() && s.GetChar(i) != ']')
           i++;
@@ -325,66 +338,66 @@ wxString Plot2DWiz::GetValue() {
   wxString file = text_ctrl_9->GetValue(); // plot to file
 
   // Expression
-  s = wxT("plot2d([") + text_ctrl_1->GetValue();
-  s += wxT("], [");
+  s = wxS("plot2d([") + text_ctrl_1->GetValue();
+  s += wxS("], [");
 
   // x-range
   s += text_ctrl_2->GetValue();
-  s += wxT(",");
-  if (x1 != wxT("0") || x2 != wxT("0"))
-    s += x1 + wxT(",") + x2;
+  s += wxS(",");
+  if (x1 != wxS("0") || x2 != wxS("0"))
+    s += x1 + wxS(",") + x2;
   else if (type == polar)
-    s += wxT("0,2*%pi");
+    s += wxS("0,2*%pi");
   else
-    s += wxT("-5,5");
-  s += wxT("]");
+    s += wxS("-5,5");
+  s += wxS("]");
 
   // y-range
-  if (y1 != wxT("0") || y2 != wxT("0")) {
-    s += wxT(", [");
+  if (y1 != wxS("0") || y2 != wxS("0")) {
+    s += wxS(", [");
     s += text_ctrl_5->GetValue();
-    s += wxT(",") + y1 + wxT(",") + y2 + wxT("]");
+    s += wxS(",") + y1 + wxS(",") + y2 + wxS("]");
   }
 
   // plot format
   if (f != _("default") && f != _("inline"))
-    s += wxT(",\n [plot_format, ") + f + wxT("]");
+    s += wxS(",\n [plot_format, ") + f + wxS("]");
 
   // gnuplot_postamble
   if (p.Length() > 0)
-    s += wxT(",\n [gnuplot_postamble, \"") + p + wxT("\"]");
+    s += wxS(",\n [gnuplot_postamble, \"") + p + wxS("\"]");
   if (t != 10) {
-    s += wxT(",\n [nticks,");
-    s += wxString::Format(wxT("%d"), t);
-    s += wxT("]");
+    s += wxS(",\n [nticks,");
+    s += wxString::Format(wxS("%d"), t);
+    s += wxS("]");
   }
 
   // check for logscales
   if (check_box_1->IsChecked())
-    s += wxT(", [logx]");
+    s += wxS(", [logx]");
   if (check_box_2->IsChecked())
-    s += wxT(", [logy]");
+    s += wxS(", [logy]");
 
   // plot to file
   if (file.Length()) {
-    s += wxT(", [gnuplot_term, ps]");
+    s += wxS(", [gnuplot_term, ps]");
 #if defined(__WXMSW__)
-    file.Replace(wxT("\\"), wxT("/"));
+    file.Replace(wxS("\\"), wxS("/"));
 #endif
 
-    if (file.Right(4) != wxT(".eps") && file.Right(3) != wxT(".ps"))
-      file = file + wxT(".eps");
-    s += wxT(",\n [gnuplot_out_file, \"") + file + wxT("\"]");
+    if (file.Right(4) != wxS(".eps") && file.Right(3) != wxS(".ps"))
+      file = file + wxS(".eps");
+    s += wxS(",\n [gnuplot_out_file, \"") + file + wxS("\"]");
   }
   // inline?
   else if (f == _("inline"))
-    s = wxT("wx") + s;
+    s = wxS("wx") + s;
 
-  s += wxT(")$");
+  s += wxS(")$");
 
-  wxConfig::Get()->Write(wxT("Wiz/Plot2D/format"), combo_box_1->GetSelection());
-  wxConfig::Get()->Write(wxT("Wiz/Plot2D/logx"), check_box_1->GetValue());
-  wxConfig::Get()->Write(wxT("Wiz/Plot2D/logy"), check_box_2->GetValue());
+  wxConfig::Get()->Write(wxS("Wiz/Plot2D/format"), combo_box_1->GetSelection());
+  wxConfig::Get()->Write(wxS("Wiz/Plot2D/logx"), check_box_1->GetValue());
+  wxConfig::Get()->Write(wxS("Wiz/Plot2D/logy"), check_box_2->GetValue());
 
   return s;
 }
@@ -392,8 +405,8 @@ wxString Plot2DWiz::GetValue() {
 void Plot2DWiz::OnButton(wxCommandEvent &WXUNUSED(event)) {
   wxMenu *popupMenu = new wxMenu();
 
-  popupMenu->Append(parametric_plot, _("Parametric plot"));
-  popupMenu->Append(discrete_plot, _("Discrete plot"));
+  popupMenu->Append(EventIDs::wizard_parametric_plot, _("Parametric plot"));
+  popupMenu->Append(EventIDs::wizard_discrete_plot, _("Discrete plot"));
 
   wxPoint pos = button_3->GetPosition();
   pos.y += button_3->GetRect().height;
@@ -402,95 +415,83 @@ void Plot2DWiz::OnButton(wxCommandEvent &WXUNUSED(event)) {
 }
 
 void Plot2DWiz::OnPopupMenu(wxCommandEvent &event) {
-  switch (event.GetId()) {
-  case parametric_plot: {
+  if(event.GetId() == EventIDs::wizard_parametric_plot) {
     wxWindowPtr<Plot2DPar> wiz(new Plot2DPar(this, -1, m_configuration, _("Plot 2D")));
     wiz->Centre(wxBOTH);
     wiz->ShowWindowModalThenDo([this,wiz](int retcode) {
       if (retcode == wxID_OK) {
-        if (text_ctrl_1->GetValue() == wxT("%"))
+        if (text_ctrl_1->GetValue() == wxS("%"))
           text_ctrl_1->SetValue(wxEmptyString);
         if (((text_ctrl_1->GetValue()).Strip()).Length())
-          text_ctrl_1->AppendText(wxT(", "));
+          text_ctrl_1->AppendText(wxS(", "));
         text_ctrl_1->AppendText(wiz->GetValue());
       }
     });
   } //-V773
-    break;
-  case discrete_plot: {
+  if(event.GetId() == EventIDs::wizard_discrete_plot) {
     wxWindowPtr<Plot2DDiscrete> wiz(new Plot2DDiscrete(this, -1, m_configuration, _("Plot 2D")));
     wiz->Centre(wxBOTH);
     wiz->ShowWindowModalThenDo([this,wiz](int retcode) {
       if (retcode == wxID_OK) {
-        if (text_ctrl_1->GetValue() == wxT("%"))
+        if (text_ctrl_1->GetValue() == wxS("%"))
           text_ctrl_1->SetValue(wxEmptyString);
         if (((text_ctrl_1->GetValue()).Strip()).Length())
-          text_ctrl_1->AppendText(wxT(", "));
+          text_ctrl_1->AppendText(wxS(", "));
         text_ctrl_1->AppendText(wiz->GetValue());
       }
     });
-  } //-V773
-    break;
   }
 }
 
 void Plot2DWiz::OnCombobox(wxCommandEvent &WXUNUSED(event)) {
   wxString selection = combo_box_2->GetStringSelection();
-  if (selection.StartsWith(wxT("set polar"))) {
-    text_ctrl_2->SetValue(wxT("ph"));
-    text_ctrl_3->SetValue(wxT("0"));
-    text_ctrl_4->SetValue(wxT("2*%pi"));
+  if (selection.StartsWith(wxS("set polar"))) {
+    text_ctrl_2->SetValue(wxS("ph"));
+    text_ctrl_3->SetValue(wxS("0"));
+    text_ctrl_4->SetValue(wxS("2*%pi"));
     type = polar;
   } else
     type = cartesian;
 
-  if (selection.StartsWith(wxT("set logscale x"))) {
-    text_ctrl_3->SetValue(wxT("0"));
-    text_ctrl_4->SetValue(wxT("100"));
+  if (selection.StartsWith(wxS("set logscale x"))) {
+    text_ctrl_3->SetValue(wxS("0"));
+    text_ctrl_4->SetValue(wxS("100"));
   }
 }
 
 void Plot2DWiz::OnFileBrowse(wxCommandEvent &WXUNUSED(event)) {
   wxString file =
-    wxFileSelector(_("Save plot to file"), wxEmptyString, wxT("plot2d.eps"),
-		   wxT("eps"), _("Postscript file (*.eps)|*.eps|All|*"),
+    wxFileSelector(_("Save plot to file"), wxEmptyString, wxS("plot2d.eps"),
+		   wxS("eps"), _("Postscript file (*.eps)|*.eps|All|*"),
 		   wxFD_SAVE | wxFD_OVERWRITE_PROMPT);
   if (file.Length() > 0)
     text_ctrl_9->SetValue(file);
 }
 
-wxBEGIN_EVENT_TABLE(Plot2DWiz, wxDialog)
-EVT_COMBOBOX(combobox, Plot2DWiz::OnCombobox)
-EVT_BUTTON(special, Plot2DWiz::OnButton)
-EVT_BUTTON(file_browse_2d, Plot2DWiz::OnFileBrowse)
-EVT_MENU(parametric_plot, Plot2DWiz::OnPopupMenu)
-EVT_MENU(discrete_plot, Plot2DWiz::OnPopupMenu)
-wxEND_EVENT_TABLE()
-
 ///////////////////////
 //
 // Plot2DPar
 //
 ///////////////////////
 
-Plot2DPar::Plot2DPar(wxWindow *parent, int id, Configuration *cfg,
+Plot2DPar::Plot2DPar(wxWindow *parent, int id, Configuration *configuration,
 		     const wxString &title, const wxPoint &pos,
 		     const wxSize &size, long style)
 : wxDialog(parent, id, title, pos, size, style) {
-  label_2 = new wxStaticText(this, -1, wxT("x = "));
-  text_ctrl_1 = new BTextCtrl(this, -1, cfg, wxEmptyString, wxDefaultPosition,
+  label_2 = new wxStaticText(this, -1, wxS("x = "));
+  text_ctrl_1 = new BTextCtrl(this, -1, configuration, wxEmptyString, wxDefaultPosition,
                               wxSize(230, -1));
-  label_3 = new wxStaticText(this, -1, wxT("y = "));
-  text_ctrl_2 = new BTextCtrl(this, -1, cfg, wxEmptyString, wxDefaultPosition,
+  label_3 = new wxStaticText(this, -1, wxS("y = "));
+  text_ctrl_2 = new BTextCtrl(this, -1, configuration, wxEmptyString, wxDefaultPosition,
                               wxSize(230, -1));
   label_4 = new wxStaticText(this, -1, _("Variable:"));
   text_ctrl_3 =
-    new BTextCtrl(this, -1, cfg, wxT("t"), wxDefaultPosition, wxSize(40, -1));
+    new BTextCtrl(this, -1, configuration, wxS("t"), wxDefaultPosition, wxSize(40, -1));
   label_5 = new wxStaticText(this, -1, _("From:"));
-  text_ctrl_4 = new BTextCtrl(this, -1, cfg, wxEmptyString, wxDefaultPosition,
+  text_ctrl_4 = new BTextCtrl(this, -1, configuration, wxEmptyString, wxDefaultPosition,
                               wxSize(70, -1));
   label_6 = new wxStaticText(this, -1, _("To:"));
-  text_ctrl_5 = new BTextCtrl(this, -1, cfg, wxEmptyString, wxDefaultPosition,
+  text_ctrl_5 = new BTextCtrl(this, -1, configuration, wxEmptyString, wxDefaultPosition,
                               wxSize(70, -1));
   label_7 = new wxStaticText(this, -1, _("Ticks:"));
   spin_ctrl_1 = new wxSpinCtrl(this, -1, wxEmptyString, wxDefaultPosition,
@@ -511,8 +512,8 @@ Plot2DPar::Plot2DPar(wxWindow *parent, int id, Configuration *cfg,
 
 void Plot2DPar::set_properties() {
   SetTitle(_("Parametric plot"));
-  text_ctrl_4->SetValue(wxT("-6"));
-  text_ctrl_5->SetValue(wxT("6"));
+  text_ctrl_4->SetValue(wxS("-6"));
+  text_ctrl_5->SetValue(wxS("6"));
 #if defined __WXMSW__
   button_1->SetDefault();
 #else
@@ -559,18 +560,18 @@ void Plot2DPar::do_layout() {
 
 wxString Plot2DPar::GetValue() {
   wxString s;
-  s = wxT("'parametric, ");
+  s = wxS("'parametric, ");
   s += text_ctrl_1->GetValue();
-  s += wxT(", ");
+  s += wxS(", ");
   s += text_ctrl_2->GetValue();
-  s += wxT(", [");
+  s += wxS(", [");
   s += text_ctrl_3->GetValue();
-  s += wxT(", ");
+  s += wxS(", ");
   s += text_ctrl_4->GetValue();
-  s += wxT(", ");
+  s += wxS(", ");
   s += text_ctrl_5->GetValue();
-  s += wxT("]], ");
-  s += wxString::Format(wxT("[nticks, %d"), spin_ctrl_1->GetValue());
+  s += wxS("]], ");
+  s += wxString::Format(wxS("[nticks, %d"), spin_ctrl_1->GetValue());
 
   return s;
 }
@@ -585,10 +586,10 @@ Plot2DDiscrete::Plot2DDiscrete(wxWindow *parent, int id, Configuration *cfg,
                                const wxString &title, const wxPoint &pos,
                                const wxSize &size, long style)
   : wxDialog(parent, id, title, pos, size, style) {
-  label_2 = new wxStaticText(this, -1, wxT("x = "));
+  label_2 = new wxStaticText(this, -1, wxS("x = "));
   text_ctrl_1 = new BTextCtrl(this, -1, cfg, wxEmptyString, wxDefaultPosition,
                               wxSize(230, -1));
-  label_3 = new wxStaticText(this, -1, wxT("y = "));
+  label_3 = new wxStaticText(this, -1, wxS("y = "));
   text_ctrl_2 = new BTextCtrl(this, -1, cfg, wxEmptyString, wxDefaultPosition,
                               wxSize(230, -1));
 
@@ -644,11 +645,11 @@ void Plot2DDiscrete::do_layout() {
 
 wxString Plot2DDiscrete::GetValue() {
   wxString s;
-  s = wxT("['discrete, [");
+  s = wxS("['discrete, [");
   s += text_ctrl_1->GetValue();
-  s += wxT("], [");
+  s += wxS("], [");
   s += text_ctrl_2->GetValue();
-  s += wxT("]]");
+  s += wxS("]]");
 
   return s;
 }
