@@ -34,53 +34,42 @@
 #include <wx/wx.h>
 
 wxMathML::wxMathML(Configuration *config) : m_configuration(config) {
-  m_wxMathML_UseFile = m_configuration->WxMathML_UseFile();
 }
 
 wxString wxMathML::GetCmd() {
-  // If we read wxMathML from a file we should read it anew, just in case
-  // the file has changed.
-  // If we have transitioned from using a file to using the internal
-  // data we read the info anew, instead, as it might differ from the file.
-  if (m_configuration->WxMathML_UseFile() || m_wxMathML_UseFile)
-    m_maximaCMD = wxEmptyString;
-  m_wxMathML_UseFile = m_configuration->WxMathML_UseFile();
+  m_maximaCMD = wxEmptyString;
 
-  if ((m_maximaCMD.IsEmpty() || (m_configuration->WxMathML_UseFile()))) {
-    if (!m_configuration->WxMathML_UseFile()) {
-      wxLogMessage(_(
-		     "Reading the Lisp part of wxMaxima from the included header file."));
-      wxMemoryInputStream istream(WXMATHML_LISP, WXMATHML_LISP_SIZE);
-      wxTextInputStream textIn(istream);
-      wxString line;
+  if (Get_MathML_Filename().IsEmpty()) {
+    wxLogMessage(_("Reading the Lisp part of wxMaxima from the included header file."));
+    wxMemoryInputStream istream(WXMATHML_LISP, WXMATHML_LISP_SIZE);
+    wxTextInputStream textIn(istream);
+    wxString line;
 
-      while (!istream.Eof()) {
-        line = textIn.ReadLine();
-        m_wxMathML += line + wxT("\n");
-      }
-      wxASSERT_MSG(m_wxMathML.Length() > 64000,
-                   _("Compiler-Bug? wxMathml.lisp is shorter than expected!"));
-    } else {
-      wxLogMessage(wxString::Format(
-				    _("Reading the Lisp part of wxMaxima from the file %s"),
-				    m_configuration->WxMathML_Filename().ToUTF8().data()));
-      wxFileInputStream input(m_configuration->WxMathML_Filename());
-      wxTextInputStream textIn(input);
-      wxString line;
+    while (!istream.Eof()) {
+      line = textIn.ReadLine();
+      m_wxMathML += line + wxS("\n");
+    }
+    wxASSERT_MSG(m_wxMathML.Length() > 64000,
+                 _("Compiler-Bug? wxMathml.lisp is shorter than expected!"));
+  } else {
+    wxLogMessage(_("Reading the Lisp part of wxMaxima from the file %s"),
+		 Get_MathML_Filename().mb_str());
+    wxFileInputStream input(Get_MathML_Filename());
+    wxTextInputStream textIn(input);
+    wxString line;
 
-      while (!input.Eof()) {
-        line = textIn.ReadLine();
-        m_wxMathML += line + wxT("\n");
-      }
+    while (!input.Eof()) {
+      line = textIn.ReadLine();
+      m_wxMathML += line + wxS("\n");
     }
   }
-  wxStringTokenizer lines(m_wxMathML, wxT("\n"));
+  wxStringTokenizer lines(m_wxMathML, wxS("\n"));
   while (lines.HasMoreTokens()) {
     wxString line = lines.GetNextToken();
     wxString lineWithoutComments;
 
     bool stringIs = false;
-    wxChar lastChar = wxT('\n');
+    wxChar lastChar = wxS('\n');
     wxString::const_iterator ch = line.begin();
     while (ch < line.end()) {
       // Remove formatting spaces
@@ -88,16 +77,16 @@ wxString wxMathML::GetCmd() {
         ++ch;
       else {
         // Handle backslashes that might escape double quotes
-        if (*ch == wxT('\\')) {
+        if (*ch == wxS('\\')) {
           lineWithoutComments += *ch;
           ++ch;
         } else {
           // Handle strings
-          if (*ch == wxT('\"'))
+          if (*ch == wxS('\"'))
             stringIs = !stringIs;
 
           // Handle comments
-          if ((*ch == wxT(';')) && (!stringIs))
+          if ((*ch == wxS(';')) && (!stringIs))
             break;
         }
         lineWithoutComments += *ch;
@@ -107,12 +96,13 @@ wxString wxMathML::GetCmd() {
     }
     m_maximaCMD += lineWithoutComments + " ";
   }
-  if (!m_configuration->WxMathML_UseFile())
+  if (!Get_MathML_Filename().IsEmpty())
     wxASSERT_MSG(m_maximaCMD.Length() > 54000,
                  _("Bug: After removing the whitespace wxMathml.lisp is "
                    "shorter than expected!"));
-  m_maximaCMD = wxT(":lisp-quiet ") + m_maximaCMD + "\n";
+  m_maximaCMD = wxS(":lisp-quiet ") + m_maximaCMD + "\n";
 
   return m_maximaCMD;
 }
 wxString wxMathML::m_maximaCMD;
+wxString wxMathML::m_wxMathML_file;
