@@ -51,6 +51,7 @@
 #ifdef __WXMSW__
 #include <windows.h>
 #endif
+#include <unordered_map>
 #define DOCUMENT_VERSION_MAJOR 1
 /*! The part of the .wxmx format version number that appears after the dot.
 
@@ -81,17 +82,32 @@ class MaximaEvent;
 class wxMaxima : public wxMaximaFrame
 {
 public:
-  wxMaxima(wxWindow *parent, int id, wxLocale *locale, const wxString title,
+  wxMaxima(wxWindow *parent, int id, const wxString title,
            const wxString &filename = wxEmptyString,
            const wxPoint pos = wxDefaultPosition, const wxSize size = wxDefaultSize);
 
   virtual ~wxMaxima();
 
+  wxString EscapeFilenameForShell(wxString name);
   //! Pipe maxima's output to stdout
   static void PipeToStdout(){m_pipeToStderr = true;}
+  //! Pipe maxima's output to stdout?
+  static bool GetPipeToStdout(){return m_pipeToStderr;}
+  //! Exit if we encounter an error
   static void ExitOnError(){m_exitOnError = true;}
+  //! Do we exit if we encounter an error?
+  static bool GetExitOnError(){return m_exitOnError;}
+  /*! Allow maxima to click buttons in wxMaxima
+
+    Disabled by default for security reasons
+   */
   static void EnableIPC(){ MaximaIPC::EnableIPC(); }
+  //! Do we allow maxima to click buttons in wxMaxima?
+  static bool GetEnableIPC(){ return MaximaIPC::GetEnableIPC(); }
+  //! Additional maxima arguments from the command line
   static void ExtraMaximaArgs(const wxString &args){m_extraMaximaArgs = args;}
+  //! Which additional maxima arguments did we get from the command line?
+  static wxString ExtraMaximaArgs(){return m_extraMaximaArgs;}
 
   //! An enum of individual IDs for all timers this class handles
   enum TimerIDs
@@ -104,9 +120,9 @@ public:
     MAXIMA_STDOUT_POLL_ID
   };
 
-#ifdef wxHAS_POWER_EVENTS 
+#ifdef wxHAS_POWER_EVENTS
   void OnPowerEvent(wxPowerEvent &event);
-#endif 
+#endif
 
   //! Is triggered when a timer this class is responsible for requires
   void OnTimerEvent(wxTimerEvent &event);
@@ -170,7 +186,15 @@ public:
     long m_patchlevel;
   };
 
+  //! Use this maxima command (from a command line option) instead of the configured path
+  static void Set_Maxima_Commandline_Filename(wxString filename) {maxima_command_line_filename = filename;}
+  //! The maxima command, if we use the --maxima=<str> command. If empty we use the configured path, not a command line option --maxima=<str>.
+  static const wxString Get_Maxima_Commandline_Filename() {return maxima_command_line_filename;}
+
+
 private:
+  //! If we use the command line option --maxima=<str>, this variable is not-empty and contains its name
+  static wxString maxima_command_line_filename;
   bool m_maximaAuthenticated = false;
   bool m_discardAllData = false;
   wxString m_maximaAuthString;
@@ -235,6 +259,7 @@ private:
   //! The buffer all text from maxima is stored in before converting it to a wxString.
   wxMemoryBuffer m_uncompletedChars;
 
+
 protected:
   //! Invoke our standard wizard that generates maxima commands
   void CommandWiz(const wxString &title,
@@ -285,7 +310,7 @@ protected:
 
   //! Show the help for Maxima
   void ShowMaximaHelp(wxString = {});
-  
+
   //! Show the help for Maxima (without handling of anchors).
   void ShowMaximaHelpWithoutAnchor();
 
@@ -332,6 +357,7 @@ protected:
     - false, if there wasn't any new data.
   */
   bool InterpretDataFromMaxima(const wxString &newData);
+  bool InterpretDataFromMaxima();
   bool m_dataFromMaximaIs;
 
   void MenuCommand(const wxString &cmd);           //!< Inserts command cmd into the worksheet
@@ -370,9 +396,6 @@ protected:
   //! Is triggered when the "Find" button in the search dialog is pressed
   void OnFind(wxFindDialogEvent &event);
 
-  //! Is triggered when the "Close" button in the search dialog is pressed
-  void OnFindClose(wxFindDialogEvent &event);
-
   //! Is triggered when the "Replace" button in the search dialog is pressed
   void OnReplace(wxFindDialogEvent &event);
 
@@ -573,7 +596,6 @@ protected:
   void VariableActionLmxChar(const wxString &value);
   void VariableActionDisplay2D(const wxString &value);
   void VariableActionAltDisplay2D(const wxString &value);
-  void VariableActionNumer(const wxString &value);
   void VariableActionAlgebraic(const wxString &value);
   void VariableActionShowtime(const wxString &value);
   void VariableActionDomain(const wxString &value);
@@ -629,12 +651,6 @@ protected:
   */
   void ResetTitle(bool saved, bool force = false);
 
-  /*! Makes this window the debug log target of all windows from this maxima process
-
-    Only necessary on the mac where the same process creates loads of windows.
-  */
-  void BecomeLogTarget();
-
   void FirstOutput();
 
   /*! Opens a content.xml file that has been extracted from a broken .wxmx file
@@ -659,6 +675,7 @@ protected:
   /*! Saves the current file
 
     \param forceSave true means: Always ask for a file name before saving.
+    \return true, if the file was saved - or didn't need to
   */
   bool SaveFile(bool forceSave = false);
 
@@ -670,6 +687,13 @@ protected:
   */
   bool AutoSave();
 
+  /*! Tries or offers to save the document
+
+      If auto-save is on the document is automatically saved.
+
+      \return
+      * wxID_NO: No saving is necessary, currently
+  */
   int SaveDocumentP();
 
   //! Set the current working directory file I/O from maxima is relative to.
@@ -696,7 +720,7 @@ protected:
   };
   /*! The server maxima connects to as client
 
-    The destructor of the server causes 
+    The destructor of the server causes
     crashes if there are still pending events.
     Instead we need to call destroy.
   */
@@ -734,9 +758,11 @@ public:
   const static wxString m_promptSuffix;
   //! Remove the said window from the list of toplevel windows
   static void DelistTopLevelWindow(wxMaxima *);
-  //! The list of toplevel windows we currently maintain
-  static std::vector<wxMaxima *> m_topLevelWindows;
 protected:
+  void OnSize(wxSizeEvent &event);
+  void OnMove(wxMoveEvent &event);
+  void OnMaximize(wxCommandEvent &event);
+
   //! Sets gnuplot's command name and tries to determine gnuplot's path
   void GnuplotCommandName(wxString gnuplot);
   //! The marker for the start of a variables section
@@ -795,7 +821,7 @@ protected:
   wxString m_gnuplotcommand;
   //! The Char the current command starts at in the current WorkingGroup
   int m_commandIndex;
-  wxFindReplaceData m_findData;
+  FindReplacePane::FindReplaceData m_findData;
   static wxRegEx m_funRegEx;
   static wxRegEx m_varRegEx;
   static wxRegEx m_blankStatementRegEx;
@@ -808,11 +834,17 @@ private:
   wxString m_logexpand;
   //! A pointer to a method that handles a text chunk
   typedef void (wxMaxima::*ParseFunction)(wxString &s);
-  WX_DECLARE_STRING_HASH_MAP(ParseFunction, ParseFunctionHash);
   typedef void (wxMaxima::*VarReadFunction)(const wxString &value);
-  WX_DECLARE_STRING_HASH_MAP(VarReadFunction, VarReadFunctionHash);
   typedef void (wxMaxima::*VarUndefinedFunction)();
+#if wxCHECK_VERSION(3, 3, 0) || wxUSE_STL
+  typedef std::unordered_map <wxString, ParseFunction> ParseFunctionHash;
+  typedef std::unordered_map <wxString, VarReadFunction> VarReadFunctionHash;
+  typedef std::unordered_map <wxString, VarUndefinedFunction> VarUndefinedFunctionHash;
+#else
+  WX_DECLARE_STRING_HASH_MAP(ParseFunction, ParseFunctionHash);
+  WX_DECLARE_STRING_HASH_MAP(VarReadFunction, VarReadFunctionHash);
   WX_DECLARE_STRING_HASH_MAP(VarUndefinedFunction, VarUndefinedFunctionHash);
+#endif
   //! A list of XML tags we know and what we want to do if we encounter them
   static ParseFunctionHash m_knownXMLTags;
   //! A list of actions we want to execute if we are sent the contents of specific variables
